/* autogenerated by pidl */

/* DO NOT EDIT
	This filter was automatically generated
	from nspi.idl and nspi.cnf.
	
	Pidl is a perl based IDL compiler for DCE/RPC idl files. 
	It is maintained by the Samba team, not the Wireshark team.
	Instructions on how to download and install Pidl can be 
	found at http://wiki.wireshark.org/Pidl

	$Id: packet-dcerpc-nspi.h 34718 2010-10-30 16:29:23Z morriss $
*/


#ifndef __PACKET_DCERPC_NSPI_H
#define __PACKET_DCERPC_NSPI_H

#define PR_ACKNOWLEDGEMENT_MODE (0x00010003)
#define PR_ACKNOWLEDGEMENT_MODE_ERROR (0x0001000a)
#define PR_ALTERNATE_RECIPIENT_ALLOWED (0x0002000b)
#define PR_ALTERNATE_RECIPIENT_ALLOWED_ERROR (0x0002000a)
#define PR_AUTHORIZING_USERS (0x00030102)
#define PR_AUTHORIZING_USERS_ERROR (0x0003000a)
#define PR_AUTO_FORWARD_COMMENT (0x0004001e)
#define PR_AUTO_FORWARD_COMMENT_UNICODE (0x0004001f)
#define PR_AUTO_FORWARD_COMMENT_ERROR (0x0004000a)
#define PR_AUTO_FORWARDED (0x0005000b)
#define PR_AUTO_FORWARDED_ERROR (0x0005000a)
#define PR_CONTENT_CONFIDENTIALITY_ALGORITHM_ID (0x00060102)
#define PR_CONTENT_CONFIDENTIALITY_ALGORITHM_ID_ERROR (0x0006000a)
#define PR_CONTENT_CORRELATOR (0x00070102)
#define PR_CONTENT_CORRELATOR_ERROR (0x0007000a)
#define PR_CONTENT_IDENTIFIER (0x0008001e)
#define PR_CONTENT_IDENTIFIER_UNICODE (0x0008001f)
#define PR_CONTENT_IDENTIFIER_ERROR (0x0008000a)
#define PR_CONTENT_LENGTH (0x00090003)
#define PR_CONTENT_LENGTH_ERROR (0x0009000a)
#define PR_CONTENT_RETURN_REQUESTED (0x000a000b)
#define PR_CONTENT_RETURN_REQUESTED_ERROR (0x000a000a)
#define PR_CONVERSATION_KEY (0x000b0102)
#define PR_CONVERSATION_KEY_ERROR (0x000b000a)
#define PR_CONVERSION_EITS (0x000c0102)
#define PR_CONVERSION_EITS_ERROR (0x000c000a)
#define PR_CONVERSION_WITH_LOSS_PROHIBITED (0x000d000b)
#define PR_CONVERSION_WITH_LOSS_PROHIBITED_ERROR (0x000d000a)
#define PR_CONVERTED_EITS (0x000e0102)
#define PR_CONVERTED_EITS_ERROR (0x000e000a)
#define PR_DEFERRED_DELIVERY_TIME (0x000f0040)
#define PR_DEFERRED_DELIVERY_TIME_ERROR (0x000f000a)
#define PR_DELIVER_TIME (0x00100040)
#define PR_DELIVER_TIME_ERROR (0x0010000a)
#define PR_DISCARD_REASON (0x00110003)
#define PR_DISCARD_REASON_ERROR (0x0011000a)
#define PR_DISCLOSURE_OF_RECIPIENTS (0x0012000b)
#define PR_DISCLOSURE_OF_RECIPIENTS_ERROR (0x0012000a)
#define PR_DL_EXPANSION_HISTORY (0x00130102)
#define PR_DL_EXPANSION_HISTORY_ERROR (0x0013000a)
#define PR_DL_EXPANSION_PROHIBITED (0x0014000b)
#define PR_DL_EXPANSION_PROHIBITED_ERROR (0x0014000a)
#define PR_EXPIRY_TIME (0x00150040)
#define PR_EXPIRY_TIME_ERROR (0x0015000a)
#define PR_IMPLICIT_CONVERSION_PROHIBITED (0x0016000b)
#define PR_IMPLICIT_CONVERSION_PROHIBITED_ERROR (0x0016000a)
#define PR_IMPORTANCE (0x00170003)
#define PR_IMPORTANCE_ERROR (0x0017000a)
#define PR_IPM_ID (0x00180102)
#define PR_IPM_ID_ERROR (0x0018000a)
#define PR_LATEST_DELIVERY_TIME (0x00190040)
#define PR_LATEST_DELIVERY_TIME_ERROR (0x0019000a)
#define PR_MESSAGE_CLASS (0x001a001e)
#define PR_MESSAGE_CLASS_UNICODE (0x001a001f)
#define PR_MESSAGE_CLASS_ERROR (0x001a000a)
#define PR_MESSAGE_DELIVERY_ID (0x001b0102)
#define PR_MESSAGE_DELIVERY_ID_ERROR (0x001b000a)
#define PR_MESSAGE_SECURITY_LABEL (0x001e0102)
#define PR_MESSAGE_SECURITY_LABEL_ERROR (0x001e000a)
#define PR_OBSOLETED_IPMS (0x001f0102)
#define PR_OBSOLETED_IPMS_ERROR (0x001f000a)
#define PR_ORIGINALLY_INTENDED_RECIPIENT_NAME (0x00200102)
#define PR_ORIGINALLY_INTENDED_RECIPIENT_NAME_ERROR (0x0020000a)
#define PR_ORIGINAL_EITS (0x00210102)
#define PR_ORIGINAL_EITS_ERROR (0x0021000a)
#define PR_ORIGINATOR_CERTIFICATE (0x00220102)
#define PR_ORIGINATOR_CERTIFICATE_ERROR (0x0022000a)
#define PR_ORIGINATOR_DELIVERY_REPORT_REQUESTED (0x0023000b)
#define PR_ORIGINATOR_DELIVERY_REPORT_REQUESTED_ERROR (0x0023000a)
#define PR_ORIGINATOR_RETURN_ADDRESS (0x00240102)
#define PR_ORIGINATOR_RETURN_ADDRESS_ERROR (0x0024000a)
#define PR_PARENT_KEY (0x00250102)
#define PR_PARENT_KEY_ERROR (0x0025000a)
#define PR_PRIORITY (0x00260003)
#define PR_PRIORITY_ERROR (0x0026000a)
#define PR_ORIGIN_CHECK (0x00270102)
#define PR_ORIGIN_CHECK_ERROR (0x0027000a)
#define PR_PROOF_OF_SUBMISSION_REQUESTED (0x0028000b)
#define PR_PROOF_OF_SUBMISSION_REQUESTED_ERROR (0x0028000a)
#define PR_READ_RECEIPT_REQUESTED (0x0029000b)
#define PR_READ_RECEIPT_REQUESTED_ERROR (0x0029000a)
#define PR_RECEIPT_TIME (0x002a0040)
#define PR_RECEIPT_TIME_ERROR (0x002a000a)
#define PR_RECIPIENT_REASSIGNMENT_PROHIBITED (0x002b000b)
#define PR_RECIPIENT_REASSIGNMENT_PROHIBITED_ERROR (0x002b000a)
#define PR_REDIRECTION_HISTORY (0x002c0102)
#define PR_REDIRECTION_HISTORY_ERROR (0x002c000a)
#define PR_RELATED_IPMS (0x002d0102)
#define PR_RELATED_IPMS_ERROR (0x002d000a)
#define PR_ORIGINAL_SENSITIVITY (0x002e0003)
#define PR_ORIGINAL_SENSITIVITY_ERROR (0x002e000a)
#define PR_LANGUAGES (0x002f001e)
#define PR_LANGUAGES_UNICODE (0x002f001f)
#define PR_LANGUAGES_ERROR (0x002f000a)
#define PR_REPLY_TIME (0x00300040)
#define PR_REPLY_TIME_ERROR (0x0030000a)
#define PR_REPORT_TAG (0x00310102)
#define PR_REPORT_TAG_ERROR (0x0031000a)
#define PR_REPORT_TIME (0x00320040)
#define PR_REPORT_TIME_ERROR (0x0032000a)
#define PR_RETURNED_IPM (0x0033000b)
#define PR_RETURNED_IPM_ERROR (0x0033000a)
#define PR_SECURITY (0x00340003)
#define PR_SECURITY_ERROR (0x0034000a)
#define PR_INCOMPLETE_COPY (0x0035000b)
#define PR_INCOMPLETE_COPY_ERROR (0x0035000a)
#define PR_SENSITIVITY (0x00360003)
#define PR_SENSITIVITY_ERROR (0x0036000a)
#define PR_SUBJECT (0x0037001e)
#define PR_SUBJECT_UNICODE (0x0037001f)
#define PR_SUBJECT_ERROR (0x0037000a)
#define PR_SUBJECT_IPM (0x00380102)
#define PR_SUBJECT_IPM_ERROR (0x0038000a)
#define PR_CLIENT_SUBMIT_TIME (0x00390040)
#define PR_CLIENT_SUBMIT_TIME_ERROR (0x0039000a)
#define PR_REPORT_NAME (0x003a001e)
#define PR_REPORT_NAME_UNICODE (0x003a001f)
#define PR_REPORT_NAME_ERROR (0x003a000a)
#define PR_SENT_REPRESENTING_SEARCH_KEY (0x003b0102)
#define PR_SENT_REPRESENTING_SEARCH_KEY_ERROR (0x003b000a)
#define PR_X400_CONTENT_TYPE (0x003c0102)
#define PR_X400_CONTENT_TYPE_ERROR (0x003c000a)
#define PR_SUBJECT_PREFIX (0x003d001e)
#define PR_SUBJECT_PREFIX_UNICODE (0x003d001f)
#define PR_SUBJECT_PREFIX_ERROR (0x003d000a)
#define PR_NON_RECEIPT_REASON (0x003e0003)
#define PR_NON_RECEIPT_REASON_ERROR (0x003e000a)
#define PR_RECEIVED_BY_ENTRYID (0x003f0102)
#define PR_RECEIVED_BY_ENTRYID_ERROR (0x003f000a)
#define PR_RECEIVED_BY_NAME (0x0040001e)
#define PR_RECEIVED_BY_NAME_UNICODE (0x0040001f)
#define PR_RECEIVED_BY_NAME_ERROR (0x0040000a)
#define PR_SENT_REPRESENTING_ENTRYID (0x00410102)
#define PR_SENT_REPRESENTING_ENTRYID_ERROR (0x0041000a)
#define PR_SENT_REPRESENTING_NAME (0x0042001e)
#define PR_SENT_REPRESENTING_NAME_UNICODE (0x0042001f)
#define PR_SENT_REPRESENTING_NAME_ERROR (0x0042000a)
#define PR_RCVD_REPRESENTING_ENTRYID (0x00430102)
#define PR_RCVD_REPRESENTING_ENTRYID_ERROR (0x0043000a)
#define PR_RCVD_REPRESENTING_NAME (0x0044001e)
#define PR_RCVD_REPRESENTING_NAME_UNICODE (0x0044001f)
#define PR_RCVD_REPRESENTING_NAME_ERROR (0x0044000a)
#define PR_REPORT_ENTRYID (0x00450102)
#define PR_REPORT_ENTRYID_ERROR (0x0045000a)
#define PR_READ_RECEIPT_ENTRYID (0x00460102)
#define PR_READ_RECEIPT_ENTRYID_ERROR (0x0046000a)
#define PR_MESSAGE_SUBMISSION_ID (0x00470102)
#define PR_MESSAGE_SUBMISSION_ID_ERROR (0x0047000a)
#define PR_PROVIDER_SUBMIT_TIME (0x00480040)
#define PR_PROVIDER_SUBMIT_TIME_ERROR (0x0048000a)
#define PR_ORIGINAL_SUBJECT (0x0049001e)
#define PR_ORIGINAL_SUBJECT_UNICODE (0x0049001f)
#define PR_ORIGINAL_SUBJECT_ERROR (0x0049000a)
#define PR_DISC_VAL (0x004a000b)
#define PR_DISC_VAL_ERROR (0x004a000a)
#define PR_ORIG_MESSAGE_CLASS (0x004b001e)
#define PR_ORIG_MESSAGE_CLASS_UNICODE (0x004b001f)
#define PR_ORIG_MESSAGE_CLASS_ERROR (0x004b000a)
#define PR_ORIGINAL_AUTHOR_ENTRYID (0x004c0102)
#define PR_ORIGINAL_AUTHOR_ENTRYID_ERROR (0x004c000a)
#define PR_ORIGINAL_AUTHOR_NAME (0x004d001e)
#define PR_ORIGINAL_AUTHOR_NAME_UNICODE (0x004d001f)
#define PR_ORIGINAL_AUTHOR_NAME_ERROR (0x004d000a)
#define PR_ORIGINAL_SUBMIT_TIME (0x004e0040)
#define PR_ORIGINAL_SUBMIT_TIME_ERROR (0x004e000a)
#define PR_REPLY_RECIPIENT_ENTRIES (0x004f0102)
#define PR_REPLY_RECIPIENT_ENTRIES_ERROR (0x004f000a)
#define PR_REPLY_RECIPIENT_NAMES (0x0050001e)
#define PR_REPLY_RECIPIENT_NAMES_UNICODE (0x0050001f)
#define PR_REPLY_RECIPIENT_NAMES_ERROR (0x0050000a)
#define PR_RECEIVED_BY_SEARCH_KEY (0x00510102)
#define PR_RECEIVED_BY_SEARCH_KEY_ERROR (0x0051000a)
#define PR_RCVD_REPRESENTING_SEARCH_KEY (0x00520102)
#define PR_RCVD_REPRESENTING_SEARCH_KEY_ERROR (0x0052000a)
#define PR_READ_RECEIPT_SEARCH_KEY (0x00530102)
#define PR_READ_RECEIPT_SEARCH_KEY_ERROR (0x0053000a)
#define PR_REPORT_SEARCH_KEY (0x00540102)
#define PR_REPORT_SEARCH_KEY_ERROR (0x0054000a)
#define PR_ORIGINAL_DELIVERY_TIME (0x00550040)
#define PR_ORIGINAL_DELIVERY_TIME_ERROR (0x0055000a)
#define PR_ORIGINAL_AUTHOR_SEARCH_KEY (0x00560102)
#define PR_ORIGINAL_AUTHOR_SEARCH_KEY_ERROR (0x0056000a)
#define PR_MESSAGE_TO_ME (0x0057000b)
#define PR_MESSAGE_TO_ME_ERROR (0x0057000a)
#define PR_MESSAGE_CC_ME (0x0058000b)
#define PR_MESSAGE_CC_ME_ERROR (0x0058000a)
#define PR_MESSAGE_RECIP_ME (0x0059000b)
#define PR_MESSAGE_RECIP_ME_ERROR (0x0059000a)
#define PR_ORIGINAL_SENDER_NAME (0x005a001e)
#define PR_ORIGINAL_SENDER_NAME_UNICODE (0x005a001f)
#define PR_ORIGINAL_SENDER_NAME_ERROR (0x005a000a)
#define PR_ORIGINAL_SENDER_ENTRYID (0x005b0102)
#define PR_ORIGINAL_SENDER_ENTRYID_ERROR (0x005b000a)
#define PR_ORIGINAL_SENDER_SEARCH_KEY (0x005c0102)
#define PR_ORIGINAL_SENDER_SEARCH_KEY_ERROR (0x005c000a)
#define PR_ORIGINAL_SENT_REPRESENTING_NAME (0x005d001e)
#define PR_ORIGINAL_SENT_REPRESENTING_NAME_UNICODE (0x005d001f)
#define PR_ORIGINAL_SENT_REPRESENTING_NAME_ERROR (0x005d000a)
#define PR_ORIGINAL_SENT_REPRESENTING_ENTRYID (0x005e0102)
#define PR_ORIGINAL_SENT_REPRESENTING_ENTRYID_ERROR (0x005e000a)
#define PR_ORIGINAL_SENT_REPRESENTING_SEARCH_KEY (0x005f0102)
#define PR_ORIGINAL_SENT_REPRESENTING_SEARCH_KEY_ERROR (0x005f000a)
#define PR_START_DATE (0x00600040)
#define PR_START_DATE_ERROR (0x0060000a)
#define PR_END_DATE (0x00610040)
#define PR_END_DATE_ERROR (0x0061000a)
#define PR_OWNER_APPT_ID (0x00620003)
#define PR_OWNER_APPT_ID_ERROR (0x0062000a)
#define PR_RESPONSE_REQUESTED (0x0063000b)
#define PR_RESPONSE_REQUESTED_ERROR (0x0063000a)
#define PR_SENT_REPRESENTING_ADDRTYPE (0x0064001e)
#define PR_SENT_REPRESENTING_ADDRTYPE_UNICODE (0x0064001f)
#define PR_SENT_REPRESENTING_ADDRTYPE_ERROR (0x0064000a)
#define PR_SENT_REPRESENTING_EMAIL_ADDRESS (0x0065001e)
#define PR_SENT_REPRESENTING_EMAIL_ADDRESS_UNICODE (0x0065001f)
#define PR_SENT_REPRESENTING_EMAIL_ADDRESS_ERROR (0x0065000a)
#define PR_ORIGINAL_SENDER_ADDRTYPE (0x0066001e)
#define PR_ORIGINAL_SENDER_ADDRTYPE_UNICODE (0x0066001f)
#define PR_ORIGINAL_SENDER_ADDRTYPE_ERROR (0x0066000a)
#define PR_ORIGINAL_SENDER_EMAIL_ADDRESS (0x0067001e)
#define PR_ORIGINAL_SENDER_EMAIL_ADDRESS_UNICODE (0x0067001f)
#define PR_ORIGINAL_SENDER_EMAIL_ADDRESS_ERROR (0x0067000a)
#define PR_ORIGINAL_SENT_REPRESENTING_ADDRTYPE (0x0068001e)
#define PR_ORIGINAL_SENT_REPRESENTING_ADDRTYPE_UNICODE (0x0068001f)
#define PR_ORIGINAL_SENT_REPRESENTING_ADDRTYPE_ERROR (0x0068000a)
#define PR_ORIGINAL_SENT_REPRESENTING_EMAIL_ADDRESS (0x0069001e)
#define PR_ORIGINAL_SENT_REPRESENTING_EMAIL_ADDRESS_UNICODE (0x0069001f)
#define PR_ORIGINAL_SENT_REPRESENTING_EMAIL_ADDRESS_ERROR (0x0069000a)
#define PR_CONVERSATION_TOPIC (0x0070001e)
#define PR_CONVERSATION_TOPIC_UNICODE (0x0070001f)
#define PR_CONVERSATION_TOPIC_ERROR (0x0070000a)
#define PR_CONVERSATION_INDEX (0x00710102)
#define PR_CONVERSATION_INDEX_ERROR (0x0071000a)
#define PR_ORIGINAL_DISPLAY_BCC (0x0072001e)
#define PR_ORIGINAL_DISPLAY_BCC_UNICODE (0x0072001f)
#define PR_ORIGINAL_DISPLAY_BCC_ERROR (0x0072000a)
#define PR_ORIGINAL_DISPLAY_CC (0x0073001e)
#define PR_ORIGINAL_DISPLAY_CC_UNICODE (0x0073001f)
#define PR_ORIGINAL_DISPLAY_CC_ERROR (0x0073000a)
#define PR_ORIGINAL_DISPLAY_TO (0x0074001e)
#define PR_ORIGINAL_DISPLAY_TO_UNICODE (0x0074001f)
#define PR_ORIGINAL_DISPLAY_TO_ERROR (0x0074000a)
#define PR_RECEIVED_BY_ADDRTYPE (0x0075001e)
#define PR_RECEIVED_BY_ADDRTYPE_UNICODE (0x0075001f)
#define PR_RECEIVED_BY_ADDRTYPE_ERROR (0x0075000a)
#define PR_RECEIVED_BY_EMAIL_ADDRESS (0x0076001e)
#define PR_RECEIVED_BY_EMAIL_ADDRESS_UNICODE (0x0076001f)
#define PR_RECEIVED_BY_EMAIL_ADDRESS_ERROR (0x0076000a)
#define PR_RCVD_REPRESENTING_ADDRTYPE (0x0077001e)
#define PR_RCVD_REPRESENTING_ADDRTYPE_UNICODE (0x0077001f)
#define PR_RCVD_REPRESENTING_ADDRTYPE_ERROR (0x0077000a)
#define PR_RCVD_REPRESENTING_EMAIL_ADDRESS (0x0078001e)
#define PR_RCVD_REPRESENTING_EMAIL_ADDRESS_UNICODE (0x0078001f)
#define PR_RCVD_REPRESENTING_EMAIL_ADDRESS_ERROR (0x0078000a)
#define PR_ORIGINAL_AUTHOR_ADDRTYPE (0x0079001e)
#define PR_ORIGINAL_AUTHOR_ADDRTYPE_UNICODE (0x0079001f)
#define PR_ORIGINAL_AUTHOR_ADDRTYPE_ERROR (0x0079000a)
#define PR_ORIGINAL_AUTHOR_EMAIL_ADDRESS (0x007a001e)
#define PR_ORIGINAL_AUTHOR_EMAIL_ADDRESS_UNICODE (0x007a001f)
#define PR_ORIGINAL_AUTHOR_EMAIL_ADDRESS_ERROR (0x007a000a)
#define PR_ORIGINALLY_INTENDED_RECIP_ADDRTYPE (0x007b001e)
#define PR_ORIGINALLY_INTENDED_RECIP_ADDRTYPE_UNICODE (0x007b001f)
#define PR_ORIGINALLY_INTENDED_RECIP_ADDRTYPE_ERROR (0x007b000a)
#define PR_ORIGINALLY_INTENDED_RECIP_EMAIL_ADDRESS (0x007c001e)
#define PR_ORIGINALLY_INTENDED_RECIP_EMAIL_ADDRESS_UNICODE (0x007c001f)
#define PR_ORIGINALLY_INTENDED_RECIP_EMAIL_ADDRESS_ERROR (0x007c000a)
#define PR_TRANSPORT_MESSAGE_HEADERS (0x007d001e)
#define PR_TRANSPORT_MESSAGE_HEADERS_UNICODE (0x007d001f)
#define PR_TRANSPORT_MESSAGE_HEADERS_ERROR (0x007d000a)
#define PR_DELEGATION (0x007e0102)
#define PR_DELEGATION_ERROR (0x007e000a)
#define PR_TNEF_CORRELATION_KEY (0x007f0102)
#define PR_TNEF_CORRELATION_KEY_ERROR (0x007f000a)
#define PR_CONTENT_INTEGRITY_CHECK (0x0c000102)
#define PR_CONTENT_INTEGRITY_CHECK_ERROR (0x0c00000a)
#define PR_EXPLICIT_CONVERSION (0x0c010003)
#define PR_EXPLICIT_CONVERSION_ERROR (0x0c01000a)
#define PR_IPM_RETURN_REQUESTED (0x0c02000b)
#define PR_IPM_RETURN_REQUESTED_ERROR (0x0c02000a)
#define PR_MESSAGE_TOKEN (0x0c030102)
#define PR_MESSAGE_TOKEN_ERROR (0x0c03000a)
#define PR_NDR_REASON_CODE (0x0c040003)
#define PR_NDR_REASON_CODE_ERROR (0x0c04000a)
#define PR_NDR_DIAG_CODE (0x0c050003)
#define PR_NDR_DIAG_CODE_ERROR (0x0c05000a)
#define PR_NON_RECEIPT_NOTIFICATION_REQUESTED (0x0c06000b)
#define PR_NON_RECEIPT_NOTIFICATION_REQUESTED_ERROR (0x0c06000a)
#define PR_DELIVERY_POINT (0x0c070003)
#define PR_DELIVERY_POINT_ERROR (0x0c07000a)
#define PR_ORIGINATOR_NON_DELIVERY_REPORT_REQUESTED (0x0c08000b)
#define PR_ORIGINATOR_NON_DELIVERY_REPORT_REQUESTED_ERROR (0x0c08000a)
#define PR_ORIGINATOR_REQUESTED_ALTERNATE_RECIPIENT (0x0c090102)
#define PR_ORIGINATOR_REQUESTED_ALTERNATE_RECIPIENT_ERROR (0x0c09000a)
#define PR_PHYSICAL_DELIVERY_BUREAU_FAX_DELIVERY (0x0c0a000b)
#define PR_PHYSICAL_DELIVERY_BUREAU_FAX_DELIVERY_ERROR (0x0c0a000a)
#define PR_PHYSICAL_DELIVERY_MODE (0x0c0b0003)
#define PR_PHYSICAL_DELIVERY_MODE_ERROR (0x0c0b000a)
#define PR_PHYSICAL_DELIVERY_REPORT_REQUEST (0x0c0c0003)
#define PR_PHYSICAL_DELIVERY_REPORT_REQUEST_ERROR (0x0c0c000a)
#define PR_PHYSICAL_FORWARDING_ADDRESS (0x0c0d0102)
#define PR_PHYSICAL_FORWARDING_ADDRESS_ERROR (0x0c0d000a)
#define PR_PHYSICAL_FORWARDING_ADDRESS_REQUESTED (0x0c0e000b)
#define PR_PHYSICAL_FORWARDING_ADDRESS_REQUESTED_ERROR (0x0c0e000a)
#define PR_PHYSICAL_FORWARDING_PROHIBITED (0x0c0f000b)
#define PR_PHYSICAL_FORWARDING_PROHIBITED_ERROR (0x0c0f000a)
#define PR_PHYSICAL_RENDITION_ATTRIBUTES (0x0c100102)
#define PR_PHYSICAL_RENDITION_ATTRIBUTES_ERROR (0x0c10000a)
#define PR_PROOF_OF_DELIVERY (0x0c110102)
#define PR_PROOF_OF_DELIVERY_ERROR (0x0c11000a)
#define PR_PROOF_OF_DELIVERY_REQUESTED (0x0c12000b)
#define PR_PROOF_OF_DELIVERY_REQUESTED_ERROR (0x0c12000a)
#define PR_RECIPIENT_CERTIFICATE (0x0c130102)
#define PR_RECIPIENT_CERTIFICATE_ERROR (0x0c13000a)
#define PR_RECIPIENT_NUMBER_FOR_ADVICE (0x0c14001e)
#define PR_RECIPIENT_NUMBER_FOR_ADVICE_UNICODE (0x0c14001f)
#define PR_RECIPIENT_NUMBER_FOR_ADVICE_ERROR (0x0c14000a)
#define PR_RECIPIENT_TYPE (0x0c150003)
#define PR_RECIPIENT_TYPE_ERROR (0x0c15000a)
#define PR_REGISTERED_MAIL_TYPE (0x0c160003)
#define PR_REGISTERED_MAIL_TYPE_ERROR (0x0c16000a)
#define PR_REPLY_REQUESTED (0x0c17000b)
#define PR_REPLY_REQUESTED_ERROR (0x0c17000a)
#define PR_REQUESTED_DELIVERY_METHOD (0x0c180003)
#define PR_REQUESTED_DELIVERY_METHOD_ERROR (0x0c18000a)
#define PR_SENDER_ENTRYID (0x0c190102)
#define PR_SENDER_ENTRYID_ERROR (0x0c19000a)
#define PR_SENDER_NAME (0x0c1a001e)
#define PR_SENDER_NAME_UNICODE (0x0c1a001f)
#define PR_SENDER_NAME_ERROR (0x0c1a000a)
#define PR_SUPPLEMENTARY_INFO (0x0c1b001e)
#define PR_SUPPLEMENTARY_INFO_UNICODE (0x0c1b001f)
#define PR_SUPPLEMENTARY_INFO_ERROR (0x0c1b000a)
#define PR_TYPE_OF_MTS_USER (0x0c1c0003)
#define PR_TYPE_OF_MTS_USER_ERROR (0x0c1c000a)
#define PR_SENDER_SEARCH_KEY (0x0c1d0102)
#define PR_SENDER_SEARCH_KEY_ERROR (0x0c1d000a)
#define PR_SENDER_ADDRTYPE (0x0c1e001e)
#define PR_SENDER_ADDRTYPE_UNICODE (0x0c1e001f)
#define PR_SENDER_ADDRTYPE_ERROR (0x0c1e000a)
#define PR_SENDER_EMAIL_ADDRESS (0x0c1f001e)
#define PR_SENDER_EMAIL_ADDRESS_UNICODE (0x0c1f001f)
#define PR_SENDER_EMAIL_ADDRESS_ERROR (0x0c1f000a)
#define PR_CURRENT_VERSION (0x0e000014)
#define PR_CURRENT_VERSION_ERROR (0x0e00000a)
#define PR_DELETE_AFTER_SUBMIT (0x0e01000b)
#define PR_DELETE_AFTER_SUBMIT_ERROR (0x0e01000a)
#define PR_DISPLAY_BCC (0x0e02001e)
#define PR_DISPLAY_BCC_UNICODE (0x0e02001f)
#define PR_DISPLAY_BCC_ERROR (0x0e02000a)
#define PR_DISPLAY_CC (0x0e03001e)
#define PR_DISPLAY_CC_UNICODE (0x0e03001f)
#define PR_DISPLAY_CC_ERROR (0x0e03000a)
#define PR_DISPLAY_TO (0x0e04001e)
#define PR_DISPLAY_TO_UNICODE (0x0e04001f)
#define PR_DISPLAY_TO_ERROR (0x0e04000a)
#define PR_PARENT_DISPLAY (0x0e05001e)
#define PR_PARENT_DISPLAY_UNICODE (0x0e05001f)
#define PR_PARENT_DISPLAY_ERROR (0x0e05000a)
#define PR_MESSAGE_DELIVERY_TIME (0x0e060040)
#define PR_MESSAGE_DELIVERY_TIME_ERROR (0x0e06000a)
#define PR_MESSAGE_FLAGS (0x0e070003)
#define PR_MESSAGE_FLAGS_ERROR (0x0e07000a)
#define PR_MESSAGE_SIZE (0x0e080003)
#define PR_MESSAGE_SIZE_ERROR (0x0e08000a)
#define PR_MESSAGE_SIZE_EXTENDED (0x0e080014)
#define PR_PARENT_ENTRYID (0x0e090102)
#define PR_PARENT_ENTRYID_ERROR (0x0e09000a)
#define PR_SENTMAIL_ENTRYID (0x0e0a0102)
#define PR_SENTMAIL_ENTRYID_ERROR (0x0e0a000a)
#define PR_CORRELATE (0x0e0c000b)
#define PR_CORRELATE_ERROR (0x0e0c000a)
#define PR_CORRELATE_MTSID (0x0e0d0102)
#define PR_CORRELATE_MTSID_ERROR (0x0e0d000a)
#define PR_DISCRETE_VALUES (0x0e0e000b)
#define PR_DISCRETE_VALUES_ERROR (0x0e0e000a)
#define PR_RESPONSIBILITY (0x0e0f000b)
#define PR_RESPONSIBILITY_ERROR (0x0e0f000a)
#define PR_SPOOLER_STATUS (0x0e100003)
#define PR_SPOOLER_STATUS_ERROR (0x0e10000a)
#define PR_TRANSPORT_STATUS (0x0e110003)
#define PR_TRANSPORT_STATUS_ERROR (0x0e11000a)
#define PR_MESSAGE_RECIPIENTS (0x0e12000d)
#define PR_MESSAGE_RECIPIENTS_ERROR (0x0e12000a)
#define PR_MESSAGE_ATTACHMENTS (0x0e13000d)
#define PR_MESSAGE_ATTACHMENTS_ERROR (0x0e13000a)
#define PR_SUBMIT_FLAGS (0x0e140003)
#define PR_SUBMIT_FLAGS_ERROR (0x0e14000a)
#define PR_RECIPIENT_STATUS (0x0e150003)
#define PR_RECIPIENT_STATUS_ERROR (0x0e15000a)
#define PR_TRANSPORT_KEY (0x0e160003)
#define PR_TRANSPORT_KEY_ERROR (0x0e16000a)
#define PR_MSG_STATUS (0x0e170003)
#define PR_MSG_STATUS_ERROR (0x0e17000a)
#define PR_MESSAGE_DOWNLOAD_TIME (0x0e180003)
#define PR_MESSAGE_DOWNLOAD_TIME_ERROR (0x0e18000a)
#define PR_CREATION_VERSION (0x0e190014)
#define PR_CREATION_VERSION_ERROR (0x0e19000a)
#define PR_MODIFY_VERSION (0x0e1a0014)
#define PR_MODIFY_VERSION_ERROR (0x0e1a000a)
#define PR_HASATTACH (0x0e1b000b)
#define PR_HASATTACH_ERROR (0x0e1b000a)
#define PR_BODY_CRC (0x0e1c0003)
#define PR_BODY_CRC_ERROR (0x0e1c000a)
#define PR_NORMALIZED_SUBJECT (0x0e1d001e)
#define PR_NORMALIZED_SUBJECT_UNICODE (0x0e1d001f)
#define PR_NORMALIZED_SUBJECT_ERROR (0x0e1d000a)
#define PR_RTF_IN_SYNC (0x0e1f000b)
#define PR_RTF_IN_SYNC_ERROR (0x0e1f000a)
#define PR_ATTACH_SIZE (0x0e200003)
#define PR_ATTACH_SIZE_ERROR (0x0e20000a)
#define PR_ATTACH_NUM (0x0e210003)
#define PR_ATTACH_NUM_ERROR (0x0e21000a)
#define PR_PREPROCESS (0x0e22000b)
#define PR_PREPROCESS_ERROR (0x0e22000a)
#define PR_INTERNET_ARTICLE_NUMBER (0x0e230003)
#define PR_INTERNET_ARTICLE_NUMBER_ERROR (0x0e23000a)
#define PR_NEWSGROUP_NAME (0x0e24001e)
#define PR_NEWSGROUP_NAME_UNICODE (0x0e24001f)
#define PR_NEWSGROUP_NAME_ERROR (0x0e24000a)
#define PR_ORIGINATING_MTA_CERTIFICATE (0x0e250102)
#define PR_ORIGINATING_MTA_CERTIFICATE_ERROR (0x0e25000a)
#define PR_PROOF_OF_SUBMISSION (0x0e260102)
#define PR_PROOF_OF_SUBMISSION_ERROR (0x0e26000a)
#define PR_NT_SECURITY_DESCRIPTOR (0x0e270102)
#define PR_NT_SECURITY_DESCRIPTOR_ERROR (0x0e27000a)
#define PR_CREATOR_SID (0x0e580102)
#define PR_CREATOR_SID_ERROR (0x0e58000a)
#define PR_LAST_MODIFIER_SID (0x0e590102)
#define PR_LAST_MODIFIER_SID_ERROR (0x0e59000a)
#define PR_MIME_HANDLER_CLASSIDS (0x0e5e0048)
#define PR_MIME_HANDLER_CLASSIDS_ERROR (0x0e5e000a)
#define PR_URL_COMP_NAME_POSTFIX (0x0e610003)
#define PR_URL_COMP_NAME_POSTFIX_ERROR (0x0e61000a)
#define PR_URL_COMP_NAME_SET (0x0e62000b)
#define PR_URL_COMP_NAME_SET_ERROR (0x0e62000a)
#define PR_SUBFOLDER_CT (0x0e630003)
#define PR_SUBFOLDER_CT_ERROR (0x0e63000a)
#define PR_DELETED_SUBFOLDER_CT (0x0e640003)
#define PR_DELETED_SUBFOLDER_CT_ERROR (0x0e64000a)
#define PR_DELETE_TIME (0x0e660040)
#define PR_DELETE_TIME_ERROR (0x0e66000a)
#define PR_AGE_LIMIT (0x0e670102)
#define PR_AGE_LIMIT_ERROR (0x0e67000a)
#define PR_TRUST_SENDER (0x0e790003)
#define PR_TRUST_SENDER_ERROR (0x0e79000a)
#define PR_ATTACH_VIRUS_SCAN_INFO (0x0e960102)
#define PR_ATTACH_VIRUS_SCAN_INFO_ERROR (0x0e96000a)
#define PR_ACCESS (0x0ff40003)
#define PR_ACCESS_ERROR (0x0ff4000a)
#define PR_ROW_TYPE (0x0ff50003)
#define PR_ROW_TYPE_ERROR (0x0ff5000a)
#define PR_INSTANCE_KEY (0x0ff60102)
#define PR_INSTANCE_KEY_ERROR (0x0ff6000a)
#define PR_ACCESS_LEVEL (0x0ff70003)
#define PR_ACCESS_LEVEL_ERROR (0x0ff7000a)
#define PR_MAPPING_SIGNATURE (0x0ff80102)
#define PR_MAPPING_SIGNATURE_ERROR (0x0ff8000a)
#define PR_RECORD_KEY (0x0ff90102)
#define PR_RECORD_KEY_ERROR (0x0ff9000a)
#define PR_STORE_RECORD_KEY (0x0ffa0102)
#define PR_STORE_RECORD_KEY_ERROR (0x0ffa000a)
#define PR_STORE_ENTRYID (0x0ffb0102)
#define PR_STORE_ENTRYID_ERROR (0x0ffb000a)
#define PR_MINI_ICON (0x0ffc0102)
#define PR_MINI_ICON_ERROR (0x0ffc000a)
#define PR_ICON (0x0ffd0102)
#define PR_ICON_ERROR (0x0ffd000a)
#define PR_OBJECT_TYPE (0x0ffe0003)
#define PR_OBJECT_TYPE_ERROR (0x0ffe000a)
#define PR_ENTRYID (0x0fff0102)
#define PR_ENTRYID_ERROR (0x0fff000a)
#define PR_BODY (0x1000001e)
#define PR_BODY_UNICODE (0x1000001f)
#define PR_BODY_ERROR (0x1000000a)
#define PR_REPORT_TEXT (0x1001001e)
#define PR_REPORT_TEXT_UNICODE (0x1001001f)
#define PR_REPORT_TEXT_ERROR (0x1001000a)
#define PR_ORIGINATOR_AND_DL_EXPANSION_HISTORY (0x10020102)
#define PR_ORIGINATOR_AND_DL_EXPANSION_HISTORY_ERROR (0x1002000a)
#define PR_REPORTING_DL_NAME (0x10030102)
#define PR_REPORTING_DL_NAME_ERROR (0x1003000a)
#define PR_REPORTING_MTA_CERTIFICATE (0x10040102)
#define PR_REPORTING_MTA_CERTIFICATE_ERROR (0x1004000a)
#define PR_RTF_SYNC_BODY_CRC (0x10060003)
#define PR_RTF_SYNC_BODY_CRC_ERROR (0x1006000a)
#define PR_RTF_SYNC_BODY_COUNT (0x10070003)
#define PR_RTF_SYNC_BODY_COUNT_ERROR (0x1007000a)
#define PR_RTF_SYNC_BODY_TAG (0x1008001e)
#define PR_RTF_SYNC_BODY_TAG_UNICODE (0x1008001f)
#define PR_RTF_SYNC_BODY_TAG_ERROR (0x1008000a)
#define PR_RTF_COMPRESSED (0x10090102)
#define PR_RTF_COMPRESSED_ERROR (0x1009000a)
#define PR_RTF_SYNC_PREFIX_COUNT (0x10100003)
#define PR_RTF_SYNC_PREFIX_COUNT_ERROR (0x1010000a)
#define PR_RTF_SYNC_TRAILING_COUNT (0x10110003)
#define PR_RTF_SYNC_TRAILING_COUNT_ERROR (0x1011000a)
#define PR_ORIGINALLY_INTENDED_RECIP_ENTRYID (0x10120102)
#define PR_ORIGINALLY_INTENDED_RECIP_ENTRYID_ERROR (0x1012000a)
#define PR_HTML (0x10130102)
#define PR_HTML_ERROR (0x1013000a)
#define PR_INTERNET_APPROVED (0x1030001e)
#define PR_INTERNET_APPROVED_UNICODE (0x1030001f)
#define PR_INTERNET_APPROVED_ERROR (0x1030000a)
#define PR_INTERNET_CONTROL (0x1031001e)
#define PR_INTERNET_CONTROL_UNICODE (0x1031001f)
#define PR_INTERNET_CONTROL_ERROR (0x1031000a)
#define PR_INTERNET_DISTRIBUTION (0x1032001e)
#define PR_INTERNET_DISTRIBUTION_UNICODE (0x1032001f)
#define PR_INTERNET_DISTRIBUTION_ERROR (0x1032000a)
#define PR_INTERNET_FOLLOWUP_TO (0x1033001e)
#define PR_INTERNET_FOLLOWUP_TO_UNICODE (0x1033001f)
#define PR_INTERNET_FOLLOWUP_TO_ERROR (0x1033000a)
#define PR_INTERNET_LINES (0x10340003)
#define PR_INTERNET_LINES_ERROR (0x1034000a)
#define PR_INTERNET_MESSAGE_ID (0x1035001e)
#define PR_INTERNET_MESSAGE_ID_UNICODE (0x1035001f)
#define PR_INTERNET_MESSAGE_ID_ERROR (0x1035000a)
#define PR_INTERNET_NEWSGROUPS (0x1036001e)
#define PR_INTERNET_NEWSGROUPS_UNICODE (0x1036001f)
#define PR_INTERNET_NEWSGROUPS_ERROR (0x1036000a)
#define PR_INTERNET_ORGANIZATION (0x1037001e)
#define PR_INTERNET_ORGANIZATION_UNICODE (0x1037001f)
#define PR_INTERNET_ORGANIZATION_ERROR (0x1037000a)
#define PR_INTERNET_NNTP_PATH (0x1038001e)
#define PR_INTERNET_NNTP_PATH_UNICODE (0x1038001f)
#define PR_INTERNET_NNTP_PATH_ERROR (0x1038000a)
#define PR_INTERNET_REFERENCES (0x1039001e)
#define PR_INTERNET_REFERENCES_UNICODE (0x1039001f)
#define PR_INTERNET_REFERENCES_ERROR (0x1039000a)
#define PR_SUPERSEDES (0x103a001e)
#define PR_SUPERSEDES_UNICODE (0x103a001f)
#define PR_SUPERSEDES_ERROR (0x103a000a)
#define PR_POST_FOLDER_ENTRIES (0x103b0102)
#define PR_POST_FOLDER_ENTRIES_ERROR (0x103b000a)
#define PR_POST_FOLDER_NAMES (0x103c001e)
#define PR_POST_FOLDER_NAMES_UNICODE (0x103c001f)
#define PR_POST_FOLDER_NAMES_ERROR (0x103c000a)
#define PR_POST_REPLY_FOLDER_ENTRIES (0x103d0102)
#define PR_POST_REPLY_FOLDER_ENTRIES_ERROR (0x103d000a)
#define PR_POST_REPLY_FOLDER_NAMES (0x103e001e)
#define PR_POST_REPLY_FOLDER_NAMES_UNICODE (0x103e001f)
#define PR_POST_REPLY_FOLDER_NAMES_ERROR (0x103e000a)
#define PR_POST_REPLY_DENIED (0x103f0102)
#define PR_POST_REPLY_DENIED_ERROR (0x103f000a)
#define PR_NNTP_XREF (0x1040001e)
#define PR_NNTP_XREF_UNICODE (0x1040001f)
#define PR_NNTP_XREF_ERROR (0x1040000a)
#define PR_INTERNET_PRECEDENCE (0x1041001e)
#define PR_INTERNET_PRECEDENCE_UNICODE (0x1041001f)
#define PR_INTERNET_PRECEDENCE_ERROR (0x1041000a)
#define PR_IN_REPLY_TO_ID (0x1042001e)
#define PR_IN_REPLY_TO_ID_UNICODE (0x1042001f)
#define PR_IN_REPLY_TO_ID_ERROR (0x1042000a)
#define PR_LIST_HELP (0x1043001e)
#define PR_LIST_HELP_UNICODE (0x1043001f)
#define PR_LIST_HELP_ERROR (0x1043000a)
#define PR_LIST_SUBSCRIBE (0x1044001e)
#define PR_LIST_SUBSCRIBE_UNICODE (0x1044001f)
#define PR_LIST_SUBSCRIBE_ERROR (0x1044000a)
#define PR_LIST_UNSUBSCRIBE (0x1045001e)
#define PR_LIST_UNSUBSCRIBE_UNICODE (0x1045001f)
#define PR_LIST_UNSUBSCRIBE_ERROR (0x1045000a)
#define PR_ACTION (0x10800003)
#define PR_ACTION_ERROR (0x1080000a)
#define PR_ACTION_FLAG (0x10810003)
#define PR_ACTION_FLAG_ERROR (0x1081000a)
#define PR_ACTION_DATE (0x10820040)
#define PR_ACTION_DATE_ERROR (0x1082000a)
#define PR_FLAG_STATUS (0x10900003)
#define PR_FLAG_STATUS_ERROR (0x1090000a)
#define PR_FLAG_COMPLETE (0x10910040)
#define PR_FLAG_COMPLETE_ERROR (0x1091000a)
#define PR_SMTP_TEMP_TBL_DATA (0x10c00102)
#define PR_SMTP_TEMP_TBL_DATA_ERROR (0x10c0000a)
#define PR_SMTP_TEMP_TBL_DATA_2 (0x10c10003)
#define PR_SMTP_TEMP_TBL_DATA_2_ERROR (0x10c1000a)
#define PR_SMTP_TEMP_TBL_DATA_3 (0x10c20102)
#define PR_SMTP_TEMP_TBL_DATA_3_ERROR (0x10c2000a)
#define PR_CAL_START_TIME (0x10c30040)
#define PR_CAL_START_TIME_ERROR (0x10c3000a)
#define PR_CAL_END_TIME (0x10c40040)
#define PR_CAL_END_TIME_ERROR (0x10c4000a)
#define PR_CAL_RECURRING_ID (0x10c50040)
#define PR_CAL_RECURRING_ID_ERROR (0x10c5000a)
#define PR_DAV_SUBMIT_DATA (0x10c6001e)
#define PR_DAV_SUBMIT_DATA_UNICODE (0x10c6001f)
#define PR_DAV_SUBMIT_DATA_ERROR (0x10c6000a)
#define PR_CDO_EXPANSION_INDEX (0x10c70003)
#define PR_CDO_EXPANSION_INDEX_ERROR (0x10c7000a)
#define PR_IFS_INTERNAL_DATA (0x10c80102)
#define PR_IFS_INTERNAL_DATA_ERROR (0x10c8000a)
#define PR_CAL_REMINDER_NEXT_TIME (0x10ca0040)
#define PR_CAL_REMINDER_NEXT_TIME_ERROR (0x10ca000a)
#define PR_OWA_URL (0x10f1001e)
#define PR_OWA_URL_UNICODE (0x10f1001f)
#define PR_OWA_URL_ERROR (0x10f1000a)
#define PR_DISABLE_FULL_FIDELITY (0x10f2000b)
#define PR_DISABLE_FULL_FIDELITY_ERROR (0x10f2000a)
#define PR_URL_COMP_NAME (0x10f3001e)
#define PR_URL_COMP_NAME_UNICODE (0x10f3001f)
#define PR_URL_COMP_NAME_ERROR (0x10f3000a)
#define PR_ATTR_HIDDEN (0x10f4000b)
#define PR_ATTR_HIDDEN_ERROR (0x10f4000a)
#define PR_ATTR_SYSTEM (0x10f5000b)
#define PR_ATTR_SYSTEM_ERROR (0x10f5000a)
#define PR_ATTR_READONLY (0x10f6000b)
#define PR_ATTR_READONLY_ERROR (0x10f6000a)
#define PR_P1_CONTENT (0x11000102)
#define PR_P1_CONTENT_ERROR (0x1100000a)
#define PR_P1_CONTENT_TYPE (0x11010102)
#define PR_P1_CONTENT_TYPE_ERROR (0x1101000a)
#define PR_ROWID (0x30000003)
#define PR_ROWID_ERROR (0x3000000a)
#define PR_DISPLAY_NAME (0x3001001e)
#define PR_DISPLAY_NAME_UNICODE (0x3001001f)
#define PR_DISPLAY_NAME_ERROR (0x3001000a)
#define PR_ADDRTYPE (0x3002001e)
#define PR_ADDRTYPE_UNICODE (0x3002001f)
#define PR_ADDRTYPE_ERROR (0x3002000a)
#define PR_EMAIL_ADDRESS (0x3003001e)
#define PR_EMAIL_ADDRESS_UNICODE (0x3003001f)
#define PR_EMAIL_ADDRESS_ERROR (0x3003000a)
#define PR_COMMENT (0x3004001e)
#define PR_COMMENT_UNICODE (0x3004001f)
#define PR_COMMENT_ERROR (0x3004000a)
#define PR_DEPTH (0x30050003)
#define PR_DEPTH_ERROR (0x3005000a)
#define PR_PROVIDER_DISPLAY (0x3006001e)
#define PR_PROVIDER_DISPLAY_UNICODE (0x3006001f)
#define PR_PROVIDER_DISPLAY_ERROR (0x3006000a)
#define PR_CREATION_TIME (0x30070040)
#define PR_CREATION_TIME_ERROR (0x3007000a)
#define PR_LAST_MODIFICATION_TIME (0x30080040)
#define PR_LAST_MODIFICATION_TIME_ERROR (0x3008000a)
#define PR_RESOURCE_FLAGS (0x30090003)
#define PR_RESOURCE_FLAGS_ERROR (0x3009000a)
#define PR_PROVIDER_DLL_NAME (0x300a001e)
#define PR_PROVIDER_DLL_NAME_UNICODE (0x300a001f)
#define PR_PROVIDER_DLL_NAME_ERROR (0x300a000a)
#define PR_SEARCH_KEY (0x300b0102)
#define PR_SEARCH_KEY_ERROR (0x300b000a)
#define PR_PROVIDER_UID (0x300c0102)
#define PR_PROVIDER_UID_ERROR (0x300c000a)
#define PR_PROVIDER_ORDINAL (0x300d0003)
#define PR_PROVIDER_ORDINAL_ERROR (0x300d000a)
#define PR_FORM_VERSION (0x3301001e)
#define PR_FORM_VERSION_UNICODE (0x3301001f)
#define PR_FORM_VERSION_ERROR (0x3301000a)
#define PR_FORM_CLSID (0x33020048)
#define PR_FORM_CLSID_ERROR (0x3302000a)
#define PR_FORM_CONTACT_NAME (0x3303001e)
#define PR_FORM_CONTACT_NAME_UNICODE (0x3303001f)
#define PR_FORM_CONTACT_NAME_ERROR (0x3303000a)
#define PR_FORM_CATEGORY (0x3304001e)
#define PR_FORM_CATEGORY_UNICODE (0x3304001f)
#define PR_FORM_CATEGORY_ERROR (0x3304000a)
#define PR_FORM_CATEGORY_SUB (0x3305001e)
#define PR_FORM_CATEGORY_SUB_UNICODE (0x3305001f)
#define PR_FORM_CATEGORY_SUB_ERROR (0x3305000a)
#define PR_FORM_HOST_MAP (0x33061003)
#define PR_FORM_HOST_MAP_ERROR (0x3306000a)
#define PR_FORM_HIDDEN (0x3307000b)
#define PR_FORM_HIDDEN_ERROR (0x3307000a)
#define PR_FORM_DESIGNER_NAME (0x3308001e)
#define PR_FORM_DESIGNER_NAME_UNICODE (0x3308001f)
#define PR_FORM_DESIGNER_NAME_ERROR (0x3308000a)
#define PR_FORM_DESIGNER_GUID (0x33090048)
#define PR_FORM_DESIGNER_GUID_ERROR (0x3309000a)
#define PR_FORM_MESSAGE_BEHAVIOR (0x330a0003)
#define PR_FORM_MESSAGE_BEHAVIOR_ERROR (0x330a000a)
#define PR_DEFAULT_STORE (0x3400000b)
#define PR_DEFAULT_STORE_ERROR (0x3400000a)
#define PR_STORE_SUPPORT_MASK (0x340d0003)
#define PR_STORE_SUPPORT_MASK_ERROR (0x340d000a)
#define PR_STORE_STATE (0x340e0003)
#define PR_STORE_STATE_ERROR (0x340e000a)
#define PR_IPM_SUBTREE_SEARCH_KEY (0x34100102)
#define PR_IPM_SUBTREE_SEARCH_KEY_ERROR (0x3410000a)
#define PR_IPM_OUTBOX_SEARCH_KEY (0x34110102)
#define PR_IPM_OUTBOX_SEARCH_KEY_ERROR (0x3411000a)
#define PR_IPM_WASTEBASKET_SEARCH_KEY (0x34120102)
#define PR_IPM_WASTEBASKET_SEARCH_KEY_ERROR (0x3412000a)
#define PR_IPM_SENTMAIL_SEARCH_KEY (0x34130102)
#define PR_IPM_SENTMAIL_SEARCH_KEY_ERROR (0x3413000a)
#define PR_MDB_PROVIDER (0x34140102)
#define PR_MDB_PROVIDER_ERROR (0x3414000a)
#define PR_RECEIVE_FOLDER_SETTINGS (0x3415000d)
#define PR_RECEIVE_FOLDER_SETTINGS_ERROR (0x3415000a)
#define PR_VALID_FOLDER_MASK (0x35df0003)
#define PR_VALID_FOLDER_MASK_ERROR (0x35df000a)
#define PR_IPM_SUBTREE_ENTRYID (0x35e00102)
#define PR_IPM_SUBTREE_ENTRYID_ERROR (0x35e0000a)
#define PR_IPM_OUTBOX_ENTRYID (0x35e20102)
#define PR_IPM_OUTBOX_ENTRYID_ERROR (0x35e2000a)
#define PR_IPM_WASTEBASKET_ENTRYID (0x35e30102)
#define PR_IPM_WASTEBASKET_ENTRYID_ERROR (0x35e3000a)
#define PR_IPM_SENTMAIL_ENTRYID (0x35e40102)
#define PR_IPM_SENTMAIL_ENTRYID_ERROR (0x35e4000a)
#define PR_VIEWS_ENTRYID (0x35e50102)
#define PR_VIEWS_ENTRYID_ERROR (0x35e5000a)
#define PR_COMMON_VIEWS_ENTRYID (0x35e60102)
#define PR_COMMON_VIEWS_ENTRYID_ERROR (0x35e6000a)
#define PR_FINDER_ENTRYID (0x35e70102)
#define PR_FINDER_ENTRYID_ERROR (0x35e7000a)
#define PR_CONTAINER_FLAGS (0x36000003)
#define PR_CONTAINER_FLAGS_ERROR (0x3600000a)
#define PR_FOLDER_TYPE (0x36010003)
#define PR_FOLDER_TYPE_ERROR (0x3601000a)
#define PR_CONTENT_COUNT (0x36020003)
#define PR_CONTENT_COUNT_ERROR (0x3602000a)
#define PR_CONTENT_UNREAD (0x36030003)
#define PR_CONTENT_UNREAD_ERROR (0x3603000a)
#define PR_CREATE_TEMPLATES (0x3604000d)
#define PR_CREATE_TEMPLATES_ERROR (0x3604000a)
#define PR_DETAILS_TABLE (0x3605000d)
#define PR_DETAILS_TABLE_ERROR (0x3605000a)
#define PR_SEARCH (0x3607000d)
#define PR_SEARCH_ERROR (0x3607000a)
#define PR_SELECTABLE (0x3609000b)
#define PR_SELECTABLE_ERROR (0x3609000a)
#define PR_SUBFOLDERS (0x360a000b)
#define PR_SUBFOLDERS_ERROR (0x360a000a)
#define PR_STATUS (0x360b0003)
#define PR_STATUS_ERROR (0x360b000a)
#define PR_ANR (0x360c001e)
#define PR_ANR_UNICODE (0x360c001f)
#define PR_ANR_ERROR (0x360c000a)
#define PR_CONTENTS_SORT_ORDER (0x360d1003)
#define PR_CONTENTS_SORT_ORDER_ERROR (0x360d000a)
#define PR_CONTAINER_HIERARCHY (0x360e000d)
#define PR_CONTAINER_HIERARCHY_ERROR (0x360e000a)
#define PR_CONTAINER_CONTENTS (0x360f000d)
#define PR_CONTAINER_CONTENTS_ERROR (0x360f000a)
#define PR_FOLDER_ASSOCIATED_CONTENTS (0x3610000d)
#define PR_FOLDER_ASSOCIATED_CONTENTS_ERROR (0x3610000a)
#define PR_DEF_CREATE_DL (0x36110102)
#define PR_DEF_CREATE_DL_ERROR (0x3611000a)
#define PR_DEF_CREATE_MAILUSER (0x36120102)
#define PR_DEF_CREATE_MAILUSER_ERROR (0x3612000a)
#define PR_CONTAINER_CLASS (0x3613001e)
#define PR_CONTAINER_CLASS_UNICODE (0x3613001f)
#define PR_CONTAINER_CLASS_ERROR (0x3613000a)
#define PR_CONTAINER_MODIFY_VERSION (0x36140014)
#define PR_CONTAINER_MODIFY_VERSION_ERROR (0x3614000a)
#define PR_AB_PROVIDER_ID (0x36150102)
#define PR_AB_PROVIDER_ID_ERROR (0x3615000a)
#define PR_DEFAULT_VIEW_ENTRYID (0x36160102)
#define PR_DEFAULT_VIEW_ENTRYID_ERROR (0x3616000a)
#define PR_ASSOC_CONTENT_COUNT (0x36170003)
#define PR_ASSOC_CONTENT_COUNT_ERROR (0x3617000a)
#define PR_PACKED_NAME_PROPS (0x361c0102)
#define PR_PACKED_NAME_PROPS_ERROR (0x361c000a)
#define PR_IPM_APPOINTMENT_ENTRYID (0x36d00102)
#define PR_IPM_APPOINTMENT_ENTRYID_ERROR (0x36d0000a)
#define PR_IPM_CONTACT_ENTRYID (0x36d10102)
#define PR_IPM_CONTACT_ENTRYID_ERROR (0x36d1000a)
#define PR_IPM_JOURNAL_ENTRYID (0x36d20102)
#define PR_IPM_JOURNAL_ENTRYID_ERROR (0x36d2000a)
#define PR_IPM_NOTE_ENTRYID (0x36d30102)
#define PR_IPM_NOTE_ENTRYID_ERROR (0x36d3000a)
#define PR_IPM_TASK_ENTRYID (0x36d40102)
#define PR_IPM_TASK_ENTRYID_ERROR (0x36d4000a)
#define PR_REMINDERS_ONLINE_ENTRYID (0x36d50102)
#define PR_REMINDERS_ONLINE_ENTRYID_ERROR (0x36d5000a)
#define PR_REMINDERS_OFFLINE_ENTRYID (0x36d60102)
#define PR_REMINDERS_OFFLINE_ENTRYID_ERROR (0x36d6000a)
#define PR_IPM_DRAFTS_ENTRYID (0x36d70102)
#define PR_IPM_DRAFTS_ENTRYID_ERROR (0x36d7000a)
#define PR_OUTLOOK_2003_ENTRYIDS (0x36d81102)
#define PR_OUTLOOK_2003_ENTRYIDS_ERROR (0x36d8000a)
#define PR_FOLDER_WEBVIEWINFO (0x36df0102)
#define PR_FOLDER_WEBVIEWINFO_ERROR (0x36df000a)
#define PR_FOLDER_XVIEWINFO_E (0x36e00102)
#define PR_FOLDER_XVIEWINFO_E_ERROR (0x36e0000a)
#define PR_FOLDER_VIEWS_ONLY (0x36e10003)
#define PR_FOLDER_VIEWS_ONLY_ERROR (0x36e1000a)
#define PR_FREEBUSY_ENTRYIDS (0x36e41102)
#define PR_FREEBUSY_ENTRYIDS_ERROR (0x36e4000a)
#define PR_DEF_MSG_CLASS (0x36e5001e)
#define PR_DEF_MSG_CLASS_UNICODE (0x36e5001f)
#define PR_DEF_MSG_CLASS_ERROR (0x36e5000a)
#define PR_DEF_FORM_NAME (0x36e6001e)
#define PR_DEF_FORM_NAME_UNICODE (0x36e6001f)
#define PR_DEF_FORM_NAME_ERROR (0x36e6000a)
#define PR_GENERATE_EXCHANGE_VIEWS (0x36e9000b)
#define PR_GENERATE_EXCHANGE_VIEWS_ERROR (0x36e9000a)
#define PR_AGING_PERIOD (0x36ec0003)
#define PR_AGING_PERIOD_ERROR (0x36ec000a)
#define PR_AGING_GRANULARITY (0x36ee0003)
#define PR_AGING_GRANULARITY_ERROR (0x36ee000a)
#define PR_ATTACHMENT_X400_PARAMETERS (0x37000102)
#define PR_ATTACHMENT_X400_PARAMETERS_ERROR (0x3700000a)
#define PR_ATTACH_DATA_OBJ (0x3701000d)
#define PR_ATTACH_DATA_OBJ_ERROR (0x3701000a)
#define PR_ATTACH_DATA_BIN (0x37010102)
#define PR_ATTACH_ENCODING (0x37020102)
#define PR_ATTACH_ENCODING_ERROR (0x3702000a)
#define PR_ATTACH_EXTENSION (0x3703001e)
#define PR_ATTACH_EXTENSION_UNICODE (0x3703001f)
#define PR_ATTACH_EXTENSION_ERROR (0x3703000a)
#define PR_ATTACH_FILENAME (0x3704001e)
#define PR_ATTACH_FILENAME_UNICODE (0x3704001f)
#define PR_ATTACH_FILENAME_ERROR (0x3704000a)
#define PR_ATTACH_METHOD (0x37050003)
#define PR_ATTACH_METHOD_ERROR (0x3705000a)
#define PR_ATTACH_LONG_FILENAME (0x3707001e)
#define PR_ATTACH_LONG_FILENAME_UNICODE (0x3707001f)
#define PR_ATTACH_LONG_FILENAME_ERROR (0x3707000a)
#define PR_ATTACH_PATHNAME (0x3708001e)
#define PR_ATTACH_PATHNAME_UNICODE (0x3708001f)
#define PR_ATTACH_PATHNAME_ERROR (0x3708000a)
#define PR_ATTACH_RENDERING (0x37090102)
#define PR_ATTACH_RENDERING_ERROR (0x3709000a)
#define PR_ATTACH_TAG (0x370a0102)
#define PR_ATTACH_TAG_ERROR (0x370a000a)
#define PR_RENDERING_POSITION (0x370b0003)
#define PR_RENDERING_POSITION_ERROR (0x370b000a)
#define PR_ATTACH_TRANSPORT_NAME (0x370c001e)
#define PR_ATTACH_TRANSPORT_NAME_UNICODE (0x370c001f)
#define PR_ATTACH_TRANSPORT_NAME_ERROR (0x370c000a)
#define PR_ATTACH_LONG_PATHNAME (0x370d001e)
#define PR_ATTACH_LONG_PATHNAME_UNICODE (0x370d001f)
#define PR_ATTACH_LONG_PATHNAME_ERROR (0x370d000a)
#define PR_ATTACH_MIME_TAG (0x370e001e)
#define PR_ATTACH_MIME_TAG_UNICODE (0x370e001f)
#define PR_ATTACH_MIME_TAG_ERROR (0x370e000a)
#define PR_ATTACH_ADDITIONAL_INFO (0x370f0102)
#define PR_ATTACH_ADDITIONAL_INFO_ERROR (0x370f000a)
#define PR_ATTACH_CONTENT_ID (0x3712001e)
#define PR_ATTACH_CONTENT_ID_UNICODE (0x3712001f)
#define PR_ATTACH_CONTENT_ID_ERROR (0x3712000a)
#define PR_ATTACH_CONTENT_LOCATION (0x3713001e)
#define PR_ATTACH_CONTENT_LOCATION_UNICODE (0x3713001f)
#define PR_ATTACH_CONTENT_LOCATION_ERROR (0x3713000a)
#define PR_ATTACH_FLAGS (0x37140003)
#define PR_ATTACH_FLAGS_ERROR (0x3714000a)
#define PR_ATTACH_CONTENT_DISPOSITION (0x3716001e)
#define PR_ATTACH_CONTENT_DISPOSITION_UNICODE (0x3716001f)
#define PR_ATTACH_CONTENT_DISPOSITION_ERROR (0x3716000a)
#define PR_SYNCEVENT_SUPPRESS_GUID (0x38800102)
#define PR_SYNCEVENT_SUPPRESS_GUID_ERROR (0x3880000a)
#define PR_DISPLAY_TYPE (0x39000003)
#define PR_DISPLAY_TYPE_ERROR (0x3900000a)
#define PR_TEMPLATEID (0x39020102)
#define PR_TEMPLATEID_ERROR (0x3902000a)
#define PR_PRIMARY_CAPABILITY (0x39040102)
#define PR_PRIMARY_CAPABILITY_ERROR (0x3904000a)
#define PR_SMTP_ADDRESS (0x39fe001e)
#define PR_SMTP_ADDRESS_UNICODE (0x39fe001f)
#define PR_SMTP_ADDRESS_ERROR (0x39fe000a)
#define PR_7BIT_DISPLAY_NAME (0x39ff001e)
#define PR_7BIT_DISPLAY_NAME_UNICODE (0x39ff001f)
#define PR_7BIT_DISPLAY_NAME_ERROR (0x39ff000a)
#define PR_ACCOUNT (0x3a00001e)
#define PR_ACCOUNT_UNICODE (0x3a00001f)
#define PR_ACCOUNT_ERROR (0x3a00000a)
#define PR_ALTERNATE_RECIPIENT (0x3a010102)
#define PR_ALTERNATE_RECIPIENT_ERROR (0x3a01000a)
#define PR_CALLBACK_TELEPHONE_NUMBER (0x3a02001e)
#define PR_CALLBACK_TELEPHONE_NUMBER_UNICODE (0x3a02001f)
#define PR_CALLBACK_TELEPHONE_NUMBER_ERROR (0x3a02000a)
#define PR_CONVERSION_PROHIBITED (0x3a03000b)
#define PR_CONVERSION_PROHIBITED_ERROR (0x3a03000a)
#define PR_DISCLOSE_RECIPIENTS (0x3a04000b)
#define PR_DISCLOSE_RECIPIENTS_ERROR (0x3a04000a)
#define PR_GENERATION (0x3a05001e)
#define PR_GENERATION_UNICODE (0x3a05001f)
#define PR_GENERATION_ERROR (0x3a05000a)
#define PR_GIVEN_NAME (0x3a06001e)
#define PR_GIVEN_NAME_UNICODE (0x3a06001f)
#define PR_GIVEN_NAME_ERROR (0x3a06000a)
#define PR_GOVERNMENT_ID_NUMBER (0x3a07001e)
#define PR_GOVERNMENT_ID_NUMBER_UNICODE (0x3a07001f)
#define PR_GOVERNMENT_ID_NUMBER_ERROR (0x3a07000a)
#define PR_OFFICE_TELEPHONE_NUMBER (0x3a08001e)
#define PR_OFFICE_TELEPHONE_NUMBER_UNICODE (0x3a08001f)
#define PR_OFFICE_TELEPHONE_NUMBER_ERROR (0x3a08000a)
#define PR_HOME_TELEPHONE_NUMBER (0x3a09001e)
#define PR_HOME_TELEPHONE_NUMBER_UNICODE (0x3a09001f)
#define PR_HOME_TELEPHONE_NUMBER_ERROR (0x3a09000a)
#define PR_INITIALS (0x3a0a001e)
#define PR_INITIALS_UNICODE (0x3a0a001f)
#define PR_INITIALS_ERROR (0x3a0a000a)
#define PR_KEYWORD (0x3a0b001e)
#define PR_KEYWORD_UNICODE (0x3a0b001f)
#define PR_KEYWORD_ERROR (0x3a0b000a)
#define PR_LANGUAGE (0x3a0c001e)
#define PR_LANGUAGE_UNICODE (0x3a0c001f)
#define PR_LANGUAGE_ERROR (0x3a0c000a)
#define PR_LOCATION (0x3a0d001e)
#define PR_LOCATION_UNICODE (0x3a0d001f)
#define PR_LOCATION_ERROR (0x3a0d000a)
#define PR_MAIL_PERMISSION (0x3a0e000b)
#define PR_MAIL_PERMISSION_ERROR (0x3a0e000a)
#define PR_MHS_COMMON_NAME (0x3a0f001e)
#define PR_MHS_COMMON_NAME_UNICODE (0x3a0f001f)
#define PR_MHS_COMMON_NAME_ERROR (0x3a0f000a)
#define PR_ORGANIZATIONAL_ID_NUMBER (0x3a10001e)
#define PR_ORGANIZATIONAL_ID_NUMBER_UNICODE (0x3a10001f)
#define PR_ORGANIZATIONAL_ID_NUMBER_ERROR (0x3a10000a)
#define PR_SURNAME (0x3a11001e)
#define PR_SURNAME_UNICODE (0x3a11001f)
#define PR_SURNAME_ERROR (0x3a11000a)
#define PR_ORIGINAL_ENTRYID (0x3a120102)
#define PR_ORIGINAL_ENTRYID_ERROR (0x3a12000a)
#define PR_ORIGINAL_DISPLAY_NAME (0x3a13001e)
#define PR_ORIGINAL_DISPLAY_NAME_UNICODE (0x3a13001f)
#define PR_ORIGINAL_DISPLAY_NAME_ERROR (0x3a13000a)
#define PR_ORIGINAL_SEARCH_KEY (0x3a140102)
#define PR_ORIGINAL_SEARCH_KEY_ERROR (0x3a14000a)
#define PR_POSTAL_ADDRESS (0x3a15001e)
#define PR_POSTAL_ADDRESS_UNICODE (0x3a15001f)
#define PR_POSTAL_ADDRESS_ERROR (0x3a15000a)
#define PR_COMPANY_NAME (0x3a16001e)
#define PR_COMPANY_NAME_UNICODE (0x3a16001f)
#define PR_COMPANY_NAME_ERROR (0x3a16000a)
#define PR_TITLE (0x3a17001e)
#define PR_TITLE_UNICODE (0x3a17001f)
#define PR_TITLE_ERROR (0x3a17000a)
#define PR_DEPARTMENT_NAME (0x3a18001e)
#define PR_DEPARTMENT_NAME_UNICODE (0x3a18001f)
#define PR_DEPARTMENT_NAME_ERROR (0x3a18000a)
#define PR_OFFICE_LOCATION (0x3a19001e)
#define PR_OFFICE_LOCATION_UNICODE (0x3a19001f)
#define PR_OFFICE_LOCATION_ERROR (0x3a19000a)
#define PR_PRIMARY_TELEPHONE_NUMBER (0x3a1a001e)
#define PR_PRIMARY_TELEPHONE_NUMBER_UNICODE (0x3a1a001f)
#define PR_PRIMARY_TELEPHONE_NUMBER_ERROR (0x3a1a000a)
#define PR_OFFICE2_TELEPHONE_NUMBER (0x3a1b001e)
#define PR_OFFICE2_TELEPHONE_NUMBER_UNICODE (0x3a1b001f)
#define PR_OFFICE2_TELEPHONE_NUMBER_ERROR (0x3a1b000a)
#define PR_MOBILE_TELEPHONE_NUMBER (0x3a1c001e)
#define PR_MOBILE_TELEPHONE_NUMBER_UNICODE (0x3a1c001f)
#define PR_MOBILE_TELEPHONE_NUMBER_ERROR (0x3a1c000a)
#define PR_RADIO_TELEPHONE_NUMBER (0x3a1d001e)
#define PR_RADIO_TELEPHONE_NUMBER_UNICODE (0x3a1d001f)
#define PR_RADIO_TELEPHONE_NUMBER_ERROR (0x3a1d000a)
#define PR_CAR_TELEPHONE_NUMBER (0x3a1e001e)
#define PR_CAR_TELEPHONE_NUMBER_UNICODE (0x3a1e001f)
#define PR_CAR_TELEPHONE_NUMBER_ERROR (0x3a1e000a)
#define PR_OTHER_TELEPHONE_NUMBER (0x3a1f001e)
#define PR_OTHER_TELEPHONE_NUMBER_UNICODE (0x3a1f001f)
#define PR_OTHER_TELEPHONE_NUMBER_ERROR (0x3a1f000a)
#define PR_TRANSMITTABLE_DISPLAY_NAME (0x3a20001e)
#define PR_TRANSMITTABLE_DISPLAY_NAME_UNICODE (0x3a20001f)
#define PR_TRANSMITTABLE_DISPLAY_NAME_ERROR (0x3a20000a)
#define PR_PAGER_TELEPHONE_NUMBER (0x3a21001e)
#define PR_PAGER_TELEPHONE_NUMBER_UNICODE (0x3a21001f)
#define PR_PAGER_TELEPHONE_NUMBER_ERROR (0x3a21000a)
#define PR_USER_CERTIFICATE (0x3a220102)
#define PR_USER_CERTIFICATE_ERROR (0x3a22000a)
#define PR_PRIMARY_FAX_NUMBER (0x3a23001e)
#define PR_PRIMARY_FAX_NUMBER_UNICODE (0x3a23001f)
#define PR_PRIMARY_FAX_NUMBER_ERROR (0x3a23000a)
#define PR_HOME_FAX_NUMBER (0x3a25001e)
#define PR_HOME_FAX_NUMBER_UNICODE (0x3a25001f)
#define PR_HOME_FAX_NUMBER_ERROR (0x3a25000a)
#define PR_COUNTRY (0x3a26001e)
#define PR_COUNTRY_UNICODE (0x3a26001f)
#define PR_COUNTRY_ERROR (0x3a26000a)
#define PR_LOCALITY (0x3a27001e)
#define PR_LOCALITY_UNICODE (0x3a27001f)
#define PR_LOCALITY_ERROR (0x3a27000a)
#define PR_STATE_OR_PROVINCE (0x3a28001e)
#define PR_STATE_OR_PROVINCE_UNICODE (0x3a28001f)
#define PR_STATE_OR_PROVINCE_ERROR (0x3a28000a)
#define PR_STREET_ADDRESS (0x3a29001e)
#define PR_STREET_ADDRESS_UNICODE (0x3a29001f)
#define PR_STREET_ADDRESS_ERROR (0x3a29000a)
#define PR_POSTAL_CODE (0x3a2a001e)
#define PR_POSTAL_CODE_UNICODE (0x3a2a001f)
#define PR_POSTAL_CODE_ERROR (0x3a2a000a)
#define PR_POST_OFFICE_BOX (0x3a2b001e)
#define PR_POST_OFFICE_BOX_UNICODE (0x3a2b001f)
#define PR_POST_OFFICE_BOX_ERROR (0x3a2b000a)
#define PR_TELEX_NUMBER (0x3a2c001e)
#define PR_TELEX_NUMBER_UNICODE (0x3a2c001f)
#define PR_TELEX_NUMBER_ERROR (0x3a2c000a)
#define PR_ISDN_NUMBER (0x3a2d001e)
#define PR_ISDN_NUMBER_UNICODE (0x3a2d001f)
#define PR_ISDN_NUMBER_ERROR (0x3a2d000a)
#define PR_ASSISTANT_TELEPHONE_NUMBER (0x3a2e001e)
#define PR_ASSISTANT_TELEPHONE_NUMBER_UNICODE (0x3a2e001f)
#define PR_ASSISTANT_TELEPHONE_NUMBER_ERROR (0x3a2e000a)
#define PR_HOME2_TELEPHONE_NUMBER (0x3a2f001e)
#define PR_HOME2_TELEPHONE_NUMBER_UNICODE (0x3a2f001f)
#define PR_HOME2_TELEPHONE_NUMBER_ERROR (0x3a2f000a)
#define PR_ASSISTANT (0x3a30001e)
#define PR_ASSISTANT_UNICODE (0x3a30001f)
#define PR_ASSISTANT_ERROR (0x3a30000a)
#define PR_SEND_RICH_INFO (0x3a40000b)
#define PR_SEND_RICH_INFO_ERROR (0x3a40000a)
#define PR_WEDDING_ANNIVERSARY (0x3a410040)
#define PR_WEDDING_ANNIVERSARY_ERROR (0x3a41000a)
#define PR_BIRTHDAY (0x3a420040)
#define PR_BIRTHDAY_ERROR (0x3a42000a)
#define PR_HOBBIES (0x3a43001e)
#define PR_HOBBIES_UNICODE (0x3a43001f)
#define PR_HOBBIES_ERROR (0x3a43000a)
#define PR_MIDDLE_NAME (0x3a44001e)
#define PR_MIDDLE_NAME_UNICODE (0x3a44001f)
#define PR_MIDDLE_NAME_ERROR (0x3a44000a)
#define PR_DISPLAY_NAME_PREFIX (0x3a45001e)
#define PR_DISPLAY_NAME_PREFIX_UNICODE (0x3a45001f)
#define PR_DISPLAY_NAME_PREFIX_ERROR (0x3a45000a)
#define PR_PROFESSION (0x3a46001e)
#define PR_PROFESSION_UNICODE (0x3a46001f)
#define PR_PROFESSION_ERROR (0x3a46000a)
#define PR_PREFERRED_BY_NAME (0x3a47001e)
#define PR_PREFERRED_BY_NAME_UNICODE (0x3a47001f)
#define PR_PREFERRED_BY_NAME_ERROR (0x3a47000a)
#define PR_SPOUSE_NAME (0x3a48001e)
#define PR_SPOUSE_NAME_UNICODE (0x3a48001f)
#define PR_SPOUSE_NAME_ERROR (0x3a48000a)
#define PR_COMPUTER_NETWORK_NAME (0x3a49001e)
#define PR_COMPUTER_NETWORK_NAME_UNICODE (0x3a49001f)
#define PR_COMPUTER_NETWORK_NAME_ERROR (0x3a49000a)
#define PR_CUSTOMER_ID (0x3a4a001e)
#define PR_CUSTOMER_ID_UNICODE (0x3a4a001f)
#define PR_CUSTOMER_ID_ERROR (0x3a4a000a)
#define PR_TTYTDD_PHONE_NUMBER (0x3a4b001e)
#define PR_TTYTDD_PHONE_NUMBER_UNICODE (0x3a4b001f)
#define PR_TTYTDD_PHONE_NUMBER_ERROR (0x3a4b000a)
#define PR_FTP_SITE (0x3a4c001e)
#define PR_FTP_SITE_UNICODE (0x3a4c001f)
#define PR_FTP_SITE_ERROR (0x3a4c000a)
#define PR_GENDER (0x3a4d0002)
#define PR_GENDER_ERROR (0x3a4d000a)
#define PR_MANAGER_NAME (0x3a4e001e)
#define PR_MANAGER_NAME_UNICODE (0x3a4e001f)
#define PR_MANAGER_NAME_ERROR (0x3a4e000a)
#define PR_NICKNAME (0x3a4f001e)
#define PR_NICKNAME_UNICODE (0x3a4f001f)
#define PR_NICKNAME_ERROR (0x3a4f000a)
#define PR_PERSONAL_HOME_PAGE (0x3a50001e)
#define PR_PERSONAL_HOME_PAGE_UNICODE (0x3a50001f)
#define PR_PERSONAL_HOME_PAGE_ERROR (0x3a50000a)
#define PR_BUSINESS_HOME_PAGE (0x3a51001e)
#define PR_BUSINESS_HOME_PAGE_UNICODE (0x3a51001f)
#define PR_BUSINESS_HOME_PAGE_ERROR (0x3a51000a)
#define PR_CONTACT_VERSION (0x3a520048)
#define PR_CONTACT_VERSION_ERROR (0x3a52000a)
#define PR_CONTACT_ENTRYIDS (0x3a531102)
#define PR_CONTACT_ENTRYIDS_ERROR (0x3a53000a)
#define PR_CONTACT_ADDRTYPES (0x3a54101e)
#define PR_CONTACT_ADDRTYPES_UNICODE (0x3a54101f)
#define PR_CONTACT_ADDRTYPES_ERROR (0x3a54000a)
#define PR_CONTACT_DEFAULT_ADDRESS_INDEX (0x3a550003)
#define PR_CONTACT_DEFAULT_ADDRESS_INDEX_ERROR (0x3a55000a)
#define PR_CONTACT_EMAIL_ADDRESSES (0x3a56101e)
#define PR_CONTACT_EMAIL_ADDRESSES_UNICODE (0x3a56101f)
#define PR_CONTACT_EMAIL_ADDRESSES_ERROR (0x3a56000a)
#define PR_COMPANY_MAIN_PHONE_NUMBER (0x3a57001e)
#define PR_COMPANY_MAIN_PHONE_NUMBER_UNICODE (0x3a57001f)
#define PR_COMPANY_MAIN_PHONE_NUMBER_ERROR (0x3a57000a)
#define PR_CHILDRENS_NAMES (0x3a58101e)
#define PR_CHILDRENS_NAMES_UNICODE (0x3a58101f)
#define PR_CHILDRENS_NAMES_ERROR (0x3a58000a)
#define PR_HOME_ADDRESS_CITY (0x3a59001e)
#define PR_HOME_ADDRESS_CITY_UNICODE (0x3a59001f)
#define PR_HOME_ADDRESS_CITY_ERROR (0x3a59000a)
#define PR_HOME_ADDRESS_COUNTRY (0x3a5a001e)
#define PR_HOME_ADDRESS_COUNTRY_UNICODE (0x3a5a001f)
#define PR_HOME_ADDRESS_COUNTRY_ERROR (0x3a5a000a)
#define PR_HOME_ADDRESS_POSTAL_CODE (0x3a5b001e)
#define PR_HOME_ADDRESS_POSTAL_CODE_UNICODE (0x3a5b001f)
#define PR_HOME_ADDRESS_POSTAL_CODE_ERROR (0x3a5b000a)
#define PR_HOME_ADDRESS_STATE_OR_PROVINCE (0x3a5c001e)
#define PR_HOME_ADDRESS_STATE_OR_PROVINCE_UNICODE (0x3a5c001f)
#define PR_HOME_ADDRESS_STATE_OR_PROVINCE_ERROR (0x3a5c000a)
#define PR_HOME_ADDRESS_STREET (0x3a5d001e)
#define PR_HOME_ADDRESS_STREET_UNICODE (0x3a5d001f)
#define PR_HOME_ADDRESS_STREET_ERROR (0x3a5d000a)
#define PR_HOME_ADDRESS_POST_OFFICE_BOX (0x3a5e001e)
#define PR_HOME_ADDRESS_POST_OFFICE_BOX_UNICODE (0x3a5e001f)
#define PR_HOME_ADDRESS_POST_OFFICE_BOX_ERROR (0x3a5e000a)
#define PR_OTHER_ADDRESS_CITY (0x3a5f001e)
#define PR_OTHER_ADDRESS_CITY_UNICODE (0x3a5f001f)
#define PR_OTHER_ADDRESS_CITY_ERROR (0x3a5f000a)
#define PR_OTHER_ADDRESS_COUNTRY (0x3a60001e)
#define PR_OTHER_ADDRESS_COUNTRY_UNICODE (0x3a60001f)
#define PR_OTHER_ADDRESS_COUNTRY_ERROR (0x3a60000a)
#define PR_OTHER_ADDRESS_POSTAL_CODE (0x3a61001e)
#define PR_OTHER_ADDRESS_POSTAL_CODE_UNICODE (0x3a61001f)
#define PR_OTHER_ADDRESS_POSTAL_CODE_ERROR (0x3a61000a)
#define PR_OTHER_ADDRESS_STATE_OR_PROVINCE (0x3a62001e)
#define PR_OTHER_ADDRESS_STATE_OR_PROVINCE_UNICODE (0x3a62001f)
#define PR_OTHER_ADDRESS_STATE_OR_PROVINCE_ERROR (0x3a62000a)
#define PR_OTHER_ADDRESS_STREET (0x3a63001e)
#define PR_OTHER_ADDRESS_STREET_UNICODE (0x3a63001f)
#define PR_OTHER_ADDRESS_STREET_ERROR (0x3a63000a)
#define PR_OTHER_ADDRESS_POST_OFFICE_BOX (0x3a64001e)
#define PR_OTHER_ADDRESS_POST_OFFICE_BOX_UNICODE (0x3a64001f)
#define PR_OTHER_ADDRESS_POST_OFFICE_BOX_ERROR (0x3a64000a)
#define PR_USER_X509_CERTIFICATE (0x3a701102)
#define PR_USER_X509_CERTIFICATE_ERROR (0x3a70000a)
#define PR_SEND_INTERNET_ENCODING (0x3a710003)
#define PR_SEND_INTERNET_ENCODING_ERROR (0x3a71000a)
#define PR_STORE_PROVIDERS (0x3d000102)
#define PR_STORE_PROVIDERS_ERROR (0x3d00000a)
#define PR_AB_PROVIDERS (0x3d010102)
#define PR_AB_PROVIDERS_ERROR (0x3d01000a)
#define PR_TRANSPORT_PROVIDERS (0x3d020102)
#define PR_TRANSPORT_PROVIDERS_ERROR (0x3d02000a)
#define PR_DEFAULT_PROFILE (0x3d04000b)
#define PR_DEFAULT_PROFILE_ERROR (0x3d04000a)
#define PR_AB_SEARCH_PATH (0x3d051102)
#define PR_AB_SEARCH_PATH_ERROR (0x3d05000a)
#define PR_AB_DEFAULT_DIR (0x3d060102)
#define PR_AB_DEFAULT_DIR_ERROR (0x3d06000a)
#define PR_AB_DEFAULT_PAB (0x3d070102)
#define PR_AB_DEFAULT_PAB_ERROR (0x3d07000a)
#define PR_FILTERING_HOOKS (0x3d080102)
#define PR_FILTERING_HOOKS_ERROR (0x3d08000a)
#define PR_SERVICE_NAME (0x3d09001e)
#define PR_SERVICE_NAME_UNICODE (0x3d09001f)
#define PR_SERVICE_NAME_ERROR (0x3d09000a)
#define PR_SERVICE_DLL_NAME (0x3d0a001e)
#define PR_SERVICE_DLL_NAME_UNICODE (0x3d0a001f)
#define PR_SERVICE_DLL_NAME_ERROR (0x3d0a000a)
#define PR_SERVICE_ENTRY_NAME (0x3d0b001e)
#define PR_SERVICE_ENTRY_NAME_UNICODE (0x3d0b001f)
#define PR_SERVICE_ENTRY_NAME_ERROR (0x3d0b000a)
#define PR_SERVICE_UID (0x3d0c0102)
#define PR_SERVICE_UID_ERROR (0x3d0c000a)
#define PR_SERVICE_EXTRA_UIDS (0x3d0d0102)
#define PR_SERVICE_EXTRA_UIDS_ERROR (0x3d0d000a)
#define PR_SERVICES (0x3d0e0102)
#define PR_SERVICES_ERROR (0x3d0e000a)
#define PR_SERVICE_SUPPORT_FILES (0x3d0f101e)
#define PR_SERVICE_SUPPORT_FILES_UNICODE (0x3d0f101f)
#define PR_SERVICE_SUPPORT_FILES_ERROR (0x3d0f000a)
#define PR_SERVICE_DELETE_FILES (0x3d10101e)
#define PR_SERVICE_DELETE_FILES_UNICODE (0x3d10101f)
#define PR_SERVICE_DELETE_FILES_ERROR (0x3d10000a)
#define PR_AB_SEARCH_PATH_UPDATE (0x3d110102)
#define PR_AB_SEARCH_PATH_UPDATE_ERROR (0x3d11000a)
#define PR_PROFILE_NAME (0x3d12001e)
#define PR_PROFILE_NAME_UNICODE (0x3d12001f)
#define PR_PROFILE_NAME_ERROR (0x3d12000a)
#define PR_SERVICE_INSTALL_ID (0x3d13001e)
#define PR_SERVICE_INSTALL_ID_UNICODE (0x3d13001f)
#define PR_SERVICE_INSTALL_ID_ERROR (0x3d13000a)
#define PR_ADMIN_SECURITY_DESCRIPTOR (0x3d210102)
#define PR_ADMIN_SECURITY_DESCRIPTOR_ERROR (0x3d21000a)
#define PR_IDENTITY_DISPLAY (0x3e00001e)
#define PR_IDENTITY_DISPLAY_UNICODE (0x3e00001f)
#define PR_IDENTITY_DISPLAY_ERROR (0x3e00000a)
#define PR_IDENTITY_ENTRYID (0x3e010102)
#define PR_IDENTITY_ENTRYID_ERROR (0x3e01000a)
#define PR_RESOURCE_METHODS (0x3e020003)
#define PR_RESOURCE_METHODS_ERROR (0x3e02000a)
#define PR_RESOURCE_TYPE (0x3e030003)
#define PR_RESOURCE_TYPE_ERROR (0x3e03000a)
#define PR_STATUS_CODE (0x3e040003)
#define PR_STATUS_CODE_ERROR (0x3e04000a)
#define PR_IDENTITY_SEARCH_KEY (0x3e050102)
#define PR_IDENTITY_SEARCH_KEY_ERROR (0x3e05000a)
#define PR_OWN_STORE_ENTRYID (0x3e060102)
#define PR_OWN_STORE_ENTRYID_ERROR (0x3e06000a)
#define PR_RESOURCE_PATH (0x3e07001e)
#define PR_RESOURCE_PATH_UNICODE (0x3e07001f)
#define PR_RESOURCE_PATH_ERROR (0x3e07000a)
#define PR_STATUS_STRING (0x3e08001e)
#define PR_STATUS_STRING_UNICODE (0x3e08001f)
#define PR_STATUS_STRING_ERROR (0x3e08000a)
#define PR_X400_DEFERRED_DELIVERY_CANCEL (0x3e09000b)
#define PR_X400_DEFERRED_DELIVERY_CANCEL_ERROR (0x3e09000a)
#define PR_HEADER_FOLDER_ENTRYID (0x3e0a0102)
#define PR_HEADER_FOLDER_ENTRYID_ERROR (0x3e0a000a)
#define PR_REMOTE_PROGRESS (0x3e0b0003)
#define PR_REMOTE_PROGRESS_ERROR (0x3e0b000a)
#define PR_REMOTE_PROGRESS_TEXT (0x3e0c001e)
#define PR_REMOTE_PROGRESS_TEXT_UNICODE (0x3e0c001f)
#define PR_REMOTE_PROGRESS_TEXT_ERROR (0x3e0c000a)
#define PR_REMOTE_VALIDATE_OK (0x3e0d000b)
#define PR_REMOTE_VALIDATE_OK_ERROR (0x3e0d000a)
#define PR_CONTROL_FLAGS (0x3f000003)
#define PR_CONTROL_FLAGS_ERROR (0x3f00000a)
#define PR_CONTROL_STRUCTURE (0x3f010102)
#define PR_CONTROL_STRUCTURE_ERROR (0x3f01000a)
#define PR_CONTROL_TYPE (0x3f020003)
#define PR_CONTROL_TYPE_ERROR (0x3f02000a)
#define PR_DELTAX (0x3f030003)
#define PR_DELTAX_ERROR (0x3f03000a)
#define PR_DELTAY (0x3f040003)
#define PR_DELTAY_ERROR (0x3f04000a)
#define PR_XPOS (0x3f050003)
#define PR_XPOS_ERROR (0x3f05000a)
#define PR_YPOS (0x3f060003)
#define PR_YPOS_ERROR (0x3f06000a)
#define PR_CONTROL_ID (0x3f070102)
#define PR_CONTROL_ID_ERROR (0x3f07000a)
#define PR_INITIAL_DETAILS_PANE (0x3f080003)
#define PR_INITIAL_DETAILS_PANE_ERROR (0x3f08000a)
#define PR_DID (0x3f800014)
#define PR_DID_ERROR (0x3f80000a)
#define PR_SEQID (0x3f810014)
#define PR_SEQID_ERROR (0x3f81000a)
#define PR_DRAFTID (0x3f820014)
#define PR_DRAFTID_ERROR (0x3f82000a)
#define PR_CHECK_IN_TIME (0x3f830040)
#define PR_CHECK_IN_TIME_ERROR (0x3f83000a)
#define PR_CHECK_IN_COMMENT (0x3f84001e)
#define PR_CHECK_IN_COMMENT_UNICODE (0x3f84001f)
#define PR_CHECK_IN_COMMENT_ERROR (0x3f84000a)
#define PR_VERSION_OP_CODE (0x3f850003)
#define PR_VERSION_OP_CODE_ERROR (0x3f85000a)
#define PR_VERSION_OP_DATA (0x3f860102)
#define PR_VERSION_OP_DATA_ERROR (0x3f86000a)
#define PR_VERSION_SEQUENCE_NUMBER (0x3f870003)
#define PR_VERSION_SEQUENCE_NUMBER_ERROR (0x3f87000a)
#define PR_ATTACH_ID (0x3f880014)
#define PR_ATTACH_ID_ERROR (0x3f88000a)
#define PR_PKM_DOC_STATUS (0x3f8d001e)
#define PR_PKM_DOC_STATUS_UNICODE (0x3f8d001f)
#define PR_PKM_DOC_STATUS_ERROR (0x3f8d000a)
#define PR_MV_PKM_OPERATION_REQ (0x3f8e101e)
#define PR_MV_PKM_OPERATION_REQ_UNICODE (0x3f8e101f)
#define PR_MV_PKM_OPERATION_REQ_ERROR (0x3f8e000a)
#define PR_PKM_DOC_INTERNAL_STATE (0x3f8f001e)
#define PR_PKM_DOC_INTERNAL_STATE_UNICODE (0x3f8f001f)
#define PR_PKM_DOC_INTERNAL_STATE_ERROR (0x3f8f000a)
#define PR_VERSIONING_FLAGS (0x3f900002)
#define PR_VERSIONING_FLAGS_ERROR (0x3f90000a)
#define PR_PKM_LAST_UNAPPROVED_VID (0x3f910102)
#define PR_PKM_LAST_UNAPPROVED_VID_ERROR (0x3f91000a)
#define PR_MV_PKM_VERSION_LABELS (0x3f92101e)
#define PR_MV_PKM_VERSION_LABELS_UNICODE (0x3f92101f)
#define PR_MV_PKM_VERSION_LABELS_ERROR (0x3f92000a)
#define PR_MV_PKM_VERSION_STATUS (0x3f93101e)
#define PR_MV_PKM_VERSION_STATUS_UNICODE (0x3f93101f)
#define PR_MV_PKM_VERSION_STATUS_ERROR (0x3f93000a)
#define PR_PKM_INTERNAL_DATA (0x3f940102)
#define PR_PKM_INTERNAL_DATA_ERROR (0x3f94000a)
#define PR_LAST_CONFLICT (0x3fc90102)
#define PR_LAST_CONFLICT_ERROR (0x3fc9000a)
#define PR_CONFLICT_MSG_KEY (0x3fca0102)
#define PR_CONFLICT_MSG_KEY_ERROR (0x3fca000a)
#define PR_REPL_HEADER (0x3fd00102)
#define PR_REPL_HEADER_ERROR (0x3fd0000a)
#define PR_REPL_STATUS (0x3fd10102)
#define PR_REPL_STATUS_ERROR (0x3fd1000a)
#define PR_REPL_CHANGES (0x3fd20102)
#define PR_REPL_CHANGES_ERROR (0x3fd2000a)
#define PR_REPL_RGM (0x3fd30102)
#define PR_REPL_RGM_ERROR (0x3fd3000a)
#define PR_RMI (0x3fd40102)
#define PR_RMI_ERROR (0x3fd4000a)
#define PR_INTERNAL_POST_REPLY (0x3fd50102)
#define PR_INTERNAL_POST_REPLY_ERROR (0x3fd5000a)
#define PR_NTSD_MODIFICATION_TIME (0x3fd60040)
#define PR_NTSD_MODIFICATION_TIME_ERROR (0x3fd6000a)
#define PR_PREVIEW_UNREAD (0x3fd8001e)
#define PR_PREVIEW_UNREAD_UNICODE (0x3fd8001f)
#define PR_PREVIEW_UNREAD_ERROR (0x3fd8000a)
#define PR_PREVIEW (0x3fd9001e)
#define PR_PREVIEW_UNICODE (0x3fd9001f)
#define PR_PREVIEW_ERROR (0x3fd9000a)
#define PR_ABSTRACT (0x3fda001e)
#define PR_ABSTRACT_UNICODE (0x3fda001f)
#define PR_ABSTRACT_ERROR (0x3fda000a)
#define PR_DL_REPORT_FLAGS (0x3fdb0003)
#define PR_DL_REPORT_FLAGS_ERROR (0x3fdb000a)
#define PR_BILATERAL_INFO (0x3fdc0102)
#define PR_BILATERAL_INFO_ERROR (0x3fdc000a)
#define PR_MSG_BODY_ID (0x3fdd0003)
#define PR_MSG_BODY_ID_ERROR (0x3fdd000a)
#define PR_INTERNET_CPID (0x3fde0003)
#define PR_INTERNET_CPID_ERROR (0x3fde000a)
#define PR_AUTO_RESPONSE_SUPPRESS (0x3fdf0003)
#define PR_AUTO_RESPONSE_SUPPRESS_ERROR (0x3fdf000a)
#define PR_ACL_TABLE (0x3fe0000d)
#define PR_ACL_TABLE_ERROR (0x3fe0000a)
#define PR_ACL_DATA (0x3fe00102)
#define PR_RULES_TABLE (0x3fe1000d)
#define PR_RULES_TABLE_ERROR (0x3fe1000a)
#define PR_RULES_DATA (0x3fe10102)
#define PR_FOLDER_DESIGN_FLAGS (0x3fe20003)
#define PR_FOLDER_DESIGN_FLAGS_ERROR (0x3fe2000a)
#define PR_DELEGATED_BY_RULE (0x3fe3000b)
#define PR_DELEGATED_BY_RULE_ERROR (0x3fe3000a)
#define PR_DESIGN_IN_PROGRESS (0x3fe4000b)
#define PR_DESIGN_IN_PROGRESS_ERROR (0x3fe4000a)
#define PR_SECURE_ORIGINATION (0x3fe5000b)
#define PR_SECURE_ORIGINATION_ERROR (0x3fe5000a)
#define PR_PUBLISH_IN_ADDRESS_BOOK (0x3fe6000b)
#define PR_PUBLISH_IN_ADDRESS_BOOK_ERROR (0x3fe6000a)
#define PR_RESOLVE_METHOD (0x3fe70003)
#define PR_RESOLVE_METHOD_ERROR (0x3fe7000a)
#define PR_ADDRESS_BOOK_DISPLAY_NAME (0x3fe8001e)
#define PR_ADDRESS_BOOK_DISPLAY_NAME_UNICODE (0x3fe8001f)
#define PR_ADDRESS_BOOK_DISPLAY_NAME_ERROR (0x3fe8000a)
#define PR_EFORMS_LOCALE_ID (0x3fe90003)
#define PR_EFORMS_LOCALE_ID_ERROR (0x3fe9000a)
#define PR_HAS_DAMS (0x3fea000b)
#define PR_HAS_DAMS_ERROR (0x3fea000a)
#define PR_DEFERRED_SEND_NUMBER (0x3feb0003)
#define PR_DEFERRED_SEND_NUMBER_ERROR (0x3feb000a)
#define PR_DEFERRED_SEND_UNITS (0x3fec0003)
#define PR_DEFERRED_SEND_UNITS_ERROR (0x3fec000a)
#define PR_EXPIRY_NUMBER (0x3fed0003)
#define PR_EXPIRY_NUMBER_ERROR (0x3fed000a)
#define PR_EXPIRY_UNITS (0x3fee0003)
#define PR_EXPIRY_UNITS_ERROR (0x3fee000a)
#define PR_DEFERRED_SEND_TIME (0x3fef0040)
#define PR_DEFERRED_SEND_TIME_ERROR (0x3fef000a)
#define PR_CONFLICT_ENTRYID (0x3ff00102)
#define PR_CONFLICT_ENTRYID_ERROR (0x3ff0000a)
#define PR_MESSAGE_LOCALE_ID (0x3ff10003)
#define PR_MESSAGE_LOCALE_ID_ERROR (0x3ff1000a)
#define PR_RULE_TRIGGER_HISTORY (0x3ff20102)
#define PR_RULE_TRIGGER_HISTORY_ERROR (0x3ff2000a)
#define PR_MOVE_TO_STORE_ENTRYID (0x3ff30102)
#define PR_MOVE_TO_STORE_ENTRYID_ERROR (0x3ff3000a)
#define PR_MOVE_TO_FOLDER_ENTRYID (0x3ff40102)
#define PR_MOVE_TO_FOLDER_ENTRYID_ERROR (0x3ff4000a)
#define PR_STORAGE_QUOTA_LIMIT (0x3ff50003)
#define PR_STORAGE_QUOTA_LIMIT_ERROR (0x3ff5000a)
#define PR_EXCESS_STORAGE_USED (0x3ff60003)
#define PR_EXCESS_STORAGE_USED_ERROR (0x3ff6000a)
#define PR_SVR_GENERATING_QUOTA_MSG (0x3ff7001e)
#define PR_SVR_GENERATING_QUOTA_MSG_UNICODE (0x3ff7001f)
#define PR_SVR_GENERATING_QUOTA_MSG_ERROR (0x3ff7000a)
#define PR_CREATOR_NAME (0x3ff8001e)
#define PR_CREATOR_NAME_UNICODE (0x3ff8001f)
#define PR_CREATOR_NAME_ERROR (0x3ff8000a)
#define PR_CREATOR_ENTRYID (0x3ff90102)
#define PR_CREATOR_ENTRYID_ERROR (0x3ff9000a)
#define PR_LAST_MODIFIER_NAME (0x3ffa001e)
#define PR_LAST_MODIFIER_NAME_UNICODE (0x3ffa001f)
#define PR_LAST_MODIFIER_NAME_ERROR (0x3ffa000a)
#define PR_LAST_MODIFIER_ENTRYID (0x3ffb0102)
#define PR_LAST_MODIFIER_ENTRYID_ERROR (0x3ffb000a)
#define PR_REPLY_RECIPIENT_SMTP_PROXIES (0x3ffc001e)
#define PR_REPLY_RECIPIENT_SMTP_PROXIES_UNICODE (0x3ffc001f)
#define PR_REPLY_RECIPIENT_SMTP_PROXIES_ERROR (0x3ffc000a)
#define PR_MESSAGE_CODEPAGE (0x3ffd0003)
#define PR_MESSAGE_CODEPAGE_ERROR (0x3ffd000a)
#define PR_EXTENDED_ACL_DATA (0x3ffe0102)
#define PR_EXTENDED_ACL_DATA_ERROR (0x3ffe000a)
#define PR_FROM_I_HAVE (0x3fff000b)
#define PR_FROM_I_HAVE_ERROR (0x3fff000a)
#define PR_NEW_ATTACH (0x40000003)
#define PR_NEW_ATTACH_ERROR (0x4000000a)
#define PR_START_EMBED (0x40010003)
#define PR_START_EMBED_ERROR (0x4001000a)
#define PR_END_EMBED (0x40020003)
#define PR_END_EMBED_ERROR (0x4002000a)
#define PR_START_RECIP (0x40030003)
#define PR_START_RECIP_ERROR (0x4003000a)
#define PR_END_RECIP (0x40040003)
#define PR_END_RECIP_ERROR (0x4004000a)
#define PR_END_CC_RECIP (0x40050003)
#define PR_END_CC_RECIP_ERROR (0x4005000a)
#define PR_END_BCC_RECIP (0x40060003)
#define PR_END_BCC_RECIP_ERROR (0x4006000a)
#define PR_END_P1_RECIP (0x40070003)
#define PR_END_P1_RECIP_ERROR (0x4007000a)
#define PR_START_TOP_FLD (0x40090003)
#define PR_START_TOP_FLD_ERROR (0x4009000a)
#define PR_START_SUB_FLD (0x400a0003)
#define PR_START_SUB_FLD_ERROR (0x400a000a)
#define PR_END_FOLDER (0x400b0003)
#define PR_END_FOLDER_ERROR (0x400b000a)
#define PR_START_MESSAGE (0x400c0003)
#define PR_START_MESSAGE_ERROR (0x400c000a)
#define PR_END_MESSAGE (0x400d0003)
#define PR_END_MESSAGE_ERROR (0x400d000a)
#define PR_END_ATTACH (0x400e0003)
#define PR_END_ATTACH_ERROR (0x400e000a)
#define PR_EC_WARNING (0x400f0003)
#define PR_EC_WARNING_ERROR (0x400f000a)
#define PR_START_FAI_MSG (0x40100003)
#define PR_START_FAI_MSG_ERROR (0x4010000a)
#define PR_NEW_FX_FOLDER (0x40110102)
#define PR_NEW_FX_FOLDER_ERROR (0x4011000a)
#define PR_INCR_SYNC_CHG (0x40120003)
#define PR_INCR_SYNC_CHG_ERROR (0x4012000a)
#define PR_INCR_SYNC_DEL (0x40130003)
#define PR_INCR_SYNC_DEL_ERROR (0x4013000a)
#define PR_INCR_SYNC_END (0x40140003)
#define PR_INCR_SYNC_END_ERROR (0x4014000a)
#define PR_INCR_SYNC_MSG (0x40150003)
#define PR_INCR_SYNC_MSG_ERROR (0x4015000a)
#define PR_FX_DEL_PROP (0x40160003)
#define PR_FX_DEL_PROP_ERROR (0x4016000a)
#define PR_IDSET_GIVEN (0x40170003)
#define PR_IDSET_GIVEN_ERROR (0x4017000a)
#define PR_SENDER_FLAGS (0x40190003)
#define PR_SENDER_FLAGS_ERROR (0x4019000a)
#define PR_SENT_REPRESENTING_FLAGS (0x401a0003)
#define PR_SENT_REPRESENTING_FLAGS_ERROR (0x401a000a)
#define PR_RCVD_BY_FLAGS (0x401b0003)
#define PR_RCVD_BY_FLAGS_ERROR (0x401b000a)
#define PR_RCVD_REPRESENTING_FLAGS (0x401c0003)
#define PR_RCVD_REPRESENTING_FLAGS_ERROR (0x401c000a)
#define PR_ORIGINAL_SENDER_FLAGS (0x401d0003)
#define PR_ORIGINAL_SENDER_FLAGS_ERROR (0x401d000a)
#define PR_ORIGINAL_SENT_REPRESENTING_FLAGS (0x401e0003)
#define PR_ORIGINAL_SENT_REPRESENTING_FLAGS_ERROR (0x401e000a)
#define PR_REPORT_FLAGS (0x401f0003)
#define PR_REPORT_FLAGS_ERROR (0x401f000a)
#define PR_READ_RECEIPT_FLAGS (0x40200003)
#define PR_READ_RECEIPT_FLAGS_ERROR (0x4020000a)
#define PR_SOFT_DELETES (0x4021000b)
#define PR_SOFT_DELETES_ERROR (0x4021000a)
#define PR_MESSAGE_SUBMISSION_ID_FROM_CLIENT (0x402c0102)
#define PR_MESSAGE_SUBMISSION_ID_FROM_CLIENT_ERROR (0x402c000a)
#define PR_SENDER_SIMPLE_DISP_NAME (0x4030001e)
#define PR_SENDER_SIMPLE_DISP_NAME_UNICODE (0x4030001f)
#define PR_SENDER_SIMPLE_DISP_NAME_ERROR (0x4030000a)
#define PR_SENT_REPRESENTING_SIMPLE_DISP_NAME (0x4031001e)
#define PR_SENT_REPRESENTING_SIMPLE_DISP_NAME_UNICODE (0x4031001f)
#define PR_SENT_REPRESENTING_SIMPLE_DISP_NAME_ERROR (0x4031000a)
#define PR_CREATOR_SIMPLE_DISP_NAME (0x4038001e)
#define PR_CREATOR_SIMPLE_DISP_NAME_UNICODE (0x4038001f)
#define PR_CREATOR_SIMPLE_DISP_NAME_ERROR (0x4038000a)
#define PR_ORG_ADDR_TYPE (0x403d001e)
#define PR_ORG_ADDR_TYPE_UNICODE (0x403d001f)
#define PR_ORG_ADDR_TYPE_ERROR (0x403d000a)
#define PR_ORG_EMAIL_ADDR (0x403e001e)
#define PR_ORG_EMAIL_ADDR_UNICODE (0x403e001f)
#define PR_ORG_EMAIL_ADDR_ERROR (0x403e000a)
#define PR_CREATOR_FLAGS (0x40590003)
#define PR_CREATOR_FLAGS_ERROR (0x4059000a)
#define PR_MODIFIER_FLAGS (0x405a0003)
#define PR_MODIFIER_FLAGS_ERROR (0x405a000a)
#define PR_ORIGINATOR_FLAGS (0x405b0003)
#define PR_ORIGINATOR_FLAGS_ERROR (0x405b000a)
#define PR_REPORT_DESTINATION_FLAGS (0x405c0003)
#define PR_REPORT_DESTINATION_FLAGS_ERROR (0x405c000a)
#define PR_ORIGINAL_AUTHOR_FLAGS (0x405d0003)
#define PR_ORIGINAL_AUTHOR_FLAGS_ERROR (0x405d000a)
#define PR_ORIGINATOR_SEARCH_KEY (0x40610102)
#define PR_ORIGINATOR_SEARCH_KEY_ERROR (0x4061000a)
#define PR_REPORT_DESTINATION_SEARCH_KEY (0x40640102)
#define PR_REPORT_DESTINATION_SEARCH_KEY_ERROR (0x4064000a)
#define PR_ER_FLAG (0x40650003)
#define PR_ER_FLAG_ERROR (0x4065000a)
#define PR_INTERNET_SUBJECT (0x40680102)
#define PR_INTERNET_SUBJECT_ERROR (0x4068000a)
#define PR_INTERNET_SENT_REPRESENTING_NAME (0x40690102)
#define PR_INTERNET_SENT_REPRESENTING_NAME_ERROR (0x4069000a)
#define PR_INET_MAIL_OVERRIDE_FORMAT (0x59020003)
#define PR_INET_MAIL_OVERRIDE_FORMAT_ERROR (0x5902000a)
#define PR_MSG_EDITOR_FORMAT (0x59090003)
#define PR_MSG_EDITOR_FORMAT_ERROR (0x5909000a)
#define PR_DOTSTUFF_STATE (0x60010003)
#define PR_DOTSTUFF_STATE_ERROR (0x6001000a)
#define PR_RULE_SERVER_RULE_ID (0x65a00014)
#define PR_RULE_SERVER_RULE_ID_ERROR (0x65a0000a)
#define PR_REPLY_TEMPLATE_ID (0x65c20102)
#define PR_REPLY_TEMPLATE_ID_ERROR (0x65c2000a)
#define PR_SOURCE_KEY (0x65e00102)
#define PR_SOURCE_KEY_ERROR (0x65e0000a)
#define PR_PARENT_SOURCE_KEY (0x65e10102)
#define PR_PARENT_SOURCE_KEY_ERROR (0x65e1000a)
#define PR_CHANGE_KEY (0x65e20102)
#define PR_CHANGE_KEY_ERROR (0x65e2000a)
#define PR_PREDECESSOR_CHANGE_LIST (0x65e30102)
#define PR_PREDECESSOR_CHANGE_LIST_ERROR (0x65e3000a)
#define PR_SYNCHRONIZE_FLAGS (0x65e40003)
#define PR_SYNCHRONIZE_FLAGS_ERROR (0x65e4000a)
#define PR_AUTO_ADD_NEW_SUBS (0x65e5000b)
#define PR_AUTO_ADD_NEW_SUBS_ERROR (0x65e5000a)
#define PR_NEW_SUBS_GET_AUTO_ADD (0x65e6000b)
#define PR_NEW_SUBS_GET_AUTO_ADD_ERROR (0x65e6000a)
#define PR_MESSAGE_SITE_NAME (0x65e7001e)
#define PR_MESSAGE_SITE_NAME_UNICODE (0x65e7001f)
#define PR_MESSAGE_SITE_NAME_ERROR (0x65e7000a)
#define PR_MESSAGE_PROCESSED (0x65e8000b)
#define PR_MESSAGE_PROCESSED_ERROR (0x65e8000a)
#define PR_RULE_MSG_STATE (0x65e90003)
#define PR_RULE_MSG_STATE_ERROR (0x65e9000a)
#define PR_RULE_MSG_USER_FLAGS (0x65ea0003)
#define PR_RULE_MSG_USER_FLAGS_ERROR (0x65ea000a)
#define PR_RULE_MSG_PROVIDER (0x65eb001e)
#define PR_RULE_MSG_PROVIDER_UNICODE (0x65eb001f)
#define PR_RULE_MSG_PROVIDER_ERROR (0x65eb000a)
#define PR_RULE_MSG_NAME (0x65ec001e)
#define PR_RULE_MSG_NAME_UNICODE (0x65ec001f)
#define PR_RULE_MSG_NAME_ERROR (0x65ec000a)
#define PR_RULE_MSG_LEVEL (0x65ed0003)
#define PR_RULE_MSG_LEVEL_ERROR (0x65ed000a)
#define PR_RULE_MSG_PROVIDER_DATA (0x65ee0102)
#define PR_RULE_MSG_PROVIDER_DATA_ERROR (0x65ee000a)
#define PR_RULE_MSG_ACTIONS (0x65ef0102)
#define PR_RULE_MSG_ACTIONS_ERROR (0x65ef000a)
#define PR_RULE_MSG_CONDITION (0x65f00102)
#define PR_RULE_MSG_CONDITION_ERROR (0x65f0000a)
#define PR_RULE_MSG_CONDITION_LCID (0x65f10003)
#define PR_RULE_MSG_CONDITION_LCID_ERROR (0x65f1000a)
#define PR_RULE_MSG_VERSION (0x65f20002)
#define PR_RULE_MSG_VERSION_ERROR (0x65f2000a)
#define PR_RULE_MSG_SEQUENCE (0x65f30003)
#define PR_RULE_MSG_SEQUENCE_ERROR (0x65f3000a)
#define PR_PREVENT_MSG_CREATE (0x65f4000b)
#define PR_PREVENT_MSG_CREATE_ERROR (0x65f4000a)
#define PR_IMAP_INTERNAL_DATE (0x65f50040)
#define PR_IMAP_INTERNAL_DATE_ERROR (0x65f5000a)
#define PR_PROFILE_VERSION (0x66000003)
#define PR_PROFILE_VERSION_ERROR (0x6600000a)
#define PR_PROFILE_CONFIG_FLAGS (0x66010003)
#define PR_PROFILE_CONFIG_FLAGS_ERROR (0x6601000a)
#define PR_PROFILE_HOME_SERVER (0x6602001e)
#define PR_PROFILE_HOME_SERVER_UNICODE (0x6602001f)
#define PR_PROFILE_HOME_SERVER_ERROR (0x6602000a)
#define PR_PROFILE_USER (0x6603001e)
#define PR_PROFILE_USER_UNICODE (0x6603001f)
#define PR_PROFILE_USER_ERROR (0x6603000a)
#define PR_PROFILE_CONNECT_FLAGS (0x66040003)
#define PR_PROFILE_CONNECT_FLAGS_ERROR (0x6604000a)
#define PR_PROFILE_TRANSPORT_FLAGS (0x66050003)
#define PR_PROFILE_TRANSPORT_FLAGS_ERROR (0x6605000a)
#define PR_PROFILE_UI_STATE (0x66060003)
#define PR_PROFILE_UI_STATE_ERROR (0x6606000a)
#define PR_PROFILE_UNRESOLVED_NAME (0x6607001e)
#define PR_PROFILE_UNRESOLVED_NAME_UNICODE (0x6607001f)
#define PR_PROFILE_UNRESOLVED_NAME_ERROR (0x6607000a)
#define PR_PROFILE_UNRESOLVED_SERVER (0x6608001e)
#define PR_PROFILE_UNRESOLVED_SERVER_UNICODE (0x6608001f)
#define PR_PROFILE_UNRESOLVED_SERVER_ERROR (0x6608000a)
#define PR_PROFILE_OPEN_FLAGS (0x66090003)
#define PR_PROFILE_OPEN_FLAGS_ERROR (0x6609000a)
#define PR_PROFILE_BINDING_ORDER (0x6609001e)
#define PR_PROFILE_BINDING_ORDER_UNICODE (0x6609001f)
#define PR_PROFILE_TYPE (0x660a0003)
#define PR_PROFILE_TYPE_ERROR (0x660a000a)
#define PR_PROFILE_MAILBOX (0x660b001e)
#define PR_PROFILE_MAILBOX_UNICODE (0x660b001f)
#define PR_PROFILE_MAILBOX_ERROR (0x660b000a)
#define PR_PROFILE_SERVER (0x660c001e)
#define PR_PROFILE_SERVER_UNICODE (0x660c001f)
#define PR_PROFILE_SERVER_ERROR (0x660c000a)
#define PR_PROFILE_MAX_RESTRICT (0x660d0003)
#define PR_PROFILE_MAX_RESTRICT_ERROR (0x660d000a)
#define PR_PROFILE_AB_FILES_PATH (0x660e001e)
#define PR_PROFILE_AB_FILES_PATH_UNICODE (0x660e001f)
#define PR_PROFILE_AB_FILES_PATH_ERROR (0x660e000a)
#define PR_PROFILE_FAVFLD_DISPLAY_NAME (0x660f001e)
#define PR_PROFILE_FAVFLD_DISPLAY_NAME_UNICODE (0x660f001f)
#define PR_PROFILE_FAVFLD_DISPLAY_NAME_ERROR (0x660f000a)
#define PR_PROFILE_OFFLINE_STORE_PATH (0x6610001e)
#define PR_PROFILE_OFFLINE_STORE_PATH_UNICODE (0x6610001f)
#define PR_PROFILE_OFFLINE_STORE_PATH_ERROR (0x6610000a)
#define PR_PROFILE_OFFLINE_INFO (0x66110102)
#define PR_PROFILE_OFFLINE_INFO_ERROR (0x6611000a)
#define PR_PROFILE_HOME_SERVER_DN (0x6612001e)
#define PR_PROFILE_HOME_SERVER_DN_UNICODE (0x6612001f)
#define PR_PROFILE_HOME_SERVER_DN_ERROR (0x6612000a)
#define PR_PROFILE_HOME_SERVER_ADDRS (0x6613101e)
#define PR_PROFILE_HOME_SERVER_ADDRS_UNICODE (0x6613101f)
#define PR_PROFILE_HOME_SERVER_ADDRS_ERROR (0x6613000a)
#define PR_PROFILE_SERVER_DN (0x6614001e)
#define PR_PROFILE_SERVER_DN_UNICODE (0x6614001f)
#define PR_PROFILE_SERVER_DN_ERROR (0x6614000a)
#define PR_PROFILE_FAVFLD_COMMENT (0x6615001e)
#define PR_PROFILE_FAVFLD_COMMENT_UNICODE (0x6615001f)
#define PR_PROFILE_FAVFLD_COMMENT_ERROR (0x6615000a)
#define PR_PROFILE_ALLPUB_DISPLAY_NAME (0x6616001e)
#define PR_PROFILE_ALLPUB_DISPLAY_NAME_UNICODE (0x6616001f)
#define PR_PROFILE_ALLPUB_DISPLAY_NAME_ERROR (0x6616000a)
#define PR_PROFILE_ALLPUB_COMMENT (0x6617001e)
#define PR_PROFILE_ALLPUB_COMMENT_UNICODE (0x6617001f)
#define PR_PROFILE_ALLPUB_COMMENT_ERROR (0x6617000a)
#define PR_DISABLE_WINSOCK (0x66180003)
#define PR_DISABLE_WINSOCK_ERROR (0x6618000a)
#define PR_IN_TRANSIT (0x6618000b)
#define PR_PROFILE_AUTH_PACKAGE (0x66190003)
#define PR_PROFILE_AUTH_PACKAGE_ERROR (0x6619000a)
#define PR_USER_ENTRYID (0x66190102)
#define PR_USER_NAME (0x661a001e)
#define PR_USER_NAME_UNICODE (0x661a001f)
#define PR_USER_NAME_ERROR (0x661a000a)
#define PR_MAILBOX_OWNER_ENTRYID (0x661b0102)
#define PR_MAILBOX_OWNER_ENTRYID_ERROR (0x661b000a)
#define PR_MAILBOX_OWNER_NAME (0x661c001e)
#define PR_MAILBOX_OWNER_NAME_UNICODE (0x661c001f)
#define PR_MAILBOX_OWNER_NAME_ERROR (0x661c000a)
#define PR_OOF_STATE (0x661d000b)
#define PR_OOF_STATE_ERROR (0x661d000a)
#define PR_SCHEDULE_FOLDER_ENTRYID (0x661e0102)
#define PR_SCHEDULE_FOLDER_ENTRYID_ERROR (0x661e000a)
#define PR_IPM_DAF_ENTRYID (0x661f0102)
#define PR_IPM_DAF_ENTRYID_ERROR (0x661f000a)
#define PR_NON_IPM_SUBTREE_ENTRYID (0x66200102)
#define PR_NON_IPM_SUBTREE_ENTRYID_ERROR (0x6620000a)
#define PR_EFORMS_REGISTRY_ENTRYID (0x66210102)
#define PR_EFORMS_REGISTRY_ENTRYID_ERROR (0x6621000a)
#define PR_SPLUS_FREE_BUSY_ENTRYID (0x66220102)
#define PR_SPLUS_FREE_BUSY_ENTRYID_ERROR (0x6622000a)
#define PR_HIERARCHY_SERVER (0x6623001e)
#define PR_HIERARCHY_SERVER_UNICODE (0x6623001f)
#define PR_HIERARCHY_SERVER_ERROR (0x6623000a)
#define PR_OFFLINE_ADDRBOOK_ENTRYID (0x66230102)
#define PR_EFORMS_FOR_LOCALE_ENTRYID (0x66240102)
#define PR_EFORMS_FOR_LOCALE_ENTRYID_ERROR (0x6624000a)
#define PR_FREE_BUSY_FOR_LOCAL_SITE_ENTRYID (0x66250102)
#define PR_FREE_BUSY_FOR_LOCAL_SITE_ENTRYID_ERROR (0x6625000a)
#define PR_ADDRBOOK_FOR_LOCAL_SITE_ENTRYID (0x66260102)
#define PR_ADDRBOOK_FOR_LOCAL_SITE_ENTRYID_ERROR (0x6626000a)
#define PR_OFFLINE_MESSAGE_ENTRYID (0x66270102)
#define PR_OFFLINE_MESSAGE_ENTRYID_ERROR (0x6627000a)
#define PR_GW_MTSIN_ENTRYID (0x66280102)
#define PR_GW_MTSIN_ENTRYID_ERROR (0x6628000a)
#define PR_GW_MTSOUT_ENTRYID (0x66290102)
#define PR_GW_MTSOUT_ENTRYID_ERROR (0x6629000a)
#define PR_TRANSFER_ENABLED (0x662a000b)
#define PR_TRANSFER_ENABLED_ERROR (0x662a000a)
#define PR_TEST_LINE_SPEED (0x662b0102)
#define PR_TEST_LINE_SPEED_ERROR (0x662b000a)
#define PR_HIERARCHY_SYNCHRONIZER (0x662c000d)
#define PR_HIERARCHY_SYNCHRONIZER_ERROR (0x662c000a)
#define PR_CONTENTS_SYNCHRONIZER (0x662d000d)
#define PR_CONTENTS_SYNCHRONIZER_ERROR (0x662d000a)
#define PR_COLLECTOR (0x662e000d)
#define PR_COLLECTOR_ERROR (0x662e000a)
#define PR_FAST_TRANSFER (0x662f000d)
#define PR_FAST_TRANSFER_ERROR (0x662f000a)
#define PR_IPM_FAVORITES_ENTRYID (0x66300102)
#define PR_IPM_FAVORITES_ENTRYID_ERROR (0x6630000a)
#define PR_IPM_PUBLIC_FOLDERS_ENTRYID (0x66310102)
#define PR_IPM_PUBLIC_FOLDERS_ENTRYID_ERROR (0x6631000a)
#define PR_STORE_OFFLINE (0x6632000b)
#define PR_STORE_OFFLINE_ERROR (0x6632000a)
#define PR_CHANGE_ADVISOR (0x6634000d)
#define PR_CHANGE_ADVISOR_ERROR (0x6634000a)
#define PR_FAVORITES_DEFAULT_NAME (0x6635001e)
#define PR_FAVORITES_DEFAULT_NAME_UNICODE (0x6635001f)
#define PR_FAVORITES_DEFAULT_NAME_ERROR (0x6635000a)
#define PR_SYS_CONFIG_FOLDER_ENTRYID (0x66360102)
#define PR_SYS_CONFIG_FOLDER_ENTRYID_ERROR (0x6636000a)
#define PR_CHANGE_NOTIFICATION_GUID (0x66370048)
#define PR_CHANGE_NOTIFICATION_GUID_ERROR (0x6637000a)
#define PR_FOLDER_CHILD_COUNT (0x66380003)
#define PR_FOLDER_CHILD_COUNT_ERROR (0x6638000a)
#define PR_RIGHTS (0x66390003)
#define PR_RIGHTS_ERROR (0x6639000a)
#define PR_HAS_RULES (0x663a000b)
#define PR_HAS_RULES_ERROR (0x663a000a)
#define PR_ADDRESS_BOOK_ENTRYID (0x663b0102)
#define PR_ADDRESS_BOOK_ENTRYID_ERROR (0x663b000a)
#define PR_PUBLIC_FOLDER_ENTRYID (0x663c0102)
#define PR_PUBLIC_FOLDER_ENTRYID_ERROR (0x663c000a)
#define PR_OFFLINE_FLAGS (0x663d0003)
#define PR_OFFLINE_FLAGS_ERROR (0x663d000a)
#define PR_HIERARCHY_CHANGE_NUM (0x663e0003)
#define PR_HIERARCHY_CHANGE_NUM_ERROR (0x663e000a)
#define PR_HAS_MODERATOR_RULES (0x663f000b)
#define PR_HAS_MODERATOR_RULES_ERROR (0x663f000a)
#define PR_DELETED_MSG_COUNT (0x66400003)
#define PR_DELETED_MSG_COUNT_ERROR (0x6640000a)
#define PR_DELETED_FOLDER_COUNT (0x66410003)
#define PR_DELETED_FOLDER_COUNT_ERROR (0x6641000a)
#define PR_OLDEST_DELETED_ON (0x66420040)
#define PR_OLDEST_DELETED_ON_ERROR (0x6642000a)
#define PR_DELETED_ASSOC_MSG_COUNT (0x66430003)
#define PR_DELETED_ASSOC_MSG_COUNT_ERROR (0x6643000a)
#define PR_REPLICA_SERVER (0x6644001e)
#define PR_REPLICA_SERVER_UNICODE (0x6644001f)
#define PR_REPLICA_SERVER_ERROR (0x6644000a)
#define PR_CLIENT_ACTIONS (0x66450102)
#define PR_CLIENT_ACTIONS_ERROR (0x6645000a)
#define PR_DAM_ORIGINAL_ENTRYID (0x66460102)
#define PR_DAM_ORIGINAL_ENTRYID_ERROR (0x6646000a)
#define PR_DAM_BACK_PATCHED (0x6647000b)
#define PR_DAM_BACK_PATCHED_ERROR (0x6647000a)
#define PR_RULE_ERROR (0x66480003)
#define PR_RULE_ERROR_ERROR (0x6648000a)
#define PR_RULE_ACTION_TYPE (0x66490003)
#define PR_RULE_ACTION_TYPE_ERROR (0x6649000a)
#define PR_HAS_NAMED_PROPERTIES (0x664a000b)
#define PR_HAS_NAMED_PROPERTIES_ERROR (0x664a000a)
#define PR_REPLICA_VERSION (0x664b0014)
#define PR_REPLICA_VERSION_ERROR (0x664b000a)
#define PR_RULE_ACTION_NUMBER (0x66500003)
#define PR_RULE_ACTION_NUMBER_ERROR (0x6650000a)
#define PR_RULE_FOLDER_ENTRYID (0x66510102)
#define PR_RULE_FOLDER_ENTRYID_ERROR (0x6651000a)
#define PR_ACTIVE_USER_ENTRYID (0x66520102)
#define PR_ACTIVE_USER_ENTRYID_ERROR (0x6652000a)
#define PR_0X400_ENVELOPE_TYPE (0x66530003)
#define PR_0X400_ENVELOPE_TYPE_ERROR (0x6653000a)
#define PR_MSG_FOLD_TIME (0x66540040)
#define PR_MSG_FOLD_TIME_ERROR (0x6654000a)
#define PR_ICS_CHANGE_KEY (0x66550102)
#define PR_ICS_CHANGE_KEY_ERROR (0x6655000a)
#define PR_GW_ADMIN_OPERATIONS (0x66580003)
#define PR_GW_ADMIN_OPERATIONS_ERROR (0x6658000a)
#define PR_INTERNET_CONTENT (0x66590102)
#define PR_INTERNET_CONTENT_ERROR (0x6659000a)
#define PR_HAS_ATTACH_FROM_IMAIL (0x665a000b)
#define PR_HAS_ATTACH_FROM_IMAIL_ERROR (0x665a000a)
#define PR_ORIGINATOR_NAME (0x665b001e)
#define PR_ORIGINATOR_NAME_UNICODE (0x665b001f)
#define PR_ORIGINATOR_NAME_ERROR (0x665b000a)
#define PR_ORIGINATOR_ADDR (0x665c001e)
#define PR_ORIGINATOR_ADDR_UNICODE (0x665c001f)
#define PR_ORIGINATOR_ADDR_ERROR (0x665c000a)
#define PR_ORIGINATOR_ADDRTYPE (0x665d001e)
#define PR_ORIGINATOR_ADDRTYPE_UNICODE (0x665d001f)
#define PR_ORIGINATOR_ADDRTYPE_ERROR (0x665d000a)
#define PR_ORIGINATOR_ENTRYID (0x665e0102)
#define PR_ORIGINATOR_ENTRYID_ERROR (0x665e000a)
#define PR_ARRIVAL_TIME (0x665f0040)
#define PR_ARRIVAL_TIME_ERROR (0x665f000a)
#define PR_TRACE_INFO (0x66600102)
#define PR_TRACE_INFO_ERROR (0x6660000a)
#define PR_SUBJECT_TRACE_INFO (0x66610102)
#define PR_SUBJECT_TRACE_INFO_ERROR (0x6661000a)
#define PR_RECIPIENT_NUMBER (0x66620003)
#define PR_RECIPIENT_NUMBER_ERROR (0x6662000a)
#define PR_MTS_SUBJECT_ID (0x66630102)
#define PR_MTS_SUBJECT_ID_ERROR (0x6663000a)
#define PR_REPORT_DESTINATION_NAME (0x6664001e)
#define PR_REPORT_DESTINATION_NAME_UNICODE (0x6664001f)
#define PR_REPORT_DESTINATION_NAME_ERROR (0x6664000a)
#define PR_REPORT_DESTINATION_ENTRYID (0x66650102)
#define PR_REPORT_DESTINATION_ENTRYID_ERROR (0x6665000a)
#define PR_CONTENT_SEARCH_KEY (0x66660102)
#define PR_CONTENT_SEARCH_KEY_ERROR (0x6666000a)
#define PR_FOREIGN_ID (0x66670102)
#define PR_FOREIGN_ID_ERROR (0x6667000a)
#define PR_FOREIGN_REPORT_ID (0x66680102)
#define PR_FOREIGN_REPORT_ID_ERROR (0x6668000a)
#define PR_FOREIGN_SUBJECT_ID (0x66690102)
#define PR_FOREIGN_SUBJECT_ID_ERROR (0x6669000a)
#define PR_INTERNAL_TRACE_INFO (0x666a0102)
#define PR_INTERNAL_TRACE_INFO_ERROR (0x666a000a)
#define PR_IN_CONFLICT (0x666c000b)
#define PR_IN_CONFLICT_ERROR (0x666c000a)
#define PR_LONGTERM_ENTRYID_FROM_TABLE (0x66700102)
#define PR_LONGTERM_ENTRYID_FROM_TABLE_ERROR (0x6670000a)
#define PR_MEMBER_ID (0x66710014)
#define PR_MEMBER_ID_ERROR (0x6671000a)
#define PR_MEMBER_NAME (0x6672001e)
#define PR_MEMBER_NAME_UNICODE (0x6672001f)
#define PR_MEMBER_NAME_ERROR (0x6672000a)
#define PR_MEMBER_RIGHTS (0x66730003)
#define PR_MEMBER_RIGHTS_ERROR (0x6673000a)
#define PR_RULE_ID (0x66740014)
#define PR_RULE_ID_ERROR (0x6674000a)
#define PR_RULE_IDS (0x66750102)
#define PR_RULE_IDS_ERROR (0x6675000a)
#define PR_RULE_SEQUENCE (0x66760003)
#define PR_RULE_SEQUENCE_ERROR (0x6676000a)
#define PR_RULE_STATE (0x66770003)
#define PR_RULE_STATE_ERROR (0x6677000a)
#define PR_RULE_USER_FLAGS (0x66780003)
#define PR_RULE_USER_FLAGS_ERROR (0x6678000a)
#define PR_RULE_CONDITION (0x667900fd)
#define PR_RULE_CONDITION_ERROR (0x6679000a)
#define PR_PROFILE_MOAB (0x667b001e)
#define PR_PROFILE_MOAB_UNICODE (0x667b001f)
#define PR_PROFILE_MOAB_ERROR (0x667b000a)
#define PR_PROFILE_MOAB_GUID (0x667c001e)
#define PR_PROFILE_MOAB_GUID_UNICODE (0x667c001f)
#define PR_PROFILE_MOAB_GUID_ERROR (0x667c000a)
#define PR_PROFILE_MOAB_SEQ (0x667d0003)
#define PR_PROFILE_MOAB_SEQ_ERROR (0x667d000a)
#define PR_IMPLIED_RESTRICTIONS (0x667f1102)
#define PR_IMPLIED_RESTRICTIONS_ERROR (0x667f000a)
#define PR_RULE_ACTIONS (0x668000fe)
#define PR_RULE_ACTIONS_ERROR (0x6680000a)
#define PR_RULE_PROVIDER (0x6681001e)
#define PR_RULE_PROVIDER_UNICODE (0x6681001f)
#define PR_RULE_PROVIDER_ERROR (0x6681000a)
#define PR_RULE_NAME (0x6682001e)
#define PR_RULE_NAME_UNICODE (0x6682001f)
#define PR_RULE_NAME_ERROR (0x6682000a)
#define PR_RULE_LEVEL (0x66830003)
#define PR_RULE_LEVEL_ERROR (0x6683000a)
#define PR_RULE_PROVIDER_DATA (0x66840102)
#define PR_RULE_PROVIDER_DATA_ERROR (0x6684000a)
#define PR_LAST_FULL_BACKUP (0x66850040)
#define PR_LAST_FULL_BACKUP_ERROR (0x6685000a)
#define PR_PROFILE_ADDR_INFO (0x66870102)
#define PR_PROFILE_ADDR_INFO_ERROR (0x6687000a)
#define PR_PROFILE_OPTIONS_DATA (0x66890102)
#define PR_PROFILE_OPTIONS_DATA_ERROR (0x6689000a)
#define PR_EVENTS_ROOT_FOLDER_ENTRYID (0x668a0102)
#define PR_EVENTS_ROOT_FOLDER_ENTRYID_ERROR (0x668a000a)
#define PR_INBOUND_NEWSFEED_DN (0x668d001e)
#define PR_INBOUND_NEWSFEED_DN_UNICODE (0x668d001f)
#define PR_INBOUND_NEWSFEED_DN_ERROR (0x668d000a)
#define PR_OUTBOUND_NEWSFEED_DN (0x668e001e)
#define PR_OUTBOUND_NEWSFEED_DN_UNICODE (0x668e001f)
#define PR_OUTBOUND_NEWSFEED_DN_ERROR (0x668e000a)
#define PR_DELETED_ON (0x668f0040)
#define PR_DELETED_ON_ERROR (0x668f000a)
#define PR_REPLICATION_STYLE (0x66900003)
#define PR_REPLICATION_STYLE_ERROR (0x6690000a)
#define PR_REPLICATION_SCHEDULE (0x66910102)
#define PR_REPLICATION_SCHEDULE_ERROR (0x6691000a)
#define PR_REPLICATION_MESSAGE_PRIORITY (0x66920003)
#define PR_REPLICATION_MESSAGE_PRIORITY_ERROR (0x6692000a)
#define PR_OVERALL_MSG_AGE_LIMIT (0x66930003)
#define PR_OVERALL_MSG_AGE_LIMIT_ERROR (0x6693000a)
#define PR_REPLICATION_ALWAYS_INTERVAL (0x66940003)
#define PR_REPLICATION_ALWAYS_INTERVAL_ERROR (0x6694000a)
#define PR_REPLICATION_MSG_SIZE (0x66950003)
#define PR_REPLICATION_MSG_SIZE_ERROR (0x6695000a)
#define PR_IS_NEWSGROUP_ANCHOR (0x6696000b)
#define PR_IS_NEWSGROUP_ANCHOR_ERROR (0x6696000a)
#define PR_IS_NEWSGROUP (0x6697000b)
#define PR_IS_NEWSGROUP_ERROR (0x6697000a)
#define PR_REPLICA_LIST (0x66980102)
#define PR_REPLICA_LIST_ERROR (0x6698000a)
#define PR_OVERALL_AGE_LIMIT (0x66990003)
#define PR_OVERALL_AGE_LIMIT_ERROR (0x6699000a)
#define PR_INTERNET_CHARSET (0x669a001e)
#define PR_INTERNET_CHARSET_UNICODE (0x669a001f)
#define PR_INTERNET_CHARSET_ERROR (0x669a000a)
#define PR_DELETED_MESSAGE_SIZE_EXTENDED (0x669b0014)
#define PR_DELETED_MESSAGE_SIZE_EXTENDED_ERROR (0x669b000a)
#define PR_DELETED_NORMAL_MESSAGE_SIZE_EXTENDED (0x669c0014)
#define PR_DELETED_NORMAL_MESSAGE_SIZE_EXTENDED_ERROR (0x669c000a)
#define PR_DELETED_ASSOC_MESSAGE_SIZE_EXTENDED (0x669d0014)
#define PR_DELETED_ASSOC_MESSAGE_SIZE_EXTENDED_ERROR (0x669d000a)
#define PR_SECURE_IN_SITE (0x669e000b)
#define PR_SECURE_IN_SITE_ERROR (0x669e000a)
#define PR_NT_USER_NAME (0x66a0001e)
#define PR_NT_USER_NAME_UNICODE (0x66a0001f)
#define PR_NT_USER_NAME_ERROR (0x66a0000a)
#define PR_LOCALE_ID (0x66a10003)
#define PR_LOCALE_ID_ERROR (0x66a1000a)
#define PR_LAST_LOGON_TIME (0x66a20040)
#define PR_LAST_LOGON_TIME_ERROR (0x66a2000a)
#define PR_LAST_LOGOFF_TIME (0x66a30040)
#define PR_LAST_LOGOFF_TIME_ERROR (0x66a3000a)
#define PR_STORAGE_LIMIT_INFORMATION (0x66a40003)
#define PR_STORAGE_LIMIT_INFORMATION_ERROR (0x66a4000a)
#define PR_NEWSGROUP_COMPONENT (0x66a5001e)
#define PR_NEWSGROUP_COMPONENT_UNICODE (0x66a5001f)
#define PR_NEWSGROUP_COMPONENT_ERROR (0x66a5000a)
#define PR_NEWSFEED_INFO (0x66a60102)
#define PR_NEWSFEED_INFO_ERROR (0x66a6000a)
#define PR_INTERNET_NEWSGROUP_NAME (0x66a7001e)
#define PR_INTERNET_NEWSGROUP_NAME_UNICODE (0x66a7001f)
#define PR_INTERNET_NEWSGROUP_NAME_ERROR (0x66a7000a)
#define PR_FOLDER_FLAGS (0x66a80003)
#define PR_FOLDER_FLAGS_ERROR (0x66a8000a)
#define PR_LAST_ACCESS_TIME (0x66a90040)
#define PR_LAST_ACCESS_TIME_ERROR (0x66a9000a)
#define PR_RESTRICTION_COUNT (0x66aa0003)
#define PR_RESTRICTION_COUNT_ERROR (0x66aa000a)
#define PR_CATEG_COUNT (0x66ab0003)
#define PR_CATEG_COUNT_ERROR (0x66ab000a)
#define PR_CACHED_COLUMN_COUNT (0x66ac0003)
#define PR_CACHED_COLUMN_COUNT_ERROR (0x66ac000a)
#define PR_NORMAL_MSG_W_ATTACH_COUNT (0x66ad0003)
#define PR_NORMAL_MSG_W_ATTACH_COUNT_ERROR (0x66ad000a)
#define PR_ASSOC_MSG_W_ATTACH_COUNT (0x66ae0003)
#define PR_ASSOC_MSG_W_ATTACH_COUNT_ERROR (0x66ae000a)
#define PR_RECIPIENT_ON_NORMAL_MSG_COUNT (0x66af0003)
#define PR_RECIPIENT_ON_NORMAL_MSG_COUNT_ERROR (0x66af000a)
#define PR_RECIPIENT_ON_ASSOC_MSG_COUNT (0x66b00003)
#define PR_RECIPIENT_ON_ASSOC_MSG_COUNT_ERROR (0x66b0000a)
#define PR_ATTACH_ON_NORMAL_MSG_COUNT (0x66b10003)
#define PR_ATTACH_ON_NORMAL_MSG_COUNT_ERROR (0x66b1000a)
#define PR_ATTACH_ON_ASSOC_MSG_COUNT (0x66b20003)
#define PR_ATTACH_ON_ASSOC_MSG_COUNT_ERROR (0x66b2000a)
#define PR_NORMAL_MESSAGE_SIZE (0x66b30003)
#define PR_NORMAL_MESSAGE_SIZE_ERROR (0x66b3000a)
#define PR_NORMAL_MESSAGE_SIZE_EXTENDED (0x66b30014)
#define PR_ASSOC_MESSAGE_SIZE (0x66b40003)
#define PR_ASSOC_MESSAGE_SIZE_ERROR (0x66b4000a)
#define PR_ASSOC_MESSAGE_SIZE_EXTENDED (0x66b40014)
#define PR_FOLDER_PATHNAME (0x66b5001e)
#define PR_FOLDER_PATHNAME_UNICODE (0x66b5001f)
#define PR_FOLDER_PATHNAME_ERROR (0x66b5000a)
#define PR_OWNER_COUNT (0x66b60003)
#define PR_OWNER_COUNT_ERROR (0x66b6000a)
#define PR_CONTACT_COUNT (0x66b70003)
#define PR_CONTACT_COUNT_ERROR (0x66b7000a)
#define PR_CODE_PAGE_ID (0x66c30003)
#define PR_CODE_PAGE_ID_ERROR (0x66c3000a)
#define PR_RETENTION_AGE_LIMIT (0x66c40003)
#define PR_RETENTION_AGE_LIMIT_ERROR (0x66c4000a)
#define PR_DISABLE_PERUSER_READ (0x66c5000b)
#define PR_DISABLE_PERUSER_READ_ERROR (0x66c5000a)
#define PR_INTERNET_PARSE_STATE (0x66c60102)
#define PR_INTERNET_PARSE_STATE_ERROR (0x66c6000a)
#define PR_INTERNET_MESSAGE_INFO (0x66c70102)
#define PR_INTERNET_MESSAGE_INFO_ERROR (0x66c7000a)
#define PR_PST_PATH (0x6700001e)
#define PR_PST_PATH_UNICODE (0x6700001f)
#define PR_PST_PATH_ERROR (0x6700000a)
#define PR_PST_REMEMBER_PW (0x6701000b)
#define PR_PST_REMEMBER_PW_ERROR (0x6701000a)
#define PR_OST_ENCRYPTION (0x67020003)
#define PR_OST_ENCRYPTION_ERROR (0x6702000a)
#define PR_PST_PW_SZ_OLD (0x6703001e)
#define PR_PST_PW_SZ_OLD_UNICODE (0x6703001f)
#define PR_PST_PW_SZ_OLD_ERROR (0x6703000a)
#define PR_PST_PW_SZ_NEW (0x6704001e)
#define PR_PST_PW_SZ_NEW_UNICODE (0x6704001f)
#define PR_PST_PW_SZ_NEW_ERROR (0x6704000a)
#define PR_SORT_LOCALE_ID (0x67050003)
#define PR_SORT_LOCALE_ID_ERROR (0x6705000a)
#define PR_URL_NAME (0x6707001e)
#define PR_URL_NAME_UNICODE (0x6707001f)
#define PR_URL_NAME_ERROR (0x6707000a)
#define PR_LOCAL_COMMIT_TIME (0x67090040)
#define PR_LOCAL_COMMIT_TIME_ERROR (0x6709000a)
#define PR_LOCAL_COMMIT_TIME_MAX (0x670a0040)
#define PR_LOCAL_COMMIT_TIME_MAX_ERROR (0x670a000a)
#define PR_DELETED_COUNT_TOTAL (0x670b0003)
#define PR_DELETED_COUNT_TOTAL_ERROR (0x670b000a)
#define PR_AUTO_RESET (0x670c0048)
#define PR_AUTO_RESET_ERROR (0x670c000a)
#define PR_URL_COMP_NAME_HASH (0x67100003)
#define PR_URL_COMP_NAME_HASH_ERROR (0x6710000a)
#define PR_MSG_FOLDER_TEMPLATE_RES_2 (0x67110003)
#define PR_MSG_FOLDER_TEMPLATE_RES_2_ERROR (0x6711000a)
#define PR_RANK (0x67120003)
#define PR_RANK_ERROR (0x6712000a)
#define PR_MSG_FOLDER_TEMPLATE_RES_4 (0x6713000b)
#define PR_MSG_FOLDER_TEMPLATE_RES_4_ERROR (0x6713000a)
#define PR_MSG_FOLDER_TEMPLATE_RES_5 (0x6714000b)
#define PR_MSG_FOLDER_TEMPLATE_RES_5_ERROR (0x6714000a)
#define PR_MSG_FOLDER_TEMPLATE_RES_6 (0x6715000b)
#define PR_MSG_FOLDER_TEMPLATE_RES_6_ERROR (0x6715000a)
#define PR_MSG_FOLDER_TEMPLATE_RES_7 (0x67160102)
#define PR_MSG_FOLDER_TEMPLATE_RES_7_ERROR (0x6716000a)
#define PR_MSG_FOLDER_TEMPLATE_RES_8 (0x67170102)
#define PR_MSG_FOLDER_TEMPLATE_RES_8_ERROR (0x6717000a)
#define PR_MSG_FOLDER_TEMPLATE_RES_9 (0x67180102)
#define PR_MSG_FOLDER_TEMPLATE_RES_9_ERROR (0x6718000a)
#define PR_MSG_FOLDER_TEMPLATE_RES_10 (0x6719001e)
#define PR_MSG_FOLDER_TEMPLATE_RES_10_UNICODE (0x6719001f)
#define PR_MSG_FOLDER_TEMPLATE_RES_10_ERROR (0x6719000a)
#define PR_MSG_FOLDER_TEMPLATE_RES_11 (0x671a001e)
#define PR_MSG_FOLDER_TEMPLATE_RES_11_UNICODE (0x671a001f)
#define PR_MSG_FOLDER_TEMPLATE_RES_11_ERROR (0x671a000a)
#define PR_MSG_FOLDER_TEMPLATE_RES_12 (0x671b001e)
#define PR_MSG_FOLDER_TEMPLATE_RES_12_UNICODE (0x671b001f)
#define PR_MSG_FOLDER_TEMPLATE_RES_12_ERROR (0x671b000a)
#define PR_PF_PLATINUM_HOME_MDB (0x671e000b)
#define PR_PF_PLATINUM_HOME_MDB_ERROR (0x671e000a)
#define PR_PF_PROXY_REQUIRED (0x671f000b)
#define PR_PF_PROXY_REQUIRED_ERROR (0x671f000a)
#define PR_INTERNET_FREE_DOC_INFO (0x67200102)
#define PR_INTERNET_FREE_DOC_INFO_ERROR (0x6720000a)
#define PR_PF_OVER_HARD_QUOTA_LIMIT (0x67210003)
#define PR_PF_OVER_HARD_QUOTA_LIMIT_ERROR (0x6721000a)
#define PR_PF_MSG_SIZE_LIMIT (0x67220003)
#define PR_PF_MSG_SIZE_LIMIT_ERROR (0x6722000a)
#define PR_CONNECTION_MODULUS (0x67430003)
#define PR_CONNECTION_MODULUS_ERROR (0x6743000a)
#define PR_DELIVER_TO_DN (0x6744001e)
#define PR_DELIVER_TO_DN_UNICODE (0x6744001f)
#define PR_DELIVER_TO_DN_ERROR (0x6744000a)
#define PR_MIME_SIZE (0x67460003)
#define PR_MIME_SIZE_ERROR (0x6746000a)
#define PR_FILE_SIZE_EXTENDED (0x67470014)
#define PR_FILE_SIZE_EXTENDED_ERROR (0x6747000a)
#define PR_FID (0x67480014)
#define PR_FID_ERROR (0x6748000a)
#define PR_PARENT_FID (0x67490014)
#define PR_PARENT_FID_ERROR (0x6749000a)
#define PR_MID (0x674a0014)
#define PR_MID_ERROR (0x674a000a)
#define PR_CATEG_ID (0x674b0014)
#define PR_CATEG_ID_ERROR (0x674b000a)
#define PR_PARENT_CATEG_ID (0x674c0014)
#define PR_PARENT_CATEG_ID_ERROR (0x674c000a)
#define PR_INST_ID (0x674d0014)
#define PR_INST_ID_ERROR (0x674d000a)
#define PR_INSTANCE_NUM (0x674e0003)
#define PR_INSTANCE_NUM_ERROR (0x674e000a)
#define PR_ADDRBOOK_MID (0x674f0014)
#define PR_ADDRBOOK_MID_ERROR (0x674f000a)
#define PR_ICS_NOTIF (0x67500003)
#define PR_ICS_NOTIF_ERROR (0x6750000a)
#define PR_ARTICLE_NUM_NEXT (0x67510003)
#define PR_ARTICLE_NUM_NEXT_ERROR (0x6751000a)
#define PR_IMAP_LAST_ARTICLE_ID (0x67520003)
#define PR_IMAP_LAST_ARTICLE_ID_ERROR (0x6752000a)
#define PR_NOT_822_RENDERABLE (0x6753000b)
#define PR_NOT_822_RENDERABLE_ERROR (0x6753000a)
#define PR_LTID (0x67580102)
#define PR_LTID_ERROR (0x6758000a)
#define PR_CN_EXPORT (0x67590102)
#define PR_CN_EXPORT_ERROR (0x6759000a)
#define PR_PCL_EXPORT (0x675a0102)
#define PR_PCL_EXPORT_ERROR (0x675a000a)
#define PR_CN_MV_EXPORT (0x675b1102)
#define PR_CN_MV_EXPORT_ERROR (0x675b000a)
#define PR_PF_QUOTA_STYLE (0x67790003)
#define PR_PF_QUOTA_STYLE_ERROR (0x6779000a)
#define PR_PF_STORAGE_QUOTA (0x677b0003)
#define PR_PF_STORAGE_QUOTA_ERROR (0x677b000a)
#define PR_SEARCH_FLAGS (0x67830003)
#define PR_SEARCH_FLAGS_ERROR (0x6783000a)
#define PR_ASSOCIATED (0x67aa000b)
#define PR_ASSOCIATED_ERROR (0x67aa000a)
#define PR_PROFILE_SECURE_MAILBOX (0x67f00102)
#define PR_PROFILE_SECURE_MAILBOX_ERROR (0x67f0000a)
#define PR_MAILBEAT_BOUNCE_SERVER (0x6800001e)
#define PR_MAILBEAT_BOUNCE_SERVER_UNICODE (0x6800001f)
#define PR_MAILBEAT_BOUNCE_SERVER_ERROR (0x6800000a)
#define PR_MAILBEAT_REQUEST_SENT (0x68010040)
#define PR_MAILBEAT_REQUEST_SENT_ERROR (0x6801000a)
#define PR_USENET_SITE_NAME (0x6802001e)
#define PR_USENET_SITE_NAME_UNICODE (0x6802001f)
#define PR_USENET_SITE_NAME_ERROR (0x6802000a)
#define PR_MAILBEAT_REQUEST_RECEIVED (0x68030040)
#define PR_MAILBEAT_REQUEST_RECEIVED_ERROR (0x6803000a)
#define PR_MAILBEAT_REQUEST_PROCESSED (0x68040040)
#define PR_MAILBEAT_REQUEST_PROCESSED_ERROR (0x6804000a)
#define PR_MAILBEAT_REPLY_SENT (0x68060040)
#define PR_MAILBEAT_REPLY_SENT_ERROR (0x6806000a)
#define PR_MAILBEAT_REPLY_SUBMIT (0x68070040)
#define PR_MAILBEAT_REPLY_SUBMIT_ERROR (0x6807000a)
#define PR_MAILBEAT_REPLY_RECEIVED (0x68080040)
#define PR_MAILBEAT_REPLY_RECEIVED_ERROR (0x6808000a)
#define PR_MAILBEAT_REPLY_PROCESSED (0x68090040)
#define PR_MAILBEAT_REPLY_PROCESSED_ERROR (0x6809000a)
#define PR_DELEGATES_DISPLAY_NAMES (0x6844101e)
#define PR_DELEGATES_DISPLAY_NAMES_UNICODE (0x6844101f)
#define PR_DELEGATES_DISPLAY_NAMES_ERROR (0x6844000a)
#define PR_DELEGATES_ENTRYIDS (0x68451102)
#define PR_DELEGATES_ENTRYIDS_ERROR (0x6845000a)
#define PR_FREEBUSY_START_RANGE (0x68470003)
#define PR_FREEBUSY_START_RANGE_ERROR (0x6847000a)
#define PR_FREEBUSY_END_RANGE (0x68480003)
#define PR_FREEBUSY_END_RANGE_ERROR (0x6848000a)
#define PR_FREEBUSY_EMAIL_ADDRESS (0x6849001e)
#define PR_FREEBUSY_EMAIL_ADDRESS_UNICODE (0x6849001f)
#define PR_FREEBUSY_EMAIL_ADDRESS_ERROR (0x6849000a)
#define PR_FREEBUSY_ALL_MONTHS (0x684f1003)
#define PR_FREEBUSY_ALL_MONTHS_ERROR (0x684f000a)
#define PR_FREEBUSY_ALL_EVENTS (0x68501102)
#define PR_FREEBUSY_ALL_EVENTS_ERROR (0x6850000a)
#define PR_FREEBUSY_TENTATIVE_MONTHS (0x68511003)
#define PR_FREEBUSY_TENTATIVE_MONTHS_ERROR (0x6851000a)
#define PR_FREEBUSY_TENTATIVE_EVENTS (0x68521102)
#define PR_FREEBUSY_TENTATIVE_EVENTS_ERROR (0x6852000a)
#define PR_FREEBUSY_BUSY_MONTHS (0x68531003)
#define PR_FREEBUSY_BUSY_MONTHS_ERROR (0x6853000a)
#define PR_FREEBUSY_BUSY_EVENTS (0x68541102)
#define PR_FREEBUSY_BUSY_EVENTS_ERROR (0x6854000a)
#define PR_FREEBUSY_OOF_MONTHS (0x68551003)
#define PR_FREEBUSY_OOF_MONTHS_ERROR (0x6855000a)
#define PR_FREEBUSY_OOF_EVENTS (0x68561102)
#define PR_FREEBUSY_OOF_EVENTS_ERROR (0x6856000a)
#define PR_FREEBUSY_LAST_MODIFIED (0x68680040)
#define PR_FREEBUSY_LAST_MODIFIED_ERROR (0x6868000a)
#define PR_FREEBUSY_NUM_MONTHS (0x68690003)
#define PR_FREEBUSY_NUM_MONTHS_ERROR (0x6869000a)
#define PR_DELEGATES_SEE_PRIVATE (0x686b1003)
#define PR_DELEGATES_SEE_PRIVATE_ERROR (0x686b000a)
#define PR_PERSONAL_FREEBUSY (0x686c0102)
#define PR_PERSONAL_FREEBUSY_ERROR (0x686c000a)
#define PR_PROCESS_MEETING_REQUESTS (0x686d000b)
#define PR_PROCESS_MEETING_REQUESTS_ERROR (0x686d000a)
#define PR_DECLINE_RECURRING_MEETING_REQUESTS (0x686e000b)
#define PR_DECLINE_RECURRING_MEETING_REQUESTS_ERROR (0x686e000a)
#define PR_DECLINE_CONFLICTING_MEETING_REQUESTS (0x686f000b)
#define PR_DECLINE_CONFLICTING_MEETING_REQUESTS_ERROR (0x686f000a)
#define PR_VD_BINARY (0x70010102)
#define PR_VD_BINARY_ERROR (0x7001000a)
#define PR_VD_STRINGS (0x7002001e)
#define PR_VD_STRINGS_UNICODE (0x7002001f)
#define PR_VD_STRINGS_ERROR (0x7002000a)
#define PR_VD_FLAGS (0x70030003)
#define PR_VD_FLAGS_ERROR (0x7003000a)
#define PR_VD_LINK_TO (0x70040102)
#define PR_VD_LINK_TO_ERROR (0x7004000a)
#define PR_VD_VIEW_FOLDER (0x70050102)
#define PR_VD_VIEW_FOLDER_ERROR (0x7005000a)
#define PR_VD_NAME (0x7006001e)
#define PR_VD_NAME_UNICODE (0x7006001f)
#define PR_VD_NAME_ERROR (0x7006000a)
#define PR_VD_VERSION (0x70070003)
#define PR_VD_VERSION_ERROR (0x7007000a)
#define PR_FAV_DISPLAY_NAME_A (0x7c00001e)
#define PR_FAV_DISPLAY_NAME_A_UNICODE (0x7c00001f)
#define PR_FAV_DISPLAY_NAME_A_ERROR (0x7c00000a)
#define PR_FAV_PUBLIC_SOURCE_KEY (0x7c020102)
#define PR_FAV_PUBLIC_SOURCE_KEY_ERROR (0x7c02000a)
#define PR_OST_OSTID (0x7c040102)
#define PR_OST_OSTID_ERROR (0x7c04000a)
#define PR_STORE_SLOWLINK (0x7c0a000b)
#define PR_STORE_SLOWLINK_ERROR (0x7c0a000a)
#define PR_FAV_AUTOSUBFOLDERS (0x7d010003)
#define PR_FAV_AUTOSUBFOLDERS_ERROR (0x7d01000a)
#define PR_FAV_PARENT_SOURCE_KEY (0x7d020102)
#define PR_FAV_PARENT_SOURCE_KEY_ERROR (0x7d02000a)
#define PR_FAV_LEVEL_MASK (0x7d030003)
#define PR_FAV_LEVEL_MASK_ERROR (0x7d03000a)
#define PR_FAV_INHERIT_AUTO (0x7d070003)
#define PR_FAV_INHERIT_AUTO_ERROR (0x7d07000a)
#define PR_FAV_DEL_SUBS (0x7d080102)
#define PR_FAV_DEL_SUBS_ERROR (0x7d08000a)
#define PR_ATTACHMENT_LINKID (0x7ffa0003)
#define PR_ATTACHMENT_LINKID_ERROR (0x7ffa000a)
#define PR_EXCEPTION_STARTTIME (0x7ffb0040)
#define PR_EXCEPTION_STARTTIME_ERROR (0x7ffb000a)
#define PR_EXCEPTION_ENDTIME (0x7ffc0040)
#define PR_EXCEPTION_ENDTIME_ERROR (0x7ffc000a)
#define PR_ATTACHMENT_FLAGS (0x7ffd0003)
#define PR_ATTACHMENT_FLAGS_ERROR (0x7ffd000a)
#define PR_ATTACHMENT_HIDDEN (0x7ffe000b)
#define PR_ATTACHMENT_HIDDEN_ERROR (0x7ffe000a)
#define PR_EMS_AB_DISPLAY_NAME_OVERRIDE (0x8001000b)
#define PR_EMS_AB_DISPLAY_NAME_OVERRIDE_ERROR (0x8001000a)
#define PR_EMS_AB_CA_CERTIFICATE (0x80031102)
#define PR_EMS_AB_CA_CERTIFICATE_ERROR (0x8003000a)
#define PR_EMS_AB_FOLDER_PATHNAME (0x8004001e)
#define PR_EMS_AB_FOLDER_PATHNAME_UNICODE (0x8004001f)
#define PR_EMS_AB_FOLDER_PATHNAME_ERROR (0x8004000a)
#define PR_EMS_AB_MANAGER (0x8005000d)
#define PR_EMS_AB_MANAGER_ERROR (0x8005000a)
#define PR_EMS_AB_MANAGER_T (0x8005001e)
#define PR_EMS_AB_MANAGER_T_UNICODE (0x8005001f)
#define PR_EMS_AB_HOME_MDB_O (0x8006000d)
#define PR_EMS_AB_HOME_MDB_O_ERROR (0x8006000a)
#define PR_EMS_AB_HOME_MDB (0x8006001e)
#define PR_EMS_AB_HOME_MDB_UNICODE (0x8006001f)
#define PR_EMS_AB_HOME_MTA_O (0x8007000d)
#define PR_EMS_AB_HOME_MTA_O_ERROR (0x8007000a)
#define PR_EMS_AB_HOME_MTA (0x8007001e)
#define PR_EMS_AB_HOME_MTA_UNICODE (0x8007001f)
#define PR_EMS_AB_IS_MEMBER_OF_DL (0x8008000d)
#define PR_EMS_AB_IS_MEMBER_OF_DL_ERROR (0x8008000a)
#define PR_EMS_AB_IS_MEMBER_OF_DL_T (0x8008001e)
#define PR_EMS_AB_IS_MEMBER_OF_DL_T_UNICODE (0x8008001f)
#define PR_EMS_AB_MEMBER (0x8009000d)
#define PR_EMS_AB_MEMBER_ERROR (0x8009000a)
#define PR_EMS_AB_MEMBER_T (0x8009001e)
#define PR_EMS_AB_MEMBER_T_UNICODE (0x8009001f)
#define PR_EMS_AB_AUTOREPLY_MESSAGE (0x800a001e)
#define PR_EMS_AB_AUTOREPLY_MESSAGE_UNICODE (0x800a001f)
#define PR_EMS_AB_AUTOREPLY_MESSAGE_ERROR (0x800a000a)
#define PR_EMS_AB_AUTOREPLY (0x800b000b)
#define PR_EMS_AB_AUTOREPLY_ERROR (0x800b000a)
#define PR_EMS_AB_OWNER_O (0x800c000d)
#define PR_EMS_AB_OWNER_O_ERROR (0x800c000a)
#define PR_EMS_AB_OWNER (0x800c001e)
#define PR_EMS_AB_OWNER_UNICODE (0x800c001f)
#define PR_EMS_AB_KM_SERVER_O (0x800d000d)
#define PR_EMS_AB_KM_SERVER_O_ERROR (0x800d000a)
#define PR_EMS_AB_KM_SERVER (0x800d001e)
#define PR_EMS_AB_KM_SERVER_UNICODE (0x800d001f)
#define PR_EMS_AB_REPORTS (0x800e000d)
#define PR_EMS_AB_REPORTS_ERROR (0x800e000a)
#define PR_EMS_AB_PROXY_ADDRESSES (0x800f101e)
#define PR_EMS_AB_PROXY_ADDRESSES_UNICODE (0x800f101f)
#define PR_EMS_AB_PROXY_ADDRESSES_ERROR (0x800f000a)
#define PR_EMS_AB_HELP_DATA32 (0x80100102)
#define PR_EMS_AB_HELP_DATA32_ERROR (0x8010000a)
#define PR_EMS_AB_TARGET_ADDRESS (0x8011001e)
#define PR_EMS_AB_TARGET_ADDRESS_UNICODE (0x8011001f)
#define PR_EMS_AB_TARGET_ADDRESS_ERROR (0x8011000a)
#define PR_EMS_AB_TELEPHONE_NUMBER (0x8012101e)
#define PR_EMS_AB_TELEPHONE_NUMBER_UNICODE (0x8012101f)
#define PR_EMS_AB_TELEPHONE_NUMBER_ERROR (0x8012000a)
#define PR_EMS_AB_NT_SECURITY_DESCRIPTOR (0x80130102)
#define PR_EMS_AB_NT_SECURITY_DESCRIPTOR_ERROR (0x8013000a)
#define PR_EMS_AB_HOME_MDB_BL_O (0x8014000d)
#define PR_EMS_AB_HOME_MDB_BL_O_ERROR (0x8014000a)
#define PR_EMS_AB_HOME_MDB_BL (0x8014101e)
#define PR_EMS_AB_HOME_MDB_BL_UNICODE (0x8014101f)
#define PR_EMS_AB_PUBLIC_DELEGATES (0x8015000d)
#define PR_EMS_AB_PUBLIC_DELEGATES_ERROR (0x8015000a)
#define PR_EMS_AB_PUBLIC_DELEGATES_T (0x8015001e)
#define PR_EMS_AB_PUBLIC_DELEGATES_T_UNICODE (0x8015001f)
#define PR_EMS_AB_CERTIFICATE_REVOCATION_LIST (0x80160102)
#define PR_EMS_AB_CERTIFICATE_REVOCATION_LIST_ERROR (0x8016000a)
#define PR_EMS_AB_ADDRESS_ENTRY_DISPLAY_TABLE (0x80170102)
#define PR_EMS_AB_ADDRESS_ENTRY_DISPLAY_TABLE_ERROR (0x8017000a)
#define PR_EMS_AB_ADDRESS_SYNTAX (0x80180102)
#define PR_EMS_AB_ADDRESS_SYNTAX_ERROR (0x8018000a)
#define PR_EMS_AB_BUSINESS_ROLES (0x80230102)
#define PR_EMS_AB_BUSINESS_ROLES_ERROR (0x8023000a)
#define PR_EMS_AB_OWNER_BL_O (0x8024000d)
#define PR_EMS_AB_OWNER_BL_O_ERROR (0x8024000a)
#define PR_EMS_AB_OWNER_BL (0x8024101e)
#define PR_EMS_AB_OWNER_BL_UNICODE (0x8024101f)
#define PR_EMS_AB_CROSS_CERTIFICATE_PAIR (0x80251102)
#define PR_EMS_AB_CROSS_CERTIFICATE_PAIR_ERROR (0x8025000a)
#define PR_EMS_AB_AUTHORITY_REVOCATION_LIST (0x80261102)
#define PR_EMS_AB_AUTHORITY_REVOCATION_LIST_ERROR (0x8026000a)
#define PR_EMS_AB_ASSOC_NT_ACCOUNT (0x80270102)
#define PR_EMS_AB_ASSOC_NT_ACCOUNT_ERROR (0x8027000a)
#define PR_EMS_AB_EXPIRATION_TIME (0x80280040)
#define PR_EMS_AB_EXPIRATION_TIME_ERROR (0x8028000a)
#define PR_EMS_AB_USN_CHANGED (0x80290003)
#define PR_EMS_AB_USN_CHANGED_ERROR (0x8029000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_1 (0x802d001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_1_UNICODE (0x802d001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_1_ERROR (0x802d000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_2 (0x802e001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_2_UNICODE (0x802e001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_2_ERROR (0x802e000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_3 (0x802f001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_3_UNICODE (0x802f001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_3_ERROR (0x802f000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_4 (0x8030001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_4_UNICODE (0x8030001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_4_ERROR (0x8030000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_5 (0x8031001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_5_UNICODE (0x8031001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_5_ERROR (0x8031000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_6 (0x8032001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_6_UNICODE (0x8032001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_6_ERROR (0x8032000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_7 (0x8033001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_7_UNICODE (0x8033001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_7_ERROR (0x8033000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_8 (0x8034001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_8_UNICODE (0x8034001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_8_ERROR (0x8034000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_9 (0x8035001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_9_UNICODE (0x8035001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_9_ERROR (0x8035000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_10 (0x8036001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_10_UNICODE (0x8036001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_10_ERROR (0x8036000a)
#define PR_EMS_AB_SECURITY_PROTOCOL (0x80371102)
#define PR_EMS_AB_SECURITY_PROTOCOL_ERROR (0x8037000a)
#define PR_EMS_AB_PF_CONTACTS_O (0x8038000d)
#define PR_EMS_AB_PF_CONTACTS_O_ERROR (0x8038000a)
#define PR_EMS_AB_PF_CONTACTS (0x8038101e)
#define PR_EMS_AB_PF_CONTACTS_UNICODE (0x8038101f)
#define PR_EMS_AB_HELP_DATA16 (0x803a0102)
#define PR_EMS_AB_HELP_DATA16_ERROR (0x803a000a)
#define PR_EMS_AB_HELP_FILE_NAME (0x803b001e)
#define PR_EMS_AB_HELP_FILE_NAME_UNICODE (0x803b001f)
#define PR_EMS_AB_HELP_FILE_NAME_ERROR (0x803b000a)
#define PR_EMS_AB_OBJ_DIST_NAME_O (0x803c000d)
#define PR_EMS_AB_OBJ_DIST_NAME_O_ERROR (0x803c000a)
#define PR_EMS_AB_OBJ_DIST_NAME (0x803c001e)
#define PR_EMS_AB_OBJ_DIST_NAME_UNICODE (0x803c001f)
#define PR_EMS_AB_ENCRYPT_ALG_SELECTED_OTHER (0x803d001e)
#define PR_EMS_AB_ENCRYPT_ALG_SELECTED_OTHER_UNICODE (0x803d001f)
#define PR_EMS_AB_ENCRYPT_ALG_SELECTED_OTHER_ERROR (0x803d000a)
#define PR_EMS_AB_AUTOREPLY_SUBJECT (0x803e001e)
#define PR_EMS_AB_AUTOREPLY_SUBJECT_UNICODE (0x803e001f)
#define PR_EMS_AB_AUTOREPLY_SUBJECT_ERROR (0x803e000a)
#define PR_EMS_AB_HOME_PUBLIC_SERVER_O (0x803f000d)
#define PR_EMS_AB_HOME_PUBLIC_SERVER_O_ERROR (0x803f000a)
#define PR_EMS_AB_HOME_PUBLIC_SERVER (0x803f001e)
#define PR_EMS_AB_HOME_PUBLIC_SERVER_UNICODE (0x803f001f)
#define PR_EMS_AB_ENCRYPT_ALG_LIST_NA (0x8040101e)
#define PR_EMS_AB_ENCRYPT_ALG_LIST_NA_UNICODE (0x8040101f)
#define PR_EMS_AB_ENCRYPT_ALG_LIST_NA_ERROR (0x8040000a)
#define PR_EMS_AB_ENCRYPT_ALG_LIST_OTHER (0x8041101e)
#define PR_EMS_AB_ENCRYPT_ALG_LIST_OTHER_UNICODE (0x8041101f)
#define PR_EMS_AB_ENCRYPT_ALG_LIST_OTHER_ERROR (0x8041000a)
#define PR_EMS_AB_IMPORTED_FROM (0x8042001e)
#define PR_EMS_AB_IMPORTED_FROM_UNICODE (0x8042001f)
#define PR_EMS_AB_IMPORTED_FROM_ERROR (0x8042000a)
#define PR_EMS_AB_ENCRYPT_ALG_SELECTED_NA (0x8043001e)
#define PR_EMS_AB_ENCRYPT_ALG_SELECTED_NA_UNICODE (0x8043001f)
#define PR_EMS_AB_ENCRYPT_ALG_SELECTED_NA_ERROR (0x8043000a)
#define PR_EMS_AB_ACCESS_CATEGORY (0x80440003)
#define PR_EMS_AB_ACCESS_CATEGORY_ERROR (0x8044000a)
#define PR_EMS_AB_ACTIVATION_SCHEDULE (0x80450102)
#define PR_EMS_AB_ACTIVATION_SCHEDULE_ERROR (0x8045000a)
#define PR_EMS_AB_ACTIVATION_STYLE (0x80460003)
#define PR_EMS_AB_ACTIVATION_STYLE_ERROR (0x8046000a)
#define PR_EMS_AB_ADDRESS_ENTRY_DISPLAY_TABLE_MSDOS (0x80470102)
#define PR_EMS_AB_ADDRESS_ENTRY_DISPLAY_TABLE_MSDOS_ERROR (0x8047000a)
#define PR_EMS_AB_ADDRESS_TYPE (0x8048001e)
#define PR_EMS_AB_ADDRESS_TYPE_UNICODE (0x8048001f)
#define PR_EMS_AB_ADDRESS_TYPE_ERROR (0x8048000a)
#define PR_EMS_AB_ADMD (0x8049001e)
#define PR_EMS_AB_ADMD_UNICODE (0x8049001f)
#define PR_EMS_AB_ADMD_ERROR (0x8049000a)
#define PR_EMS_AB_ADMIN_DESCRIPTION (0x804a001e)
#define PR_EMS_AB_ADMIN_DESCRIPTION_UNICODE (0x804a001f)
#define PR_EMS_AB_ADMIN_DESCRIPTION_ERROR (0x804a000a)
#define PR_EMS_AB_ADMIN_DISPLAY_NAME (0x804b001e)
#define PR_EMS_AB_ADMIN_DISPLAY_NAME_UNICODE (0x804b001f)
#define PR_EMS_AB_ADMIN_DISPLAY_NAME_ERROR (0x804b000a)
#define PR_EMS_AB_ADMIN_EXTENSION_DLL (0x804c001e)
#define PR_EMS_AB_ADMIN_EXTENSION_DLL_UNICODE (0x804c001f)
#define PR_EMS_AB_ADMIN_EXTENSION_DLL_ERROR (0x804c000a)
#define PR_EMS_AB_ALIASED_OBJECT_NAME_O (0x804d000d)
#define PR_EMS_AB_ALIASED_OBJECT_NAME_O_ERROR (0x804d000a)
#define PR_EMS_AB_ALIASED_OBJECT_NAME (0x804d001e)
#define PR_EMS_AB_ALIASED_OBJECT_NAME_UNICODE (0x804d001f)
#define PR_EMS_AB_ALT_RECIPIENT_O (0x804e000d)
#define PR_EMS_AB_ALT_RECIPIENT_O_ERROR (0x804e000a)
#define PR_EMS_AB_ALT_RECIPIENT (0x804e001e)
#define PR_EMS_AB_ALT_RECIPIENT_UNICODE (0x804e001f)
#define PR_EMS_AB_ALT_RECIPIENT_BL_O (0x804f000d)
#define PR_EMS_AB_ALT_RECIPIENT_BL_O_ERROR (0x804f000a)
#define PR_EMS_AB_ALT_RECIPIENT_BL (0x804f101e)
#define PR_EMS_AB_ALT_RECIPIENT_BL_UNICODE (0x804f101f)
#define PR_EMS_AB_ANCESTOR_ID (0x80500102)
#define PR_EMS_AB_ANCESTOR_ID_ERROR (0x8050000a)
#define PR_EMS_AB_ASSOC_REMOTE_DXA_O (0x8051000d)
#define PR_EMS_AB_ASSOC_REMOTE_DXA_O_ERROR (0x8051000a)
#define PR_EMS_AB_ASSOC_REMOTE_DXA (0x8051101e)
#define PR_EMS_AB_ASSOC_REMOTE_DXA_UNICODE (0x8051101f)
#define PR_EMS_AB_ASSOCIATION_LIFETIME (0x80520003)
#define PR_EMS_AB_ASSOCIATION_LIFETIME_ERROR (0x8052000a)
#define PR_EMS_AB_AUTH_ORIG_BL_O (0x8053000d)
#define PR_EMS_AB_AUTH_ORIG_BL_O_ERROR (0x8053000a)
#define PR_EMS_AB_AUTH_ORIG_BL (0x8053101e)
#define PR_EMS_AB_AUTH_ORIG_BL_UNICODE (0x8053101f)
#define PR_EMS_AB_AUTHORIZED_DOMAIN (0x8054001e)
#define PR_EMS_AB_AUTHORIZED_DOMAIN_UNICODE (0x8054001f)
#define PR_EMS_AB_AUTHORIZED_DOMAIN_ERROR (0x8054000a)
#define PR_EMS_AB_AUTHORIZED_PASSWORD (0x80550102)
#define PR_EMS_AB_AUTHORIZED_PASSWORD_ERROR (0x8055000a)
#define PR_EMS_AB_AUTHORIZED_USER (0x8056001e)
#define PR_EMS_AB_AUTHORIZED_USER_UNICODE (0x8056001f)
#define PR_EMS_AB_AUTHORIZED_USER_ERROR (0x8056000a)
#define PR_EMS_AB_BUSINESS_CATEGORY (0x8057101e)
#define PR_EMS_AB_BUSINESS_CATEGORY_UNICODE (0x8057101f)
#define PR_EMS_AB_BUSINESS_CATEGORY_ERROR (0x8057000a)
#define PR_EMS_AB_CAN_CREATE_PF_O (0x8058000d)
#define PR_EMS_AB_CAN_CREATE_PF_O_ERROR (0x8058000a)
#define PR_EMS_AB_CAN_CREATE_PF (0x8058101e)
#define PR_EMS_AB_CAN_CREATE_PF_UNICODE (0x8058101f)
#define PR_EMS_AB_CAN_CREATE_PF_BL_O (0x8059000d)
#define PR_EMS_AB_CAN_CREATE_PF_BL_O_ERROR (0x8059000a)
#define PR_EMS_AB_CAN_CREATE_PF_BL (0x8059101e)
#define PR_EMS_AB_CAN_CREATE_PF_BL_UNICODE (0x8059101f)
#define PR_EMS_AB_CAN_CREATE_PF_DL_O (0x805a000d)
#define PR_EMS_AB_CAN_CREATE_PF_DL_O_ERROR (0x805a000a)
#define PR_EMS_AB_CAN_CREATE_PF_DL (0x805a101e)
#define PR_EMS_AB_CAN_CREATE_PF_DL_UNICODE (0x805a101f)
#define PR_EMS_AB_CAN_CREATE_PF_DL_BL_O (0x805b000d)
#define PR_EMS_AB_CAN_CREATE_PF_DL_BL_O_ERROR (0x805b000a)
#define PR_EMS_AB_CAN_CREATE_PF_DL_BL (0x805b101e)
#define PR_EMS_AB_CAN_CREATE_PF_DL_BL_UNICODE (0x805b101f)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_O (0x805c000d)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_O_ERROR (0x805c000a)
#define PR_EMS_AB_CAN_NOT_CREATE_PF (0x805c101e)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_UNICODE (0x805c101f)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_BL_O (0x805d000d)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_BL_O_ERROR (0x805d000a)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_BL (0x805d101e)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_BL_UNICODE (0x805d101f)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_DL_O (0x805e000d)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_DL_O_ERROR (0x805e000a)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_DL (0x805e101e)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_DL_UNICODE (0x805e101f)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_DL_BL_O (0x805f000d)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_DL_BL_O_ERROR (0x805f000a)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_DL_BL (0x805f101e)
#define PR_EMS_AB_CAN_NOT_CREATE_PF_DL_BL_UNICODE (0x805f101f)
#define PR_EMS_AB_CAN_PRESERVE_DNS (0x8060000b)
#define PR_EMS_AB_CAN_PRESERVE_DNS_ERROR (0x8060000a)
#define PR_EMS_AB_CLOCK_ALERT_OFFSET (0x80610003)
#define PR_EMS_AB_CLOCK_ALERT_OFFSET_ERROR (0x8061000a)
#define PR_EMS_AB_CLOCK_ALERT_REPAIR (0x8062000b)
#define PR_EMS_AB_CLOCK_ALERT_REPAIR_ERROR (0x8062000a)
#define PR_EMS_AB_CLOCK_WARNING_OFFSET (0x80630003)
#define PR_EMS_AB_CLOCK_WARNING_OFFSET_ERROR (0x8063000a)
#define PR_EMS_AB_CLOCK_WARNING_REPAIR (0x8064000b)
#define PR_EMS_AB_CLOCK_WARNING_REPAIR_ERROR (0x8064000a)
#define PR_EMS_AB_COMPUTER_NAME (0x8065001e)
#define PR_EMS_AB_COMPUTER_NAME_UNICODE (0x8065001f)
#define PR_EMS_AB_COMPUTER_NAME_ERROR (0x8065000a)
#define PR_EMS_AB_CONNECTED_DOMAINS (0x8066101e)
#define PR_EMS_AB_CONNECTED_DOMAINS_UNICODE (0x8066101f)
#define PR_EMS_AB_CONNECTED_DOMAINS_ERROR (0x8066000a)
#define PR_EMS_AB_CONTAINER_INFO (0x80670003)
#define PR_EMS_AB_CONTAINER_INFO_ERROR (0x8067000a)
#define PR_EMS_AB_COST (0x80680003)
#define PR_EMS_AB_COST_ERROR (0x8068000a)
#define PR_EMS_AB_COUNTRY_NAME (0x8069001e)
#define PR_EMS_AB_COUNTRY_NAME_UNICODE (0x8069001f)
#define PR_EMS_AB_COUNTRY_NAME_ERROR (0x8069000a)
#define PR_EMS_AB_DELIV_CONT_LENGTH (0x806a0003)
#define PR_EMS_AB_DELIV_CONT_LENGTH_ERROR (0x806a000a)
#define PR_EMS_AB_DELIV_EITS (0x806b1102)
#define PR_EMS_AB_DELIV_EITS_ERROR (0x806b000a)
#define PR_EMS_AB_DELIV_EXT_CONT_TYPES (0x806c1102)
#define PR_EMS_AB_DELIV_EXT_CONT_TYPES_ERROR (0x806c000a)
#define PR_EMS_AB_DELIVER_AND_REDIRECT (0x806d000b)
#define PR_EMS_AB_DELIVER_AND_REDIRECT_ERROR (0x806d000a)
#define PR_EMS_AB_DELIVERY_MECHANISM (0x806e0003)
#define PR_EMS_AB_DELIVERY_MECHANISM_ERROR (0x806e000a)
#define PR_EMS_AB_DESCRIPTION (0x806f101e)
#define PR_EMS_AB_DESCRIPTION_UNICODE (0x806f101f)
#define PR_EMS_AB_DESCRIPTION_ERROR (0x806f000a)
#define PR_EMS_AB_DESTINATION_INDICATOR (0x8070101e)
#define PR_EMS_AB_DESTINATION_INDICATOR_UNICODE (0x8070101f)
#define PR_EMS_AB_DESTINATION_INDICATOR_ERROR (0x8070000a)
#define PR_EMS_AB_DIAGNOSTIC_REG_KEY (0x8071001e)
#define PR_EMS_AB_DIAGNOSTIC_REG_KEY_UNICODE (0x8071001f)
#define PR_EMS_AB_DIAGNOSTIC_REG_KEY_ERROR (0x8071000a)
#define PR_EMS_AB_DL_MEM_REJECT_PERMS_BL_O (0x8072000d)
#define PR_EMS_AB_DL_MEM_REJECT_PERMS_BL_O_ERROR (0x8072000a)
#define PR_EMS_AB_DL_MEM_REJECT_PERMS_BL (0x8072101e)
#define PR_EMS_AB_DL_MEM_REJECT_PERMS_BL_UNICODE (0x8072101f)
#define PR_EMS_AB_DL_MEM_SUBMIT_PERMS_BL_O (0x8073000d)
#define PR_EMS_AB_DL_MEM_SUBMIT_PERMS_BL_O_ERROR (0x8073000a)
#define PR_EMS_AB_DL_MEM_SUBMIT_PERMS_BL (0x8073101e)
#define PR_EMS_AB_DL_MEM_SUBMIT_PERMS_BL_UNICODE (0x8073101f)
#define PR_EMS_AB_DL_MEMBER_RULE (0x80741102)
#define PR_EMS_AB_DL_MEMBER_RULE_ERROR (0x8074000a)
#define PR_EMS_AB_DOMAIN_DEF_ALT_RECIP_O (0x8075000d)
#define PR_EMS_AB_DOMAIN_DEF_ALT_RECIP_O_ERROR (0x8075000a)
#define PR_EMS_AB_DOMAIN_DEF_ALT_RECIP (0x8075001e)
#define PR_EMS_AB_DOMAIN_DEF_ALT_RECIP_UNICODE (0x8075001f)
#define PR_EMS_AB_DOMAIN_NAME (0x8076001e)
#define PR_EMS_AB_DOMAIN_NAME_UNICODE (0x8076001f)
#define PR_EMS_AB_DOMAIN_NAME_ERROR (0x8076000a)
#define PR_EMS_AB_DSA_SIGNATURE (0x80770102)
#define PR_EMS_AB_DSA_SIGNATURE_ERROR (0x8077000a)
#define PR_EMS_AB_DXA_ADMIN_COPY (0x8078000b)
#define PR_EMS_AB_DXA_ADMIN_COPY_ERROR (0x8078000a)
#define PR_EMS_AB_DXA_ADMIN_FORWARD (0x8079000b)
#define PR_EMS_AB_DXA_ADMIN_FORWARD_ERROR (0x8079000a)
#define PR_EMS_AB_DXA_ADMIN_UPDATE (0x807a0003)
#define PR_EMS_AB_DXA_ADMIN_UPDATE_ERROR (0x807a000a)
#define PR_EMS_AB_DXA_APPEND_REQCN (0x807b000b)
#define PR_EMS_AB_DXA_APPEND_REQCN_ERROR (0x807b000a)
#define PR_EMS_AB_DXA_CONF_CONTAINER_LIST_O (0x807c000d)
#define PR_EMS_AB_DXA_CONF_CONTAINER_LIST_O_ERROR (0x807c000a)
#define PR_EMS_AB_DXA_CONF_CONTAINER_LIST (0x807c101e)
#define PR_EMS_AB_DXA_CONF_CONTAINER_LIST_UNICODE (0x807c101f)
#define PR_EMS_AB_DXA_CONF_REQ_TIME (0x807d0040)
#define PR_EMS_AB_DXA_CONF_REQ_TIME_ERROR (0x807d000a)
#define PR_EMS_AB_DXA_CONF_SEQ (0x807e001e)
#define PR_EMS_AB_DXA_CONF_SEQ_UNICODE (0x807e001f)
#define PR_EMS_AB_DXA_CONF_SEQ_ERROR (0x807e000a)
#define PR_EMS_AB_DXA_CONF_SEQ_USN (0x807f0003)
#define PR_EMS_AB_DXA_CONF_SEQ_USN_ERROR (0x807f000a)
#define PR_EMS_AB_DXA_EXCHANGE_OPTIONS (0x80800003)
#define PR_EMS_AB_DXA_EXCHANGE_OPTIONS_ERROR (0x8080000a)
#define PR_EMS_AB_DXA_EXPORT_NOW (0x8081000b)
#define PR_EMS_AB_DXA_EXPORT_NOW_ERROR (0x8081000a)
#define PR_EMS_AB_DXA_FLAGS (0x80820003)
#define PR_EMS_AB_DXA_FLAGS_ERROR (0x8082000a)
#define PR_EMS_AB_DXA_IMP_SEQ (0x8083001e)
#define PR_EMS_AB_DXA_IMP_SEQ_UNICODE (0x8083001f)
#define PR_EMS_AB_DXA_IMP_SEQ_ERROR (0x8083000a)
#define PR_EMS_AB_DXA_IMP_SEQ_TIME (0x80840040)
#define PR_EMS_AB_DXA_IMP_SEQ_TIME_ERROR (0x8084000a)
#define PR_EMS_AB_DXA_IMP_SEQ_USN (0x80850003)
#define PR_EMS_AB_DXA_IMP_SEQ_USN_ERROR (0x8085000a)
#define PR_EMS_AB_DXA_IMPORT_NOW (0x8086000b)
#define PR_EMS_AB_DXA_IMPORT_NOW_ERROR (0x8086000a)
#define PR_EMS_AB_DXA_IN_TEMPLATE_MAP (0x8087101e)
#define PR_EMS_AB_DXA_IN_TEMPLATE_MAP_UNICODE (0x8087101f)
#define PR_EMS_AB_DXA_IN_TEMPLATE_MAP_ERROR (0x8087000a)
#define PR_EMS_AB_DXA_LOCAL_ADMIN_O (0x8088000d)
#define PR_EMS_AB_DXA_LOCAL_ADMIN_O_ERROR (0x8088000a)
#define PR_EMS_AB_DXA_LOCAL_ADMIN (0x8088001e)
#define PR_EMS_AB_DXA_LOCAL_ADMIN_UNICODE (0x8088001f)
#define PR_EMS_AB_DXA_LOGGING_LEVEL (0x80890003)
#define PR_EMS_AB_DXA_LOGGING_LEVEL_ERROR (0x8089000a)
#define PR_EMS_AB_DXA_NATIVE_ADDRESS_TYPE (0x808a001e)
#define PR_EMS_AB_DXA_NATIVE_ADDRESS_TYPE_UNICODE (0x808a001f)
#define PR_EMS_AB_DXA_NATIVE_ADDRESS_TYPE_ERROR (0x808a000a)
#define PR_EMS_AB_DXA_OUT_TEMPLATE_MAP (0x808b101e)
#define PR_EMS_AB_DXA_OUT_TEMPLATE_MAP_UNICODE (0x808b101f)
#define PR_EMS_AB_DXA_OUT_TEMPLATE_MAP_ERROR (0x808b000a)
#define PR_EMS_AB_DXA_PASSWORD (0x808c001e)
#define PR_EMS_AB_DXA_PASSWORD_UNICODE (0x808c001f)
#define PR_EMS_AB_DXA_PASSWORD_ERROR (0x808c000a)
#define PR_EMS_AB_DXA_PREV_EXCHANGE_OPTIONS (0x808d0003)
#define PR_EMS_AB_DXA_PREV_EXCHANGE_OPTIONS_ERROR (0x808d000a)
#define PR_EMS_AB_DXA_PREV_EXPORT_NATIVE_ONLY (0x808e000b)
#define PR_EMS_AB_DXA_PREV_EXPORT_NATIVE_ONLY_ERROR (0x808e000a)
#define PR_EMS_AB_DXA_PREV_IN_EXCHANGE_SENSITIVITY (0x808f0003)
#define PR_EMS_AB_DXA_PREV_IN_EXCHANGE_SENSITIVITY_ERROR (0x808f000a)
#define PR_EMS_AB_DXA_PREV_REMOTE_ENTRIES_O (0x8090000d)
#define PR_EMS_AB_DXA_PREV_REMOTE_ENTRIES_O_ERROR (0x8090000a)
#define PR_EMS_AB_DXA_PREV_REMOTE_ENTRIES (0x8090001e)
#define PR_EMS_AB_DXA_PREV_REMOTE_ENTRIES_UNICODE (0x8090001f)
#define PR_EMS_AB_DXA_PREV_REPLICATION_SENSITIVITY (0x80910003)
#define PR_EMS_AB_DXA_PREV_REPLICATION_SENSITIVITY_ERROR (0x8091000a)
#define PR_EMS_AB_DXA_PREV_TEMPLATE_OPTIONS (0x80920003)
#define PR_EMS_AB_DXA_PREV_TEMPLATE_OPTIONS_ERROR (0x8092000a)
#define PR_EMS_AB_DXA_PREV_TYPES (0x80930003)
#define PR_EMS_AB_DXA_PREV_TYPES_ERROR (0x8093000a)
#define PR_EMS_AB_DXA_RECIPIENT_CP (0x8094001e)
#define PR_EMS_AB_DXA_RECIPIENT_CP_UNICODE (0x8094001f)
#define PR_EMS_AB_DXA_RECIPIENT_CP_ERROR (0x8094000a)
#define PR_EMS_AB_DXA_REMOTE_CLIENT_O (0x8095000d)
#define PR_EMS_AB_DXA_REMOTE_CLIENT_O_ERROR (0x8095000a)
#define PR_EMS_AB_DXA_REMOTE_CLIENT (0x8095001e)
#define PR_EMS_AB_DXA_REMOTE_CLIENT_UNICODE (0x8095001f)
#define PR_EMS_AB_DXA_REQ_SEQ (0x8096001e)
#define PR_EMS_AB_DXA_REQ_SEQ_UNICODE (0x8096001f)
#define PR_EMS_AB_DXA_REQ_SEQ_ERROR (0x8096000a)
#define PR_EMS_AB_DXA_REQ_SEQ_TIME (0x80970040)
#define PR_EMS_AB_DXA_REQ_SEQ_TIME_ERROR (0x8097000a)
#define PR_EMS_AB_DXA_REQ_SEQ_USN (0x80980003)
#define PR_EMS_AB_DXA_REQ_SEQ_USN_ERROR (0x8098000a)
#define PR_EMS_AB_DXA_REQNAME (0x8099001e)
#define PR_EMS_AB_DXA_REQNAME_UNICODE (0x8099001f)
#define PR_EMS_AB_DXA_REQNAME_ERROR (0x8099000a)
#define PR_EMS_AB_DXA_SVR_SEQ (0x809a001e)
#define PR_EMS_AB_DXA_SVR_SEQ_UNICODE (0x809a001f)
#define PR_EMS_AB_DXA_SVR_SEQ_ERROR (0x809a000a)
#define PR_EMS_AB_DXA_SVR_SEQ_TIME (0x809b0040)
#define PR_EMS_AB_DXA_SVR_SEQ_TIME_ERROR (0x809b000a)
#define PR_EMS_AB_DXA_SVR_SEQ_USN (0x809c0003)
#define PR_EMS_AB_DXA_SVR_SEQ_USN_ERROR (0x809c000a)
#define PR_EMS_AB_DXA_TASK (0x809d0003)
#define PR_EMS_AB_DXA_TASK_ERROR (0x809d000a)
#define PR_EMS_AB_DXA_TEMPLATE_OPTIONS (0x809e0003)
#define PR_EMS_AB_DXA_TEMPLATE_OPTIONS_ERROR (0x809e000a)
#define PR_EMS_AB_DXA_TEMPLATE_TIMESTAMP (0x809f0040)
#define PR_EMS_AB_DXA_TEMPLATE_TIMESTAMP_ERROR (0x809f000a)
#define PR_EMS_AB_DXA_TYPES (0x80a00003)
#define PR_EMS_AB_DXA_TYPES_ERROR (0x80a0000a)
#define PR_EMS_AB_DXA_UNCONF_CONTAINER_LIST_O (0x80a1000d)
#define PR_EMS_AB_DXA_UNCONF_CONTAINER_LIST_O_ERROR (0x80a1000a)
#define PR_EMS_AB_DXA_UNCONF_CONTAINER_LIST (0x80a1101e)
#define PR_EMS_AB_DXA_UNCONF_CONTAINER_LIST_UNICODE (0x80a1101f)
#define PR_EMS_AB_ENCAPSULATION_METHOD (0x80a20003)
#define PR_EMS_AB_ENCAPSULATION_METHOD_ERROR (0x80a2000a)
#define PR_EMS_AB_ENCRYPT (0x80a3000b)
#define PR_EMS_AB_ENCRYPT_ERROR (0x80a3000a)
#define PR_EMS_AB_EXPAND_DLS_LOCALLY (0x80a4000b)
#define PR_EMS_AB_EXPAND_DLS_LOCALLY_ERROR (0x80a4000a)
#define PR_EMS_AB_EXPORT_CONTAINERS_O (0x80a5000d)
#define PR_EMS_AB_EXPORT_CONTAINERS_O_ERROR (0x80a5000a)
#define PR_EMS_AB_EXPORT_CONTAINERS (0x80a5101e)
#define PR_EMS_AB_EXPORT_CONTAINERS_UNICODE (0x80a5101f)
#define PR_EMS_AB_EXPORT_CUSTOM_RECIPIENTS (0x80a6000b)
#define PR_EMS_AB_EXPORT_CUSTOM_RECIPIENTS_ERROR (0x80a6000a)
#define PR_EMS_AB_EXTENDED_CHARS_ALLOWED (0x80a7000b)
#define PR_EMS_AB_EXTENDED_CHARS_ALLOWED_ERROR (0x80a7000a)
#define PR_EMS_AB_EXTENSION_DATA (0x80a81102)
#define PR_EMS_AB_EXTENSION_DATA_ERROR (0x80a8000a)
#define PR_EMS_AB_EXTENSION_NAME (0x80a9101e)
#define PR_EMS_AB_EXTENSION_NAME_UNICODE (0x80a9101f)
#define PR_EMS_AB_EXTENSION_NAME_ERROR (0x80a9000a)
#define PR_EMS_AB_EXTENSION_NAME_INHERITED (0x80aa101e)
#define PR_EMS_AB_EXTENSION_NAME_INHERITED_UNICODE (0x80aa101f)
#define PR_EMS_AB_EXTENSION_NAME_INHERITED_ERROR (0x80aa000a)
#define PR_EMS_AB_FACSIMILE_TELEPHONE_NUMBER (0x80ab1102)
#define PR_EMS_AB_FACSIMILE_TELEPHONE_NUMBER_ERROR (0x80ab000a)
#define PR_EMS_AB_FILE_VERSION (0x80ac0102)
#define PR_EMS_AB_FILE_VERSION_ERROR (0x80ac000a)
#define PR_EMS_AB_FILTER_LOCAL_ADDRESSES (0x80ad000b)
#define PR_EMS_AB_FILTER_LOCAL_ADDRESSES_ERROR (0x80ad000a)
#define PR_EMS_AB_FOLDERS_CONTAINER_O (0x80ae000d)
#define PR_EMS_AB_FOLDERS_CONTAINER_O_ERROR (0x80ae000a)
#define PR_EMS_AB_FOLDERS_CONTAINER (0x80ae001e)
#define PR_EMS_AB_FOLDERS_CONTAINER_UNICODE (0x80ae001f)
#define PR_EMS_AB_GARBAGE_COLL_PERIOD (0x80af0003)
#define PR_EMS_AB_GARBAGE_COLL_PERIOD_ERROR (0x80af000a)
#define PR_EMS_AB_GATEWAY_LOCAL_CRED (0x80b0001e)
#define PR_EMS_AB_GATEWAY_LOCAL_CRED_UNICODE (0x80b0001f)
#define PR_EMS_AB_GATEWAY_LOCAL_CRED_ERROR (0x80b0000a)
#define PR_EMS_AB_GATEWAY_LOCAL_DESIG (0x80b1001e)
#define PR_EMS_AB_GATEWAY_LOCAL_DESIG_UNICODE (0x80b1001f)
#define PR_EMS_AB_GATEWAY_LOCAL_DESIG_ERROR (0x80b1000a)
#define PR_EMS_AB_GATEWAY_PROXY (0x80b2101e)
#define PR_EMS_AB_GATEWAY_PROXY_UNICODE (0x80b2101f)
#define PR_EMS_AB_GATEWAY_PROXY_ERROR (0x80b2000a)
#define PR_EMS_AB_GATEWAY_ROUTING_TREE (0x80b30102)
#define PR_EMS_AB_GATEWAY_ROUTING_TREE_ERROR (0x80b3000a)
#define PR_EMS_AB_GWART_LAST_MODIFIED (0x80b40040)
#define PR_EMS_AB_GWART_LAST_MODIFIED_ERROR (0x80b4000a)
#define PR_EMS_AB_HAS_FULL_REPLICA_NCS_O (0x80b5000d)
#define PR_EMS_AB_HAS_FULL_REPLICA_NCS_O_ERROR (0x80b5000a)
#define PR_EMS_AB_HAS_FULL_REPLICA_NCS (0x80b5101e)
#define PR_EMS_AB_HAS_FULL_REPLICA_NCS_UNICODE (0x80b5101f)
#define PR_EMS_AB_HAS_MASTER_NCS_O (0x80b6000d)
#define PR_EMS_AB_HAS_MASTER_NCS_O_ERROR (0x80b6000a)
#define PR_EMS_AB_HAS_MASTER_NCS (0x80b6101e)
#define PR_EMS_AB_HAS_MASTER_NCS_UNICODE (0x80b6101f)
#define PR_EMS_AB_HEURISTICS (0x80b70003)
#define PR_EMS_AB_HEURISTICS_ERROR (0x80b7000a)
#define PR_EMS_AB_HIDE_DL_MEMBERSHIP (0x80b8000b)
#define PR_EMS_AB_HIDE_DL_MEMBERSHIP_ERROR (0x80b8000a)
#define PR_EMS_AB_HIDE_FROM_ADDRESS_BOOK (0x80b9000b)
#define PR_EMS_AB_HIDE_FROM_ADDRESS_BOOK_ERROR (0x80b9000a)
#define PR_EMS_AB_IMPORT_CONTAINER_O (0x80ba000d)
#define PR_EMS_AB_IMPORT_CONTAINER_O_ERROR (0x80ba000a)
#define PR_EMS_AB_IMPORT_CONTAINER (0x80ba001e)
#define PR_EMS_AB_IMPORT_CONTAINER_UNICODE (0x80ba001f)
#define PR_EMS_AB_IMPORT_SENSITIVITY (0x80bb0003)
#define PR_EMS_AB_IMPORT_SENSITIVITY_ERROR (0x80bb000a)
#define PR_EMS_AB_INBOUND_SITES_O (0x80bc000d)
#define PR_EMS_AB_INBOUND_SITES_O_ERROR (0x80bc000a)
#define PR_EMS_AB_INBOUND_SITES (0x80bc101e)
#define PR_EMS_AB_INBOUND_SITES_UNICODE (0x80bc101f)
#define PR_EMS_AB_INSTANCE_TYPE (0x80bd0003)
#define PR_EMS_AB_INSTANCE_TYPE_ERROR (0x80bd000a)
#define PR_EMS_AB_INTERNATIONAL_ISDN_NUMBER (0x80be101e)
#define PR_EMS_AB_INTERNATIONAL_ISDN_NUMBER_UNICODE (0x80be101f)
#define PR_EMS_AB_INTERNATIONAL_ISDN_NUMBER_ERROR (0x80be000a)
#define PR_EMS_AB_INVOCATION_ID (0x80bf0102)
#define PR_EMS_AB_INVOCATION_ID_ERROR (0x80bf000a)
#define PR_EMS_AB_IS_DELETED (0x80c0000b)
#define PR_EMS_AB_IS_DELETED_ERROR (0x80c0000a)
#define PR_EMS_AB_IS_SINGLE_VALUED (0x80c1000b)
#define PR_EMS_AB_IS_SINGLE_VALUED_ERROR (0x80c1000a)
#define PR_EMS_AB_KCC_STATUS (0x80c21102)
#define PR_EMS_AB_KCC_STATUS_ERROR (0x80c2000a)
#define PR_EMS_AB_KNOWLEDGE_INFORMATION (0x80c3101e)
#define PR_EMS_AB_KNOWLEDGE_INFORMATION_UNICODE (0x80c3101f)
#define PR_EMS_AB_KNOWLEDGE_INFORMATION_ERROR (0x80c3000a)
#define PR_EMS_AB_LINE_WRAP (0x80c40003)
#define PR_EMS_AB_LINE_WRAP_ERROR (0x80c4000a)
#define PR_EMS_AB_LINK_ID (0x80c50003)
#define PR_EMS_AB_LINK_ID_ERROR (0x80c5000a)
#define PR_EMS_AB_LOCAL_BRIDGE_HEAD (0x80c6001e)
#define PR_EMS_AB_LOCAL_BRIDGE_HEAD_UNICODE (0x80c6001f)
#define PR_EMS_AB_LOCAL_BRIDGE_HEAD_ERROR (0x80c6000a)
#define PR_EMS_AB_LOCAL_BRIDGE_HEAD_ADDRESS (0x80c7001e)
#define PR_EMS_AB_LOCAL_BRIDGE_HEAD_ADDRESS_UNICODE (0x80c7001f)
#define PR_EMS_AB_LOCAL_BRIDGE_HEAD_ADDRESS_ERROR (0x80c7000a)
#define PR_EMS_AB_LOCAL_INITIAL_TURN (0x80c8000b)
#define PR_EMS_AB_LOCAL_INITIAL_TURN_ERROR (0x80c8000a)
#define PR_EMS_AB_LOCAL_SCOPE_O (0x80c9000d)
#define PR_EMS_AB_LOCAL_SCOPE_O_ERROR (0x80c9000a)
#define PR_EMS_AB_LOCAL_SCOPE (0x80c9101e)
#define PR_EMS_AB_LOCAL_SCOPE_UNICODE (0x80c9101f)
#define PR_EMS_AB_LOG_FILENAME (0x80ca001e)
#define PR_EMS_AB_LOG_FILENAME_UNICODE (0x80ca001f)
#define PR_EMS_AB_LOG_FILENAME_ERROR (0x80ca000a)
#define PR_EMS_AB_LOG_ROLLOVER_INTERVAL (0x80cb0003)
#define PR_EMS_AB_LOG_ROLLOVER_INTERVAL_ERROR (0x80cb000a)
#define PR_EMS_AB_MAINTAIN_AUTOREPLY_HISTORY (0x80cc000b)
#define PR_EMS_AB_MAINTAIN_AUTOREPLY_HISTORY_ERROR (0x80cc000a)
#define PR_EMS_AB_MAPI_DISPLAY_TYPE (0x80cd0003)
#define PR_EMS_AB_MAPI_DISPLAY_TYPE_ERROR (0x80cd000a)
#define PR_EMS_AB_MAPI_ID (0x80ce0003)
#define PR_EMS_AB_MAPI_ID_ERROR (0x80ce000a)
#define PR_EMS_AB_MDB_BACKOFF_INTERVAL (0x80cf0003)
#define PR_EMS_AB_MDB_BACKOFF_INTERVAL_ERROR (0x80cf000a)
#define PR_EMS_AB_MDB_MSG_TIME_OUT_PERIOD (0x80d00003)
#define PR_EMS_AB_MDB_MSG_TIME_OUT_PERIOD_ERROR (0x80d0000a)
#define PR_EMS_AB_MDB_OVER_QUOTA_LIMIT (0x80d10003)
#define PR_EMS_AB_MDB_OVER_QUOTA_LIMIT_ERROR (0x80d1000a)
#define PR_EMS_AB_MDB_STORAGE_QUOTA (0x80d20003)
#define PR_EMS_AB_MDB_STORAGE_QUOTA_ERROR (0x80d2000a)
#define PR_EMS_AB_MDB_UNREAD_LIMIT (0x80d30003)
#define PR_EMS_AB_MDB_UNREAD_LIMIT_ERROR (0x80d3000a)
#define PR_EMS_AB_MDB_USE_DEFAULTS (0x80d4000b)
#define PR_EMS_AB_MDB_USE_DEFAULTS_ERROR (0x80d4000a)
#define PR_EMS_AB_MESSAGE_TRACKING_ENABLED (0x80d5000b)
#define PR_EMS_AB_MESSAGE_TRACKING_ENABLED_ERROR (0x80d5000a)
#define PR_EMS_AB_MONITOR_CLOCK (0x80d6000b)
#define PR_EMS_AB_MONITOR_CLOCK_ERROR (0x80d6000a)
#define PR_EMS_AB_MONITOR_SERVERS (0x80d7000b)
#define PR_EMS_AB_MONITOR_SERVERS_ERROR (0x80d7000a)
#define PR_EMS_AB_MONITOR_SERVICES (0x80d8000b)
#define PR_EMS_AB_MONITOR_SERVICES_ERROR (0x80d8000a)
#define PR_EMS_AB_MONITORED_CONFIGURATIONS_O (0x80d9000d)
#define PR_EMS_AB_MONITORED_CONFIGURATIONS_O_ERROR (0x80d9000a)
#define PR_EMS_AB_MONITORED_CONFIGURATIONS (0x80d9101e)
#define PR_EMS_AB_MONITORED_CONFIGURATIONS_UNICODE (0x80d9101f)
#define PR_EMS_AB_MONITORED_SERVERS_O (0x80da000d)
#define PR_EMS_AB_MONITORED_SERVERS_O_ERROR (0x80da000a)
#define PR_EMS_AB_MONITORED_SERVERS (0x80da101e)
#define PR_EMS_AB_MONITORED_SERVERS_UNICODE (0x80da101f)
#define PR_EMS_AB_MONITORED_SERVICES (0x80db101e)
#define PR_EMS_AB_MONITORED_SERVICES_UNICODE (0x80db101f)
#define PR_EMS_AB_MONITORED_SERVICES_ERROR (0x80db000a)
#define PR_EMS_AB_MONITORING_ALERT_DELAY (0x80dc0003)
#define PR_EMS_AB_MONITORING_ALERT_DELAY_ERROR (0x80dc000a)
#define PR_EMS_AB_MONITORING_ALERT_UNITS (0x80dd0003)
#define PR_EMS_AB_MONITORING_ALERT_UNITS_ERROR (0x80dd000a)
#define PR_EMS_AB_MONITORING_AVAILABILITY_STYLE (0x80de0003)
#define PR_EMS_AB_MONITORING_AVAILABILITY_STYLE_ERROR (0x80de000a)
#define PR_EMS_AB_MONITORING_AVAILABILITY_WINDOW (0x80df0102)
#define PR_EMS_AB_MONITORING_AVAILABILITY_WINDOW_ERROR (0x80df000a)
#define PR_EMS_AB_MONITORING_CACHED_VIA_MAIL_O (0x80e0000d)
#define PR_EMS_AB_MONITORING_CACHED_VIA_MAIL_O_ERROR (0x80e0000a)
#define PR_EMS_AB_MONITORING_CACHED_VIA_MAIL (0x80e0101e)
#define PR_EMS_AB_MONITORING_CACHED_VIA_MAIL_UNICODE (0x80e0101f)
#define PR_EMS_AB_MONITORING_CACHED_VIA_RPC_O (0x80e1000d)
#define PR_EMS_AB_MONITORING_CACHED_VIA_RPC_O_ERROR (0x80e1000a)
#define PR_EMS_AB_MONITORING_CACHED_VIA_RPC (0x80e1101e)
#define PR_EMS_AB_MONITORING_CACHED_VIA_RPC_UNICODE (0x80e1101f)
#define PR_EMS_AB_MONITORING_ESCALATION_PROCEDURE (0x80e21102)
#define PR_EMS_AB_MONITORING_ESCALATION_PROCEDURE_ERROR (0x80e2000a)
#define PR_EMS_AB_MONITORING_HOTSITE_POLL_INTERVAL (0x80e30003)
#define PR_EMS_AB_MONITORING_HOTSITE_POLL_INTERVAL_ERROR (0x80e3000a)
#define PR_EMS_AB_MONITORING_HOTSITE_POLL_UNITS (0x80e40003)
#define PR_EMS_AB_MONITORING_HOTSITE_POLL_UNITS_ERROR (0x80e4000a)
#define PR_EMS_AB_MONITORING_MAIL_UPDATE_INTERVAL (0x80e50003)
#define PR_EMS_AB_MONITORING_MAIL_UPDATE_INTERVAL_ERROR (0x80e5000a)
#define PR_EMS_AB_MONITORING_MAIL_UPDATE_UNITS (0x80e60003)
#define PR_EMS_AB_MONITORING_MAIL_UPDATE_UNITS_ERROR (0x80e6000a)
#define PR_EMS_AB_MONITORING_NORMAL_POLL_INTERVAL (0x80e70003)
#define PR_EMS_AB_MONITORING_NORMAL_POLL_INTERVAL_ERROR (0x80e7000a)
#define PR_EMS_AB_MONITORING_NORMAL_POLL_UNITS (0x80e80003)
#define PR_EMS_AB_MONITORING_NORMAL_POLL_UNITS_ERROR (0x80e8000a)
#define PR_EMS_AB_MONITORING_RECIPIENTS_O (0x80e9000d)
#define PR_EMS_AB_MONITORING_RECIPIENTS_O_ERROR (0x80e9000a)
#define PR_EMS_AB_MONITORING_RECIPIENTS (0x80e9101e)
#define PR_EMS_AB_MONITORING_RECIPIENTS_UNICODE (0x80e9101f)
#define PR_EMS_AB_MONITORING_RECIPIENTS_NDR_O (0x80ea000d)
#define PR_EMS_AB_MONITORING_RECIPIENTS_NDR_O_ERROR (0x80ea000a)
#define PR_EMS_AB_MONITORING_RECIPIENTS_NDR (0x80ea101e)
#define PR_EMS_AB_MONITORING_RECIPIENTS_NDR_UNICODE (0x80ea101f)
#define PR_EMS_AB_MONITORING_RPC_UPDATE_INTERVAL (0x80eb0003)
#define PR_EMS_AB_MONITORING_RPC_UPDATE_INTERVAL_ERROR (0x80eb000a)
#define PR_EMS_AB_MONITORING_RPC_UPDATE_UNITS (0x80ec0003)
#define PR_EMS_AB_MONITORING_RPC_UPDATE_UNITS_ERROR (0x80ec000a)
#define PR_EMS_AB_MONITORING_WARNING_DELAY (0x80ed0003)
#define PR_EMS_AB_MONITORING_WARNING_DELAY_ERROR (0x80ed000a)
#define PR_EMS_AB_MONITORING_WARNING_UNITS (0x80ee0003)
#define PR_EMS_AB_MONITORING_WARNING_UNITS_ERROR (0x80ee000a)
#define PR_EMS_AB_MTA_LOCAL_CRED (0x80ef001e)
#define PR_EMS_AB_MTA_LOCAL_CRED_UNICODE (0x80ef001f)
#define PR_EMS_AB_MTA_LOCAL_CRED_ERROR (0x80ef000a)
#define PR_EMS_AB_MTA_LOCAL_DESIG (0x80f0001e)
#define PR_EMS_AB_MTA_LOCAL_DESIG_UNICODE (0x80f0001f)
#define PR_EMS_AB_MTA_LOCAL_DESIG_ERROR (0x80f0000a)
#define PR_EMS_AB_N_ADDRESS (0x80f10102)
#define PR_EMS_AB_N_ADDRESS_ERROR (0x80f1000a)
#define PR_EMS_AB_N_ADDRESS_TYPE (0x80f20003)
#define PR_EMS_AB_N_ADDRESS_TYPE_ERROR (0x80f2000a)
#define PR_EMS_AB_NT_MACHINE_NAME (0x80f3001e)
#define PR_EMS_AB_NT_MACHINE_NAME_UNICODE (0x80f3001f)
#define PR_EMS_AB_NT_MACHINE_NAME_ERROR (0x80f3000a)
#define PR_EMS_AB_NUM_OF_OPEN_RETRIES (0x80f40003)
#define PR_EMS_AB_NUM_OF_OPEN_RETRIES_ERROR (0x80f4000a)
#define PR_EMS_AB_NUM_OF_TRANSFER_RETRIES (0x80f50003)
#define PR_EMS_AB_NUM_OF_TRANSFER_RETRIES_ERROR (0x80f5000a)
#define PR_EMS_AB_OBJECT_CLASS_CATEGORY (0x80f60003)
#define PR_EMS_AB_OBJECT_CLASS_CATEGORY_ERROR (0x80f6000a)
#define PR_EMS_AB_OBJECT_VERSION (0x80f70003)
#define PR_EMS_AB_OBJECT_VERSION_ERROR (0x80f7000a)
#define PR_EMS_AB_OFF_LINE_AB_CONTAINERS_O (0x80f8000d)
#define PR_EMS_AB_OFF_LINE_AB_CONTAINERS_O_ERROR (0x80f8000a)
#define PR_EMS_AB_OFF_LINE_AB_CONTAINERS (0x80f8101e)
#define PR_EMS_AB_OFF_LINE_AB_CONTAINERS_UNICODE (0x80f8101f)
#define PR_EMS_AB_OFF_LINE_AB_SCHEDULE (0x80f90102)
#define PR_EMS_AB_OFF_LINE_AB_SCHEDULE_ERROR (0x80f9000a)
#define PR_EMS_AB_OFF_LINE_AB_SERVER_O (0x80fa000d)
#define PR_EMS_AB_OFF_LINE_AB_SERVER_O_ERROR (0x80fa000a)
#define PR_EMS_AB_OFF_LINE_AB_SERVER (0x80fa001e)
#define PR_EMS_AB_OFF_LINE_AB_SERVER_UNICODE (0x80fa001f)
#define PR_EMS_AB_OFF_LINE_AB_STYLE (0x80fb0003)
#define PR_EMS_AB_OFF_LINE_AB_STYLE_ERROR (0x80fb000a)
#define PR_EMS_AB_OID_TYPE (0x80fc0003)
#define PR_EMS_AB_OID_TYPE_ERROR (0x80fc000a)
#define PR_EMS_AB_OM_OBJECT_CLASS (0x80fd0102)
#define PR_EMS_AB_OM_OBJECT_CLASS_ERROR (0x80fd000a)
#define PR_EMS_AB_OM_SYNTAX (0x80fe0003)
#define PR_EMS_AB_OM_SYNTAX_ERROR (0x80fe000a)
#define PR_EMS_AB_OOF_REPLY_TO_ORIGINATOR (0x80ff000b)
#define PR_EMS_AB_OOF_REPLY_TO_ORIGINATOR_ERROR (0x80ff000a)
#define PR_EMS_AB_OPEN_RETRY_INTERVAL (0x81000003)
#define PR_EMS_AB_OPEN_RETRY_INTERVAL_ERROR (0x8100000a)
#define PR_EMS_AB_ORGANIZATION_NAME (0x8101101e)
#define PR_EMS_AB_ORGANIZATION_NAME_UNICODE (0x8101101f)
#define PR_EMS_AB_ORGANIZATION_NAME_ERROR (0x8101000a)
#define PR_EMS_AB_ORGANIZATIONAL_UNIT_NAME (0x8102101e)
#define PR_EMS_AB_ORGANIZATIONAL_UNIT_NAME_UNICODE (0x8102101f)
#define PR_EMS_AB_ORGANIZATIONAL_UNIT_NAME_ERROR (0x8102000a)
#define PR_EMS_AB_ORIGINAL_DISPLAY_TABLE (0x81030102)
#define PR_EMS_AB_ORIGINAL_DISPLAY_TABLE_ERROR (0x8103000a)
#define PR_EMS_AB_ORIGINAL_DISPLAY_TABLE_MSDOS (0x81040102)
#define PR_EMS_AB_ORIGINAL_DISPLAY_TABLE_MSDOS_ERROR (0x8104000a)
#define PR_EMS_AB_OUTBOUND_SITES_O (0x8105000d)
#define PR_EMS_AB_OUTBOUND_SITES_O_ERROR (0x8105000a)
#define PR_EMS_AB_OUTBOUND_SITES (0x8105101e)
#define PR_EMS_AB_OUTBOUND_SITES_UNICODE (0x8105101f)
#define PR_EMS_AB_P_SELECTOR (0x81060102)
#define PR_EMS_AB_P_SELECTOR_ERROR (0x8106000a)
#define PR_EMS_AB_P_SELECTOR_INBOUND (0x81070102)
#define PR_EMS_AB_P_SELECTOR_INBOUND_ERROR (0x8107000a)
#define PR_EMS_AB_PER_MSG_DIALOG_DISPLAY_TABLE (0x81080102)
#define PR_EMS_AB_PER_MSG_DIALOG_DISPLAY_TABLE_ERROR (0x8108000a)
#define PR_EMS_AB_PER_RECIP_DIALOG_DISPLAY_TABLE (0x81090102)
#define PR_EMS_AB_PER_RECIP_DIALOG_DISPLAY_TABLE_ERROR (0x8109000a)
#define PR_EMS_AB_PERIOD_REP_SYNC_TIMES (0x810a0102)
#define PR_EMS_AB_PERIOD_REP_SYNC_TIMES_ERROR (0x810a000a)
#define PR_EMS_AB_PERIOD_REPL_STAGGER (0x810b0003)
#define PR_EMS_AB_PERIOD_REPL_STAGGER_ERROR (0x810b000a)
#define PR_EMS_AB_POSTAL_ADDRESS (0x810c1102)
#define PR_EMS_AB_POSTAL_ADDRESS_ERROR (0x810c000a)
#define PR_EMS_AB_PREFERRED_DELIVERY_METHOD (0x810d1003)
#define PR_EMS_AB_PREFERRED_DELIVERY_METHOD_ERROR (0x810d000a)
#define PR_EMS_AB_PRMD (0x810e001e)
#define PR_EMS_AB_PRMD_UNICODE (0x810e001f)
#define PR_EMS_AB_PRMD_ERROR (0x810e000a)
#define PR_EMS_AB_PROXY_GENERATOR_DLL (0x810f001e)
#define PR_EMS_AB_PROXY_GENERATOR_DLL_UNICODE (0x810f001f)
#define PR_EMS_AB_PROXY_GENERATOR_DLL_ERROR (0x810f000a)
#define PR_EMS_AB_PUBLIC_DELEGATES_BL_O (0x8110000d)
#define PR_EMS_AB_PUBLIC_DELEGATES_BL_O_ERROR (0x8110000a)
#define PR_EMS_AB_PUBLIC_DELEGATES_BL (0x8110101e)
#define PR_EMS_AB_PUBLIC_DELEGATES_BL_UNICODE (0x8110101f)
#define PR_EMS_AB_QUOTA_NOTIFICATION_SCHEDULE (0x81110102)
#define PR_EMS_AB_QUOTA_NOTIFICATION_SCHEDULE_ERROR (0x8111000a)
#define PR_EMS_AB_QUOTA_NOTIFICATION_STYLE (0x81120003)
#define PR_EMS_AB_QUOTA_NOTIFICATION_STYLE_ERROR (0x8112000a)
#define PR_EMS_AB_RANGE_LOWER (0x81130003)
#define PR_EMS_AB_RANGE_LOWER_ERROR (0x8113000a)
#define PR_EMS_AB_RANGE_UPPER (0x81140003)
#define PR_EMS_AB_RANGE_UPPER_ERROR (0x8114000a)
#define PR_EMS_AB_RAS_CALLBACK_NUMBER (0x8115001e)
#define PR_EMS_AB_RAS_CALLBACK_NUMBER_UNICODE (0x8115001f)
#define PR_EMS_AB_RAS_CALLBACK_NUMBER_ERROR (0x8115000a)
#define PR_EMS_AB_RAS_PHONE_NUMBER (0x8116001e)
#define PR_EMS_AB_RAS_PHONE_NUMBER_UNICODE (0x8116001f)
#define PR_EMS_AB_RAS_PHONE_NUMBER_ERROR (0x8116000a)
#define PR_EMS_AB_RAS_PHONEBOOK_ENTRY_NAME (0x8117001e)
#define PR_EMS_AB_RAS_PHONEBOOK_ENTRY_NAME_UNICODE (0x8117001f)
#define PR_EMS_AB_RAS_PHONEBOOK_ENTRY_NAME_ERROR (0x8117000a)
#define PR_EMS_AB_RAS_REMOTE_SRVR_NAME (0x8118001e)
#define PR_EMS_AB_RAS_REMOTE_SRVR_NAME_UNICODE (0x8118001f)
#define PR_EMS_AB_RAS_REMOTE_SRVR_NAME_ERROR (0x8118000a)
#define PR_EMS_AB_REGISTERED_ADDRESS (0x81191102)
#define PR_EMS_AB_REGISTERED_ADDRESS_ERROR (0x8119000a)
#define PR_EMS_AB_REMOTE_BRIDGE_HEAD (0x811a001e)
#define PR_EMS_AB_REMOTE_BRIDGE_HEAD_UNICODE (0x811a001f)
#define PR_EMS_AB_REMOTE_BRIDGE_HEAD_ERROR (0x811a000a)
#define PR_EMS_AB_REMOTE_BRIDGE_HEAD_ADDRESS (0x811b001e)
#define PR_EMS_AB_REMOTE_BRIDGE_HEAD_ADDRESS_UNICODE (0x811b001f)
#define PR_EMS_AB_REMOTE_BRIDGE_HEAD_ADDRESS_ERROR (0x811b000a)
#define PR_EMS_AB_REMOTE_OUT_BH_SERVER_O (0x811c000d)
#define PR_EMS_AB_REMOTE_OUT_BH_SERVER_O_ERROR (0x811c000a)
#define PR_EMS_AB_REMOTE_OUT_BH_SERVER (0x811c001e)
#define PR_EMS_AB_REMOTE_OUT_BH_SERVER_UNICODE (0x811c001f)
#define PR_EMS_AB_REMOTE_SITE_O (0x811d000d)
#define PR_EMS_AB_REMOTE_SITE_O_ERROR (0x811d000a)
#define PR_EMS_AB_REMOTE_SITE (0x811d001e)
#define PR_EMS_AB_REMOTE_SITE_UNICODE (0x811d001f)
#define PR_EMS_AB_REPLICATION_SENSITIVITY (0x811e0003)
#define PR_EMS_AB_REPLICATION_SENSITIVITY_ERROR (0x811e000a)
#define PR_EMS_AB_REPLICATION_STAGGER (0x811f0003)
#define PR_EMS_AB_REPLICATION_STAGGER_ERROR (0x811f000a)
#define PR_EMS_AB_REPORT_TO_ORIGINATOR (0x8120000b)
#define PR_EMS_AB_REPORT_TO_ORIGINATOR_ERROR (0x8120000a)
#define PR_EMS_AB_REPORT_TO_OWNER (0x8121000b)
#define PR_EMS_AB_REPORT_TO_OWNER_ERROR (0x8121000a)
#define PR_EMS_AB_REQ_SEQ (0x81220003)
#define PR_EMS_AB_REQ_SEQ_ERROR (0x8122000a)
#define PR_EMS_AB_RESPONSIBLE_LOCAL_DXA_O (0x8123000d)
#define PR_EMS_AB_RESPONSIBLE_LOCAL_DXA_O_ERROR (0x8123000a)
#define PR_EMS_AB_RESPONSIBLE_LOCAL_DXA (0x8123001e)
#define PR_EMS_AB_RESPONSIBLE_LOCAL_DXA_UNICODE (0x8123001f)
#define PR_EMS_AB_RID_SERVER_O (0x8124000d)
#define PR_EMS_AB_RID_SERVER_O_ERROR (0x8124000a)
#define PR_EMS_AB_RID_SERVER (0x8124001e)
#define PR_EMS_AB_RID_SERVER_UNICODE (0x8124001f)
#define PR_EMS_AB_ROLE_OCCUPANT_O (0x8125000d)
#define PR_EMS_AB_ROLE_OCCUPANT_O_ERROR (0x8125000a)
#define PR_EMS_AB_ROLE_OCCUPANT (0x8125101e)
#define PR_EMS_AB_ROLE_OCCUPANT_UNICODE (0x8125101f)
#define PR_EMS_AB_ROUTING_LIST (0x8126101e)
#define PR_EMS_AB_ROUTING_LIST_UNICODE (0x8126101f)
#define PR_EMS_AB_ROUTING_LIST_ERROR (0x8126000a)
#define PR_EMS_AB_RTS_CHECKPOINT_SIZE (0x81270003)
#define PR_EMS_AB_RTS_CHECKPOINT_SIZE_ERROR (0x8127000a)
#define PR_EMS_AB_RTS_RECOVERY_TIMEOUT (0x81280003)
#define PR_EMS_AB_RTS_RECOVERY_TIMEOUT_ERROR (0x8128000a)
#define PR_EMS_AB_RTS_WINDOW_SIZE (0x81290003)
#define PR_EMS_AB_RTS_WINDOW_SIZE_ERROR (0x8129000a)
#define PR_EMS_AB_RUNS_ON_O (0x812a000d)
#define PR_EMS_AB_RUNS_ON_O_ERROR (0x812a000a)
#define PR_EMS_AB_RUNS_ON (0x812a101e)
#define PR_EMS_AB_RUNS_ON_UNICODE (0x812a101f)
#define PR_EMS_AB_S_SELECTOR (0x812b0102)
#define PR_EMS_AB_S_SELECTOR_ERROR (0x812b000a)
#define PR_EMS_AB_S_SELECTOR_INBOUND (0x812c0102)
#define PR_EMS_AB_S_SELECTOR_INBOUND_ERROR (0x812c000a)
#define PR_EMS_AB_SEARCH_FLAGS (0x812d0003)
#define PR_EMS_AB_SEARCH_FLAGS_ERROR (0x812d000a)
#define PR_EMS_AB_SEARCH_GUIDE (0x812e1102)
#define PR_EMS_AB_SEARCH_GUIDE_ERROR (0x812e000a)
#define PR_EMS_AB_SEE_ALSO_O (0x812f000d)
#define PR_EMS_AB_SEE_ALSO_O_ERROR (0x812f000a)
#define PR_EMS_AB_SEE_ALSO (0x812f101e)
#define PR_EMS_AB_SEE_ALSO_UNICODE (0x812f101f)
#define PR_EMS_AB_SERIAL_NUMBER (0x8130101e)
#define PR_EMS_AB_SERIAL_NUMBER_UNICODE (0x8130101f)
#define PR_EMS_AB_SERIAL_NUMBER_ERROR (0x8130000a)
#define PR_EMS_AB_SERVICE_ACTION_FIRST (0x81310003)
#define PR_EMS_AB_SERVICE_ACTION_FIRST_ERROR (0x8131000a)
#define PR_EMS_AB_SERVICE_ACTION_OTHER (0x81320003)
#define PR_EMS_AB_SERVICE_ACTION_OTHER_ERROR (0x8132000a)
#define PR_EMS_AB_SERVICE_ACTION_SECOND (0x81330003)
#define PR_EMS_AB_SERVICE_ACTION_SECOND_ERROR (0x8133000a)
#define PR_EMS_AB_SERVICE_RESTART_DELAY (0x81340003)
#define PR_EMS_AB_SERVICE_RESTART_DELAY_ERROR (0x8134000a)
#define PR_EMS_AB_SERVICE_RESTART_MESSAGE (0x8135001e)
#define PR_EMS_AB_SERVICE_RESTART_MESSAGE_UNICODE (0x8135001f)
#define PR_EMS_AB_SERVICE_RESTART_MESSAGE_ERROR (0x8135000a)
#define PR_EMS_AB_SESSION_DISCONNECT_TIMER (0x81360003)
#define PR_EMS_AB_SESSION_DISCONNECT_TIMER_ERROR (0x8136000a)
#define PR_EMS_AB_SITE_AFFINITY (0x8137101e)
#define PR_EMS_AB_SITE_AFFINITY_UNICODE (0x8137101f)
#define PR_EMS_AB_SITE_AFFINITY_ERROR (0x8137000a)
#define PR_EMS_AB_SITE_PROXY_SPACE (0x8138101e)
#define PR_EMS_AB_SITE_PROXY_SPACE_UNICODE (0x8138101f)
#define PR_EMS_AB_SITE_PROXY_SPACE_ERROR (0x8138000a)
#define PR_EMS_AB_SPACE_LAST_COMPUTED (0x81390040)
#define PR_EMS_AB_SPACE_LAST_COMPUTED_ERROR (0x8139000a)
#define PR_EMS_AB_STREET_ADDRESS (0x813a001e)
#define PR_EMS_AB_STREET_ADDRESS_UNICODE (0x813a001f)
#define PR_EMS_AB_STREET_ADDRESS_ERROR (0x813a000a)
#define PR_EMS_AB_SUB_REFS_O (0x813b000d)
#define PR_EMS_AB_SUB_REFS_O_ERROR (0x813b000a)
#define PR_EMS_AB_SUB_REFS (0x813b101e)
#define PR_EMS_AB_SUB_REFS_UNICODE (0x813b101f)
#define PR_EMS_AB_SUBMISSION_CONT_LENGTH (0x813c0003)
#define PR_EMS_AB_SUBMISSION_CONT_LENGTH_ERROR (0x813c000a)
#define PR_EMS_AB_SUPPORTED_APPLICATION_CONTEXT (0x813d1102)
#define PR_EMS_AB_SUPPORTED_APPLICATION_CONTEXT_ERROR (0x813d000a)
#define PR_EMS_AB_SUPPORTING_STACK_O (0x813e000d)
#define PR_EMS_AB_SUPPORTING_STACK_O_ERROR (0x813e000a)
#define PR_EMS_AB_SUPPORTING_STACK (0x813e101e)
#define PR_EMS_AB_SUPPORTING_STACK_UNICODE (0x813e101f)
#define PR_EMS_AB_SUPPORTING_STACK_BL_O (0x813f000d)
#define PR_EMS_AB_SUPPORTING_STACK_BL_O_ERROR (0x813f000a)
#define PR_EMS_AB_SUPPORTING_STACK_BL (0x813f101e)
#define PR_EMS_AB_SUPPORTING_STACK_BL_UNICODE (0x813f101f)
#define PR_EMS_AB_T_SELECTOR (0x81400102)
#define PR_EMS_AB_T_SELECTOR_ERROR (0x8140000a)
#define PR_EMS_AB_T_SELECTOR_INBOUND (0x81410102)
#define PR_EMS_AB_T_SELECTOR_INBOUND_ERROR (0x8141000a)
#define PR_EMS_AB_TARGET_MTAS (0x8142101e)
#define PR_EMS_AB_TARGET_MTAS_UNICODE (0x8142101f)
#define PR_EMS_AB_TARGET_MTAS_ERROR (0x8142000a)
#define PR_EMS_AB_TELETEX_TERMINAL_IDENTIFIER (0x81431102)
#define PR_EMS_AB_TELETEX_TERMINAL_IDENTIFIER_ERROR (0x8143000a)
#define PR_EMS_AB_TEMP_ASSOC_THRESHOLD (0x81440003)
#define PR_EMS_AB_TEMP_ASSOC_THRESHOLD_ERROR (0x8144000a)
#define PR_EMS_AB_TOMBSTONE_LIFETIME (0x81450003)
#define PR_EMS_AB_TOMBSTONE_LIFETIME_ERROR (0x8145000a)
#define PR_EMS_AB_TRACKING_LOG_PATH_NAME (0x8146001e)
#define PR_EMS_AB_TRACKING_LOG_PATH_NAME_UNICODE (0x8146001f)
#define PR_EMS_AB_TRACKING_LOG_PATH_NAME_ERROR (0x8146000a)
#define PR_EMS_AB_TRANS_RETRY_MINS (0x81470003)
#define PR_EMS_AB_TRANS_RETRY_MINS_ERROR (0x8147000a)
#define PR_EMS_AB_TRANS_TIMEOUT_MINS (0x81480003)
#define PR_EMS_AB_TRANS_TIMEOUT_MINS_ERROR (0x8148000a)
#define PR_EMS_AB_TRANSFER_RETRY_INTERVAL (0x81490003)
#define PR_EMS_AB_TRANSFER_RETRY_INTERVAL_ERROR (0x8149000a)
#define PR_EMS_AB_TRANSFER_TIMEOUT_NON_URGENT (0x814a0003)
#define PR_EMS_AB_TRANSFER_TIMEOUT_NON_URGENT_ERROR (0x814a000a)
#define PR_EMS_AB_TRANSFER_TIMEOUT_NORMAL (0x814b0003)
#define PR_EMS_AB_TRANSFER_TIMEOUT_NORMAL_ERROR (0x814b000a)
#define PR_EMS_AB_TRANSFER_TIMEOUT_URGENT (0x814c0003)
#define PR_EMS_AB_TRANSFER_TIMEOUT_URGENT_ERROR (0x814c000a)
#define PR_EMS_AB_TRANSLATION_TABLE_USED (0x814d0003)
#define PR_EMS_AB_TRANSLATION_TABLE_USED_ERROR (0x814d000a)
#define PR_EMS_AB_TRANSPORT_EXPEDITED_DATA (0x814e000b)
#define PR_EMS_AB_TRANSPORT_EXPEDITED_DATA_ERROR (0x814e000a)
#define PR_EMS_AB_TRUST_LEVEL (0x814f0003)
#define PR_EMS_AB_TRUST_LEVEL_ERROR (0x814f000a)
#define PR_EMS_AB_TURN_REQUEST_THRESHOLD (0x81500003)
#define PR_EMS_AB_TURN_REQUEST_THRESHOLD_ERROR (0x8150000a)
#define PR_EMS_AB_TWO_WAY_ALTERNATE_FACILITY (0x8151000b)
#define PR_EMS_AB_TWO_WAY_ALTERNATE_FACILITY_ERROR (0x8151000a)
#define PR_EMS_AB_UNAUTH_ORIG_BL_O (0x8152000d)
#define PR_EMS_AB_UNAUTH_ORIG_BL_O_ERROR (0x8152000a)
#define PR_EMS_AB_UNAUTH_ORIG_BL (0x8152101e)
#define PR_EMS_AB_UNAUTH_ORIG_BL_UNICODE (0x8152101f)
#define PR_EMS_AB_USER_PASSWORD (0x81531102)
#define PR_EMS_AB_USER_PASSWORD_ERROR (0x8153000a)
#define PR_EMS_AB_USN_CREATED (0x81540003)
#define PR_EMS_AB_USN_CREATED_ERROR (0x8154000a)
#define PR_EMS_AB_USN_DSA_LAST_OBJ_REMOVED (0x81550003)
#define PR_EMS_AB_USN_DSA_LAST_OBJ_REMOVED_ERROR (0x8155000a)
#define PR_EMS_AB_USN_LAST_OBJ_REM (0x81560003)
#define PR_EMS_AB_USN_LAST_OBJ_REM_ERROR (0x8156000a)
#define PR_EMS_AB_USN_SOURCE (0x81570003)
#define PR_EMS_AB_USN_SOURCE_ERROR (0x8157000a)
#define PR_EMS_AB_X121_ADDRESS (0x8158101e)
#define PR_EMS_AB_X121_ADDRESS_UNICODE (0x8158101f)
#define PR_EMS_AB_X121_ADDRESS_ERROR (0x8158000a)
#define PR_EMS_AB_X25_CALL_USER_DATA_INCOMING (0x81590102)
#define PR_EMS_AB_X25_CALL_USER_DATA_INCOMING_ERROR (0x8159000a)
#define PR_EMS_AB_X25_CALL_USER_DATA_OUTGOING (0x815a0102)
#define PR_EMS_AB_X25_CALL_USER_DATA_OUTGOING_ERROR (0x815a000a)
#define PR_EMS_AB_X25_FACILITIES_DATA_INCOMING (0x815b0102)
#define PR_EMS_AB_X25_FACILITIES_DATA_INCOMING_ERROR (0x815b000a)
#define PR_EMS_AB_X25_FACILITIES_DATA_OUTGOING (0x815c0102)
#define PR_EMS_AB_X25_FACILITIES_DATA_OUTGOING_ERROR (0x815c000a)
#define PR_EMS_AB_X25_LEASED_LINE_PORT (0x815d0102)
#define PR_EMS_AB_X25_LEASED_LINE_PORT_ERROR (0x815d000a)
#define PR_EMS_AB_X25_LEASED_OR_SWITCHED (0x815e000b)
#define PR_EMS_AB_X25_LEASED_OR_SWITCHED_ERROR (0x815e000a)
#define PR_EMS_AB_X25_REMOTE_MTA_PHONE (0x815f001e)
#define PR_EMS_AB_X25_REMOTE_MTA_PHONE_UNICODE (0x815f001f)
#define PR_EMS_AB_X25_REMOTE_MTA_PHONE_ERROR (0x815f000a)
#define PR_EMS_AB_X400_ATTACHMENT_TYPE (0x81600102)
#define PR_EMS_AB_X400_ATTACHMENT_TYPE_ERROR (0x8160000a)
#define PR_EMS_AB_X400_SELECTOR_SYNTAX (0x81610003)
#define PR_EMS_AB_X400_SELECTOR_SYNTAX_ERROR (0x8161000a)
#define PR_EMS_AB_X500_ACCESS_CONTROL_LIST (0x81620102)
#define PR_EMS_AB_X500_ACCESS_CONTROL_LIST_ERROR (0x8162000a)
#define PR_EMS_AB_XMIT_TIMEOUT_NON_URGENT (0x81630003)
#define PR_EMS_AB_XMIT_TIMEOUT_NON_URGENT_ERROR (0x8163000a)
#define PR_EMS_AB_XMIT_TIMEOUT_NORMAL (0x81640003)
#define PR_EMS_AB_XMIT_TIMEOUT_NORMAL_ERROR (0x8164000a)
#define PR_EMS_AB_XMIT_TIMEOUT_URGENT (0x81650003)
#define PR_EMS_AB_XMIT_TIMEOUT_URGENT_ERROR (0x8165000a)
#define PR_EMS_AB_SITE_FOLDER_GUID (0x81660102)
#define PR_EMS_AB_SITE_FOLDER_GUID_ERROR (0x8166000a)
#define PR_EMS_AB_SITE_FOLDER_SERVER_O (0x8167000d)
#define PR_EMS_AB_SITE_FOLDER_SERVER_O_ERROR (0x8167000a)
#define PR_EMS_AB_SITE_FOLDER_SERVER (0x8167001e)
#define PR_EMS_AB_SITE_FOLDER_SERVER_UNICODE (0x8167001f)
#define PR_EMS_AB_REPLICATION_MAIL_MSG_SIZE (0x81680003)
#define PR_EMS_AB_REPLICATION_MAIL_MSG_SIZE_ERROR (0x8168000a)
#define PR_EMS_AB_MAXIMUM_OBJECT_ID (0x81690102)
#define PR_EMS_AB_MAXIMUM_OBJECT_ID_ERROR (0x8169000a)
#define PR_EMS_AB_NETWORK_ADDRESS (0x8170101e)
#define PR_EMS_AB_NETWORK_ADDRESS_UNICODE (0x8170101f)
#define PR_EMS_AB_NETWORK_ADDRESS_ERROR (0x8170000a)
#define PR_EMS_AB_LDAP_DISPLAY_NAME (0x8171101e)
#define PR_EMS_AB_LDAP_DISPLAY_NAME_UNICODE (0x8171101f)
#define PR_EMS_AB_LDAP_DISPLAY_NAME_ERROR (0x8171000a)
#define PR_EMS_AB_SCHEMA_FLAGS (0x81730003)
#define PR_EMS_AB_SCHEMA_FLAGS_ERROR (0x8173000a)
#define PR_EMS_AB_BRIDGEHEAD_SERVERS_O (0x8174000d)
#define PR_EMS_AB_BRIDGEHEAD_SERVERS_O_ERROR (0x8174000a)
#define PR_EMS_AB_BRIDGEHEAD_SERVERS (0x8174101e)
#define PR_EMS_AB_BRIDGEHEAD_SERVERS_UNICODE (0x8174101f)
#define PR_EMS_AB_WWW_HOME_PAGE (0x8175001e)
#define PR_EMS_AB_WWW_HOME_PAGE_UNICODE (0x8175001f)
#define PR_EMS_AB_WWW_HOME_PAGE_ERROR (0x8175000a)
#define PR_EMS_AB_NNTP_CONTENT_FORMAT (0x8176001e)
#define PR_EMS_AB_NNTP_CONTENT_FORMAT_UNICODE (0x8176001f)
#define PR_EMS_AB_NNTP_CONTENT_FORMAT_ERROR (0x8176000a)
#define PR_EMS_AB_POP_CONTENT_FORMAT (0x8177001e)
#define PR_EMS_AB_POP_CONTENT_FORMAT_UNICODE (0x8177001f)
#define PR_EMS_AB_POP_CONTENT_FORMAT_ERROR (0x8177000a)
#define PR_EMS_AB_LANGUAGE (0x81780003)
#define PR_EMS_AB_LANGUAGE_ERROR (0x8178000a)
#define PR_EMS_AB_POP_CHARACTER_SET (0x8179001e)
#define PR_EMS_AB_POP_CHARACTER_SET_UNICODE (0x8179001f)
#define PR_EMS_AB_POP_CHARACTER_SET_ERROR (0x8179000a)
#define PR_EMS_AB_USN_INTERSITE (0x817a0003)
#define PR_EMS_AB_USN_INTERSITE_ERROR (0x817a000a)
#define PR_EMS_AB_SUB_SITE (0x817b001e)
#define PR_EMS_AB_SUB_SITE_UNICODE (0x817b001f)
#define PR_EMS_AB_SUB_SITE_ERROR (0x817b000a)
#define PR_EMS_AB_SCHEMA_VERSION (0x817c1003)
#define PR_EMS_AB_SCHEMA_VERSION_ERROR (0x817c000a)
#define PR_EMS_AB_NNTP_CHARACTER_SET (0x817d001e)
#define PR_EMS_AB_NNTP_CHARACTER_SET_UNICODE (0x817d001f)
#define PR_EMS_AB_NNTP_CHARACTER_SET_ERROR (0x817d000a)
#define PR_EMS_AB_USE_SERVER_VALUES (0x817e000b)
#define PR_EMS_AB_USE_SERVER_VALUES_ERROR (0x817e000a)
#define PR_EMS_AB_ENABLED_PROTOCOLS (0x817f0003)
#define PR_EMS_AB_ENABLED_PROTOCOLS_ERROR (0x817f000a)
#define PR_EMS_AB_CONNECTION_LIST_FILTER (0x81800102)
#define PR_EMS_AB_CONNECTION_LIST_FILTER_ERROR (0x8180000a)
#define PR_EMS_AB_AVAILABLE_AUTHORIZATION_PACKAGES (0x8181101e)
#define PR_EMS_AB_AVAILABLE_AUTHORIZATION_PACKAGES_UNICODE (0x8181101f)
#define PR_EMS_AB_AVAILABLE_AUTHORIZATION_PACKAGES_ERROR (0x8181000a)
#define PR_EMS_AB_CHARACTER_SET_LIST (0x8182101e)
#define PR_EMS_AB_CHARACTER_SET_LIST_UNICODE (0x8182101f)
#define PR_EMS_AB_CHARACTER_SET_LIST_ERROR (0x8182000a)
#define PR_EMS_AB_USE_SITE_VALUES (0x8183000b)
#define PR_EMS_AB_USE_SITE_VALUES_ERROR (0x8183000a)
#define PR_EMS_AB_ENABLED_AUTHORIZATION_PACKAGES (0x8184101e)
#define PR_EMS_AB_ENABLED_AUTHORIZATION_PACKAGES_UNICODE (0x8184101f)
#define PR_EMS_AB_ENABLED_AUTHORIZATION_PACKAGES_ERROR (0x8184000a)
#define PR_EMS_AB_CHARACTER_SET (0x8185001e)
#define PR_EMS_AB_CHARACTER_SET_UNICODE (0x8185001f)
#define PR_EMS_AB_CHARACTER_SET_ERROR (0x8185000a)
#define PR_EMS_AB_CONTENT_TYPE (0x81860003)
#define PR_EMS_AB_CONTENT_TYPE_ERROR (0x8186000a)
#define PR_EMS_AB_ANONYMOUS_ACCESS (0x8187000b)
#define PR_EMS_AB_ANONYMOUS_ACCESS_ERROR (0x8187000a)
#define PR_EMS_AB_CONTROL_MSG_FOLDER_ID (0x81880102)
#define PR_EMS_AB_CONTROL_MSG_FOLDER_ID_ERROR (0x8188000a)
#define PR_EMS_AB_USENET_SITE_NAME (0x8189001e)
#define PR_EMS_AB_USENET_SITE_NAME_UNICODE (0x8189001f)
#define PR_EMS_AB_USENET_SITE_NAME_ERROR (0x8189000a)
#define PR_EMS_AB_CONTROL_MSG_RULES (0x818a0102)
#define PR_EMS_AB_CONTROL_MSG_RULES_ERROR (0x818a000a)
#define PR_EMS_AB_AVAILABLE_DISTRIBUTIONS (0x818b001e)
#define PR_EMS_AB_AVAILABLE_DISTRIBUTIONS_UNICODE (0x818b001f)
#define PR_EMS_AB_AVAILABLE_DISTRIBUTIONS_ERROR (0x818b000a)
#define PR_EMS_AB_OUTBOUND_HOST (0x818d0102)
#define PR_EMS_AB_OUTBOUND_HOST_ERROR (0x818d000a)
#define PR_EMS_AB_INBOUND_HOST (0x818e101e)
#define PR_EMS_AB_INBOUND_HOST_UNICODE (0x818e101f)
#define PR_EMS_AB_INBOUND_HOST_ERROR (0x818e000a)
#define PR_EMS_AB_OUTGOING_MSG_SIZE_LIMIT (0x818f0003)
#define PR_EMS_AB_OUTGOING_MSG_SIZE_LIMIT_ERROR (0x818f000a)
#define PR_EMS_AB_INCOMING_MSG_SIZE_LIMIT (0x81900003)
#define PR_EMS_AB_INCOMING_MSG_SIZE_LIMIT_ERROR (0x8190000a)
#define PR_EMS_AB_SEND_TNEF (0x8191000b)
#define PR_EMS_AB_SEND_TNEF_ERROR (0x8191000a)
#define PR_EMS_AB_AUTHORIZED_PASSWORD_CONFIRM (0x81920102)
#define PR_EMS_AB_AUTHORIZED_PASSWORD_CONFIRM_ERROR (0x8192000a)
#define PR_EMS_AB_INBOUND_NEWSFEED (0x8193001e)
#define PR_EMS_AB_INBOUND_NEWSFEED_UNICODE (0x8193001f)
#define PR_EMS_AB_INBOUND_NEWSFEED_ERROR (0x8193000a)
#define PR_EMS_AB_NEWSFEED_TYPE (0x81940003)
#define PR_EMS_AB_NEWSFEED_TYPE_ERROR (0x8194000a)
#define PR_EMS_AB_OUTBOUND_NEWSFEED (0x8195001e)
#define PR_EMS_AB_OUTBOUND_NEWSFEED_UNICODE (0x8195001f)
#define PR_EMS_AB_OUTBOUND_NEWSFEED_ERROR (0x8195000a)
#define PR_EMS_AB_NEWSGROUP_LIST (0x81960102)
#define PR_EMS_AB_NEWSGROUP_LIST_ERROR (0x8196000a)
#define PR_EMS_AB_NNTP_DISTRIBUTIONS (0x8197101e)
#define PR_EMS_AB_NNTP_DISTRIBUTIONS_UNICODE (0x8197101f)
#define PR_EMS_AB_NNTP_DISTRIBUTIONS_ERROR (0x8197000a)
#define PR_EMS_AB_NEWSGROUP (0x8198001e)
#define PR_EMS_AB_NEWSGROUP_UNICODE (0x8198001f)
#define PR_EMS_AB_NEWSGROUP_ERROR (0x8198000a)
#define PR_EMS_AB_MODERATOR (0x8199001e)
#define PR_EMS_AB_MODERATOR_UNICODE (0x8199001f)
#define PR_EMS_AB_MODERATOR_ERROR (0x8199000a)
#define PR_EMS_AB_AUTHENTICATION_TO_USE (0x819a001e)
#define PR_EMS_AB_AUTHENTICATION_TO_USE_UNICODE (0x819a001f)
#define PR_EMS_AB_AUTHENTICATION_TO_USE_ERROR (0x819a000a)
#define PR_EMS_AB_HTTP_PUB_GAL (0x819b000b)
#define PR_EMS_AB_HTTP_PUB_GAL_ERROR (0x819b000a)
#define PR_EMS_AB_HTTP_PUB_GAL_LIMIT (0x819c0003)
#define PR_EMS_AB_HTTP_PUB_GAL_LIMIT_ERROR (0x819c000a)
#define PR_EMS_AB_HTTP_PUB_PF (0x819e1102)
#define PR_EMS_AB_HTTP_PUB_PF_ERROR (0x819e000a)
#define PR_EMS_AB_X500_RDN (0x81a1001e)
#define PR_EMS_AB_X500_RDN_UNICODE (0x81a1001f)
#define PR_EMS_AB_X500_RDN_ERROR (0x81a1000a)
#define PR_EMS_AB_X500_NC (0x81a2001e)
#define PR_EMS_AB_X500_NC_UNICODE (0x81a2001f)
#define PR_EMS_AB_X500_NC_ERROR (0x81a2000a)
#define PR_EMS_AB_REFERRAL_LIST (0x81a3101e)
#define PR_EMS_AB_REFERRAL_LIST_UNICODE (0x81a3101f)
#define PR_EMS_AB_REFERRAL_LIST_ERROR (0x81a3000a)
#define PR_EMS_AB_NNTP_DISTRIBUTIONS_FLAG (0x81a4000b)
#define PR_EMS_AB_NNTP_DISTRIBUTIONS_FLAG_ERROR (0x81a4000a)
#define PR_EMS_AB_ASSOC_PROTOCOL_CFG_NNTP_O (0x81a5000d)
#define PR_EMS_AB_ASSOC_PROTOCOL_CFG_NNTP_O_ERROR (0x81a5000a)
#define PR_EMS_AB_ASSOC_PROTOCOL_CFG_NNTP (0x81a5001e)
#define PR_EMS_AB_ASSOC_PROTOCOL_CFG_NNTP_UNICODE (0x81a5001f)
#define PR_EMS_AB_NNTP_NEWSFEEDS_O (0x81a6000d)
#define PR_EMS_AB_NNTP_NEWSFEEDS_O_ERROR (0x81a6000a)
#define PR_EMS_AB_NNTP_NEWSFEEDS (0x81a6101e)
#define PR_EMS_AB_NNTP_NEWSFEEDS_UNICODE (0x81a6101f)
#define PR_EMS_AB_ENABLED_PROTOCOL_CFG (0x81a8000b)
#define PR_EMS_AB_ENABLED_PROTOCOL_CFG_ERROR (0x81a8000a)
#define PR_EMS_AB_HTTP_PUB_AB_ATTRIBUTES (0x81a9101e)
#define PR_EMS_AB_HTTP_PUB_AB_ATTRIBUTES_UNICODE (0x81a9101f)
#define PR_EMS_AB_HTTP_PUB_AB_ATTRIBUTES_ERROR (0x81a9000a)
#define PR_EMS_AB_HTTP_SERVERS (0x81ab101e)
#define PR_EMS_AB_HTTP_SERVERS_UNICODE (0x81ab101f)
#define PR_EMS_AB_HTTP_SERVERS_ERROR (0x81ab000a)
#define PR_EMS_AB_MODERATED (0x81ac000b)
#define PR_EMS_AB_MODERATED_ERROR (0x81ac000a)
#define PR_EMS_AB_RAS_ACCOUNT (0x81ad001e)
#define PR_EMS_AB_RAS_ACCOUNT_UNICODE (0x81ad001f)
#define PR_EMS_AB_RAS_ACCOUNT_ERROR (0x81ad000a)
#define PR_EMS_AB_RAS_PASSWORD (0x81ae0102)
#define PR_EMS_AB_RAS_PASSWORD_ERROR (0x81ae000a)
#define PR_EMS_AB_INCOMING_PASSWORD (0x81af0102)
#define PR_EMS_AB_INCOMING_PASSWORD_ERROR (0x81af000a)
#define PR_EMS_AB_OUTBOUND_HOST_TYPE (0x81b0000b)
#define PR_EMS_AB_OUTBOUND_HOST_TYPE_ERROR (0x81b0000a)
#define PR_EMS_AB_PROXY_GENERATION_ENABLED (0x81b1000b)
#define PR_EMS_AB_PROXY_GENERATION_ENABLED_ERROR (0x81b1000a)
#define PR_EMS_AB_ROOT_NEWSGROUPS_FOLDER_ID (0x81b20102)
#define PR_EMS_AB_ROOT_NEWSGROUPS_FOLDER_ID_ERROR (0x81b2000a)
#define PR_EMS_AB_CONNECTION_TYPE (0x81b3000b)
#define PR_EMS_AB_CONNECTION_TYPE_ERROR (0x81b3000a)
#define PR_EMS_AB_CONNECTION_LIST_FILTER_TYPE (0x81b40003)
#define PR_EMS_AB_CONNECTION_LIST_FILTER_TYPE_ERROR (0x81b4000a)
#define PR_EMS_AB_PORT_NUMBER (0x81b50003)
#define PR_EMS_AB_PORT_NUMBER_ERROR (0x81b5000a)
#define PR_EMS_AB_PROTOCOL_SETTINGS (0x81b6101e)
#define PR_EMS_AB_PROTOCOL_SETTINGS_UNICODE (0x81b6101f)
#define PR_EMS_AB_PROTOCOL_SETTINGS_ERROR (0x81b6000a)
#define PR_EMS_AB_GROUP_BY_ATTR_1 (0x81b7001e)
#define PR_EMS_AB_GROUP_BY_ATTR_1_UNICODE (0x81b7001f)
#define PR_EMS_AB_GROUP_BY_ATTR_1_ERROR (0x81b7000a)
#define PR_EMS_AB_GROUP_BY_ATTR_2 (0x81b8001e)
#define PR_EMS_AB_GROUP_BY_ATTR_2_UNICODE (0x81b8001f)
#define PR_EMS_AB_GROUP_BY_ATTR_2_ERROR (0x81b8000a)
#define PR_EMS_AB_GROUP_BY_ATTR_3 (0x81b9001e)
#define PR_EMS_AB_GROUP_BY_ATTR_3_UNICODE (0x81b9001f)
#define PR_EMS_AB_GROUP_BY_ATTR_3_ERROR (0x81b9000a)
#define PR_EMS_AB_GROUP_BY_ATTR_4 (0x81ba001e)
#define PR_EMS_AB_GROUP_BY_ATTR_4_UNICODE (0x81ba001f)
#define PR_EMS_AB_GROUP_BY_ATTR_4_ERROR (0x81ba000a)
#define PR_EMS_AB_VIEW_SITE (0x81be001e)
#define PR_EMS_AB_VIEW_SITE_UNICODE (0x81be001f)
#define PR_EMS_AB_VIEW_SITE_ERROR (0x81be000a)
#define PR_EMS_AB_VIEW_CONTAINER_1 (0x81bf001e)
#define PR_EMS_AB_VIEW_CONTAINER_1_UNICODE (0x81bf001f)
#define PR_EMS_AB_VIEW_CONTAINER_1_ERROR (0x81bf000a)
#define PR_EMS_AB_VIEW_CONTAINER_2 (0x81c0001e)
#define PR_EMS_AB_VIEW_CONTAINER_2_UNICODE (0x81c0001f)
#define PR_EMS_AB_VIEW_CONTAINER_2_ERROR (0x81c0000a)
#define PR_EMS_AB_VIEW_CONTAINER_3 (0x81c1001e)
#define PR_EMS_AB_VIEW_CONTAINER_3_UNICODE (0x81c1001f)
#define PR_EMS_AB_VIEW_CONTAINER_3_ERROR (0x81c1000a)
#define PR_EMS_AB_PROMO_EXPIRATION (0x81c20040)
#define PR_EMS_AB_PROMO_EXPIRATION_ERROR (0x81c2000a)
#define PR_EMS_AB_DISABLED_GATEWAY_PROXY (0x81c3101e)
#define PR_EMS_AB_DISABLED_GATEWAY_PROXY_UNICODE (0x81c3101f)
#define PR_EMS_AB_DISABLED_GATEWAY_PROXY_ERROR (0x81c3000a)
#define PR_EMS_AB_COMPROMISED_KEY_LIST (0x81c40102)
#define PR_EMS_AB_COMPROMISED_KEY_LIST_ERROR (0x81c4000a)
#define PR_EMS_AB_INSADMIN_O (0x81c5000d)
#define PR_EMS_AB_INSADMIN_O_ERROR (0x81c5000a)
#define PR_EMS_AB_INSADMIN (0x81c5001e)
#define PR_EMS_AB_INSADMIN_UNICODE (0x81c5001f)
#define PR_EMS_AB_OVERRIDE_NNTP_CONTENT_FORMAT (0x81c6000b)
#define PR_EMS_AB_OVERRIDE_NNTP_CONTENT_FORMAT_ERROR (0x81c6000a)
#define PR_EMS_AB_OBJ_VIEW_CONTAINERS_O (0x81c7000d)
#define PR_EMS_AB_OBJ_VIEW_CONTAINERS_O_ERROR (0x81c7000a)
#define PR_EMS_AB_OBJ_VIEW_CONTAINERS (0x81c7101e)
#define PR_EMS_AB_OBJ_VIEW_CONTAINERS_UNICODE (0x81c7101f)
#define PR_EMS_AB_VIEW_FLAGS (0x8c180003)
#define PR_EMS_AB_VIEW_FLAGS_ERROR (0x8c18000a)
#define PR_EMS_AB_GROUP_BY_ATTR_VALUE_STR (0x8c19001e)
#define PR_EMS_AB_GROUP_BY_ATTR_VALUE_STR_UNICODE (0x8c19001f)
#define PR_EMS_AB_GROUP_BY_ATTR_VALUE_STR_ERROR (0x8c19000a)
#define PR_EMS_AB_GROUP_BY_ATTR_VALUE_DN_O (0x8c1a000d)
#define PR_EMS_AB_GROUP_BY_ATTR_VALUE_DN_O_ERROR (0x8c1a000a)
#define PR_EMS_AB_GROUP_BY_ATTR_VALUE_DN (0x8c1a001e)
#define PR_EMS_AB_GROUP_BY_ATTR_VALUE_DN_UNICODE (0x8c1a001f)
#define PR_EMS_AB_VIEW_DEFINITION (0x8c1b1102)
#define PR_EMS_AB_VIEW_DEFINITION_ERROR (0x8c1b000a)
#define PR_EMS_AB_MIME_TYPES (0x8c1c0102)
#define PR_EMS_AB_MIME_TYPES_ERROR (0x8c1c000a)
#define PR_EMS_AB_LDAP_SEARCH_CFG (0x8c1d0003)
#define PR_EMS_AB_LDAP_SEARCH_CFG_ERROR (0x8c1d000a)
#define PR_EMS_AB_INBOUND_DN_O (0x8c1e000d)
#define PR_EMS_AB_INBOUND_DN_O_ERROR (0x8c1e000a)
#define PR_EMS_AB_INBOUND_DN (0x8c1e001e)
#define PR_EMS_AB_INBOUND_DN_UNICODE (0x8c1e001f)
#define PR_EMS_AB_INBOUND_NEWSFEED_TYPE (0x8c1f000b)
#define PR_EMS_AB_INBOUND_NEWSFEED_TYPE_ERROR (0x8c1f000a)
#define PR_EMS_AB_INBOUND_ACCEPT_ALL (0x8c20000b)
#define PR_EMS_AB_INBOUND_ACCEPT_ALL_ERROR (0x8c20000a)
#define PR_EMS_AB_ENABLED (0x8c21000b)
#define PR_EMS_AB_ENABLED_ERROR (0x8c21000a)
#define PR_EMS_AB_PRESERVE_INTERNET_CONTENT (0x8c22000b)
#define PR_EMS_AB_PRESERVE_INTERNET_CONTENT_ERROR (0x8c22000a)
#define PR_EMS_AB_DISABLE_DEFERRED_COMMIT (0x8c23000b)
#define PR_EMS_AB_DISABLE_DEFERRED_COMMIT_ERROR (0x8c23000a)
#define PR_EMS_AB_CLIENT_ACCESS_ENABLED (0x8c24000b)
#define PR_EMS_AB_CLIENT_ACCESS_ENABLED_ERROR (0x8c24000a)
#define PR_EMS_AB_REQUIRE_SSL (0x8c25000b)
#define PR_EMS_AB_REQUIRE_SSL_ERROR (0x8c25000a)
#define PR_EMS_AB_ANONYMOUS_ACCOUNT (0x8c26001e)
#define PR_EMS_AB_ANONYMOUS_ACCOUNT_UNICODE (0x8c26001f)
#define PR_EMS_AB_ANONYMOUS_ACCOUNT_ERROR (0x8c26000a)
#define PR_EMS_AB_CERTIFICATE_CHAIN_V3 (0x8c270102)
#define PR_EMS_AB_CERTIFICATE_CHAIN_V3_ERROR (0x8c27000a)
#define PR_EMS_AB_CERTIFICATE_REVOCATION_LIST_V3 (0x8c280102)
#define PR_EMS_AB_CERTIFICATE_REVOCATION_LIST_V3_ERROR (0x8c28000a)
#define PR_EMS_AB_CERTIFICATE_REVOCATION_LIST_V1 (0x8c290102)
#define PR_EMS_AB_CERTIFICATE_REVOCATION_LIST_V1_ERROR (0x8c29000a)
#define PR_EMS_AB_CROSS_CERTIFICATE_CRL (0x8c301102)
#define PR_EMS_AB_CROSS_CERTIFICATE_CRL_ERROR (0x8c30000a)
#define PR_EMS_AB_SEND_EMAIL_MESSAGE (0x8c31000b)
#define PR_EMS_AB_SEND_EMAIL_MESSAGE_ERROR (0x8c31000a)
#define PR_EMS_AB_ENABLE_COMPATIBILITY (0x8c32000b)
#define PR_EMS_AB_ENABLE_COMPATIBILITY_ERROR (0x8c32000a)
#define PR_EMS_AB_SMIME_ALG_LIST_NA (0x8c33101e)
#define PR_EMS_AB_SMIME_ALG_LIST_NA_UNICODE (0x8c33101f)
#define PR_EMS_AB_SMIME_ALG_LIST_NA_ERROR (0x8c33000a)
#define PR_EMS_AB_SMIME_ALG_LIST_OTHER (0x8c34101e)
#define PR_EMS_AB_SMIME_ALG_LIST_OTHER_UNICODE (0x8c34101f)
#define PR_EMS_AB_SMIME_ALG_LIST_OTHER_ERROR (0x8c34000a)
#define PR_EMS_AB_SMIME_ALG_SELECTED_NA (0x8c35001e)
#define PR_EMS_AB_SMIME_ALG_SELECTED_NA_UNICODE (0x8c35001f)
#define PR_EMS_AB_SMIME_ALG_SELECTED_NA_ERROR (0x8c35000a)
#define PR_EMS_AB_SMIME_ALG_SELECTED_OTHER (0x8c36001e)
#define PR_EMS_AB_SMIME_ALG_SELECTED_OTHER_UNICODE (0x8c36001f)
#define PR_EMS_AB_SMIME_ALG_SELECTED_OTHER_ERROR (0x8c36000a)
#define PR_EMS_AB_DEFAULT_MESSAGE_FORMAT (0x8c37000b)
#define PR_EMS_AB_DEFAULT_MESSAGE_FORMAT_ERROR (0x8c37000a)
#define PR_EMS_AB_TYPE (0x8c38001e)
#define PR_EMS_AB_TYPE_UNICODE (0x8c38001f)
#define PR_EMS_AB_TYPE_ERROR (0x8c38000a)
#define PR_EMS_AB_DO_OAB_VERSION (0x8c3a0003)
#define PR_EMS_AB_DO_OAB_VERSION_ERROR (0x8c3a000a)
#define PR_EMS_AB_VOICE_MAIL_SYSTEM_GUID (0x8c3b0102)
#define PR_EMS_AB_VOICE_MAIL_SYSTEM_GUID_ERROR (0x8c3b000a)
#define PR_EMS_AB_VOICE_MAIL_USER_ID (0x8c3c001e)
#define PR_EMS_AB_VOICE_MAIL_USER_ID_UNICODE (0x8c3c001f)
#define PR_EMS_AB_VOICE_MAIL_USER_ID_ERROR (0x8c3c000a)
#define PR_EMS_AB_VOICE_MAIL_PASSWORD (0x8c3d001e)
#define PR_EMS_AB_VOICE_MAIL_PASSWORD_UNICODE (0x8c3d001f)
#define PR_EMS_AB_VOICE_MAIL_PASSWORD_ERROR (0x8c3d000a)
#define PR_EMS_AB_VOICE_MAIL_RECORDED_NAME (0x8c3e0102)
#define PR_EMS_AB_VOICE_MAIL_RECORDED_NAME_ERROR (0x8c3e000a)
#define PR_EMS_AB_VOICE_MAIL_GREETINGS (0x8c3f101e)
#define PR_EMS_AB_VOICE_MAIL_GREETINGS_UNICODE (0x8c3f101f)
#define PR_EMS_AB_VOICE_MAIL_GREETINGS_ERROR (0x8c3f000a)
#define PR_EMS_AB_VOICE_MAIL_FLAGS (0x8c401102)
#define PR_EMS_AB_VOICE_MAIL_FLAGS_ERROR (0x8c40000a)
#define PR_EMS_AB_VOICE_MAIL_VOLUME (0x8c410003)
#define PR_EMS_AB_VOICE_MAIL_VOLUME_ERROR (0x8c41000a)
#define PR_EMS_AB_VOICE_MAIL_SPEED (0x8c420003)
#define PR_EMS_AB_VOICE_MAIL_SPEED_ERROR (0x8c42000a)
#define PR_EMS_AB_VOICE_MAIL_RECORDING_LENGTH (0x8c431003)
#define PR_EMS_AB_VOICE_MAIL_RECORDING_LENGTH_ERROR (0x8c43000a)
#define PR_EMS_AB_DISPLAY_NAME_SUFFIX (0x8c44001e)
#define PR_EMS_AB_DISPLAY_NAME_SUFFIX_UNICODE (0x8c44001f)
#define PR_EMS_AB_DISPLAY_NAME_SUFFIX_ERROR (0x8c44000a)
#define PR_EMS_AB_ATTRIBUTE_CERTIFICATE (0x8c451102)
#define PR_EMS_AB_ATTRIBUTE_CERTIFICATE_ERROR (0x8c45000a)
#define PR_EMS_AB_DELTA_REVOCATION_LIST (0x8c461102)
#define PR_EMS_AB_DELTA_REVOCATION_LIST_ERROR (0x8c46000a)
#define PR_EMS_AB_SECURITY_POLICY (0x8c471102)
#define PR_EMS_AB_SECURITY_POLICY_ERROR (0x8c47000a)
#define PR_EMS_AB_SUPPORT_SMIME_SIGNATURES (0x8c48000b)
#define PR_EMS_AB_SUPPORT_SMIME_SIGNATURES_ERROR (0x8c48000a)
#define PR_EMS_AB_DELEGATE_USER (0x8c49000b)
#define PR_EMS_AB_DELEGATE_USER_ERROR (0x8c49000a)
#define PR_EMS_AB_LIST_PUBLIC_FOLDERS (0x8c50000b)
#define PR_EMS_AB_LIST_PUBLIC_FOLDERS_ERROR (0x8c50000a)
#define PR_EMS_AB_LABELEDURI (0x8c51001e)
#define PR_EMS_AB_LABELEDURI_UNICODE (0x8c51001f)
#define PR_EMS_AB_LABELEDURI_ERROR (0x8c51000a)
#define PR_EMS_AB_RETURN_EXACT_MSG_SIZE (0x8c52000b)
#define PR_EMS_AB_RETURN_EXACT_MSG_SIZE_ERROR (0x8c52000a)
#define PR_EMS_AB_GENERATION_QUALIFIER (0x8c53001e)
#define PR_EMS_AB_GENERATION_QUALIFIER_UNICODE (0x8c53001f)
#define PR_EMS_AB_GENERATION_QUALIFIER_ERROR (0x8c53000a)
#define PR_EMS_AB_HOUSE_IDENTIFIER (0x8c54001e)
#define PR_EMS_AB_HOUSE_IDENTIFIER_UNICODE (0x8c54001f)
#define PR_EMS_AB_HOUSE_IDENTIFIER_ERROR (0x8c54000a)
#define PR_EMS_AB_SUPPORTED_ALGORITHMS (0x8c550102)
#define PR_EMS_AB_SUPPORTED_ALGORITHMS_ERROR (0x8c55000a)
#define PR_EMS_AB_DMD_NAME (0x8c56001e)
#define PR_EMS_AB_DMD_NAME_UNICODE (0x8c56001f)
#define PR_EMS_AB_DMD_NAME_ERROR (0x8c56000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_11 (0x8c57001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_11_UNICODE (0x8c57001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_11_ERROR (0x8c57000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_12 (0x8c58001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_12_UNICODE (0x8c58001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_12_ERROR (0x8c58000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_13 (0x8c59001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_13_UNICODE (0x8c59001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_13_ERROR (0x8c59000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_14 (0x8c60001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_14_UNICODE (0x8c60001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_14_ERROR (0x8c60000a)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_15 (0x8c61001e)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_15_UNICODE (0x8c61001f)
#define PR_EMS_AB_EXTENSION_ATTRIBUTE_15_ERROR (0x8c61000a)
#define PR_EMS_AB_REPLICATED_OBJECT_VERSION (0x8c620003)
#define PR_EMS_AB_REPLICATED_OBJECT_VERSION_ERROR (0x8c62000a)
#define PR_EMS_AB_MAIL_DROP (0x8c63001e)
#define PR_EMS_AB_MAIL_DROP_UNICODE (0x8c63001f)
#define PR_EMS_AB_MAIL_DROP_ERROR (0x8c63000a)
#define PR_EMS_AB_FORWARDING_ADDRESS (0x8c64001e)
#define PR_EMS_AB_FORWARDING_ADDRESS_UNICODE (0x8c64001f)
#define PR_EMS_AB_FORWARDING_ADDRESS_ERROR (0x8c64000a)
#define PR_EMS_AB_FORM_DATA (0x8c650102)
#define PR_EMS_AB_FORM_DATA_ERROR (0x8c65000a)
#define PR_EMS_AB_OWA_SERVER (0x8c66001e)
#define PR_EMS_AB_OWA_SERVER_UNICODE (0x8c66001f)
#define PR_EMS_AB_OWA_SERVER_ERROR (0x8c66000a)
#define PR_EMS_AB_EMPLOYEE_NUMBER (0x8c67001e)
#define PR_EMS_AB_EMPLOYEE_NUMBER_UNICODE (0x8c67001f)
#define PR_EMS_AB_EMPLOYEE_NUMBER_ERROR (0x8c67000a)
#define PR_EMS_AB_TELEPHONE_PERSONAL_PAGER (0x8c68001e)
#define PR_EMS_AB_TELEPHONE_PERSONAL_PAGER_UNICODE (0x8c68001f)
#define PR_EMS_AB_TELEPHONE_PERSONAL_PAGER_ERROR (0x8c68000a)
#define PR_EMS_AB_EMPLOYEE_TYPE (0x8c69001e)
#define PR_EMS_AB_EMPLOYEE_TYPE_UNICODE (0x8c69001f)
#define PR_EMS_AB_EMPLOYEE_TYPE_ERROR (0x8c69000a)
#define PR_EMS_AB_TAGGED_X509_CERT (0x8c6a1102)
#define PR_EMS_AB_TAGGED_X509_CERT_ERROR (0x8c6a000a)
#define PR_EMS_AB_PERSONAL_TITLE (0x8c6b001e)
#define PR_EMS_AB_PERSONAL_TITLE_UNICODE (0x8c6b001f)
#define PR_EMS_AB_PERSONAL_TITLE_ERROR (0x8c6b000a)
#define PR_EMS_AB_LANGUAGE_ISO639 (0x8c6c001e)
#define PR_EMS_AB_LANGUAGE_ISO639_UNICODE (0x8c6c001f)
#define PR_EMS_AB_LANGUAGE_ISO639_ERROR (0x8c6c000a)
#define PR_EMS_AB_OTHER_RECIPS (0xf000000d)
#define PR_EMS_AB_OTHER_RECIPS_ERROR (0xf000000a)
#define PR_EMS_AB_CHILD_RDNS (0xfff8101e)
#define PR_EMS_AB_CHILD_RDNS_UNICODE (0xfff8101f)
#define PR_EMS_AB_CHILD_RDNS_ERROR (0xfff8000a)
#define PR_EMS_AB_HIERARCHY_PATH (0xfff9001e)
#define PR_EMS_AB_HIERARCHY_PATH_UNICODE (0xfff9001f)
#define PR_EMS_AB_HIERARCHY_PATH_ERROR (0xfff9000a)
#define PR_EMS_AB_OBJECT_OID (0xfffa0102)
#define PR_EMS_AB_OBJECT_OID_ERROR (0xfffa000a)
#define PR_EMS_AB_IS_MASTER (0xfffb000b)
#define PR_EMS_AB_IS_MASTER_ERROR (0xfffb000a)
#define PR_EMS_AB_PARENT_ENTRYID (0xfffc0102)
#define PR_EMS_AB_PARENT_ENTRYID_ERROR (0xfffc000a)
#define PR_EMS_AB_CONTAINERID (0xfffd0003)
#define PR_EMS_AB_CONTAINERID_ERROR (0xfffd000a)
#define PR_EMS_AB_SERVER (0xfffe001e)
#define PR_EMS_AB_SERVER_UNICODE (0xfffe001f)
#define PR_EMS_AB_SERVER_ERROR (0xfffe000a)
#define MAPI_PROP_RESERVED (0xFFFFFFFF)
extern const value_string nspi_MAPITAGS_vals[];
int nspi_dissect_enum_MAPITAGS(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree, guint8 *drep, int hf_index, guint32 *param);
#define MAPI_E_SUCCESS (0x00000000)
#define MAPI_E_NO_SUPPORT (0x80040102)
#define MAPI_E_BAD_CHARWIDTH (0x80040103)
#define MAPI_E_STRING_TOO_LONG (0x80040105)
#define MAPI_E_UNKNOWN_FLAGS (0x80040106)
#define MAPI_E_INVALID_ENTRYID (0x80040107)
#define MAPI_E_INVALID_OBJECT (0x80040108)
#define MAPI_E_OBJECT_CHANGED (0x80040109)
#define MAPI_E_OBJECT_DELETED (0x8004010A)
#define MAPI_E_BUSY (0x8004010B)
#define MAPI_E_NOT_ENOUGH_DISK (0x8004010D)
#define MAPI_E_NOT_ENOUGH_RESOURCES (0x8004010E)
#define MAPI_E_NOT_FOUND (0x8004010F)
#define MAPI_E_VERSION (0x80040110)
#define MAPI_E_LOGON_FAILED (0x80040111)
#define MAPI_E_SESSION_LIMIT (0x80040112)
#define MAPI_E_USER_CANCEL (0x80040113)
#define MAPI_E_UNABLE_TO_ABORT (0x80040114)
#define MAPI_E_NETWORK_ERROR (0x80040115)
#define MAPI_E_DISK_ERROR (0x80040116)
#define MAPI_E_TOO_COMPLEX (0x80040117)
#define MAPI_E_BAD_COLUMN (0x80040118)
#define MAPI_E_EXTENDED_ERROR (0x80040119)
#define MAPI_E_COMPUTED (0x8004011A)
#define MAPI_E_CORRUPT_DATA (0x8004011B)
#define MAPI_E_UNCONFIGURED (0x8004011C)
#define MAPI_E_FAILONEPROVIDER (0x8004011D)
#define MAPI_E_UNKNOWN_CPID (0x8004011E)
#define MAPI_E_UNKNOWN_LCID (0x8004011F)
#define MAPI_E_PASSWORD_CHANGE_REQUIRED (0x80040120)
#define MAPI_E_PASSWORD_EXPIRED (0x80040121)
#define MAPI_E_INVALID_WORKSTATION_ACCOUNT (0x80040122)
#define MAPI_E_INVALID_ACCESS_TIME (0x80040123)
#define MAPI_E_ACCOUNT_DISABLED (0x80040124)
#define MAPI_E_END_OF_SESSION (0x80040200)
#define MAPI_E_UNKNOWN_ENTRYID (0x80040201)
#define MAPI_E_MISSING_REQUIRED_COLUMN (0x80040202)
#define MAPI_W_NO_SERVICE (0x80040203)
#define MAPI_E_BAD_VALUE (0x80040301)
#define MAPI_E_INVALID_TYPE (0x80040302)
#define MAPI_E_TYPE_NO_SUPPORT (0x80040303)
#define MAPI_E_UNEXPECTED_TYPE (0x80040304)
#define MAPI_E_TOO_BIG (0x80040305)
#define MAPI_E_DECLINE_COPY (0x80040306)
#define MAPI_E_UNEXPECTED_ID (0x80040307)
#define MAPI_W_ERRORS_RETURNED (0x80040380)
#define MAPI_E_UNABLE_TO_COMPLETE (0x80040400)
#define MAPI_E_TIMEOUT (0x80040401)
#define MAPI_E_TABLE_EMPTY (0x80040402)
#define MAPI_E_TABLE_TOO_BIG (0x80040403)
#define MAPI_E_INVALID_BOOKMARK (0x80040405)
#define MAPI_W_POSITION_CHANGED (0x80040481)
#define MAPI_W_APPROX_COUNT (0x80040482)
#define MAPI_E_WAIT (0x80040500)
#define MAPI_E_CANCEL (0x80040501)
#define MAPI_E_NOT_ME (0x80040502)
#define MAPI_W_CANCEL_MESSAGE (0x80040580)
#define MAPI_E_CORRUPT_STORE (0x80040600)
#define MAPI_E_NOT_IN_QUEUE (0x80040601)
#define MAPI_E_NO_SUPPRESS (0x80040602)
#define MAPI_E_COLLISION (0x80040604)
#define MAPI_E_NOT_INITIALIZED (0x80040605)
#define MAPI_E_NON_STANDARD (0x80040606)
#define MAPI_E_NO_RECIPIENTS (0x80040607)
#define MAPI_E_SUBMITTED (0x80040608)
#define MAPI_E_HAS_FOLDERS (0x80040609)
#define MAPI_E_HAS_MESAGES (0x8004060A)
#define MAPI_E_FOLDER_CYCLE (0x8004060B)
#define MAPI_W_PARTIAL_COMPLETION (0x80040680)
#define MAPI_E_AMBIGUOUS_RECIP (0x80040700)
#define MAPI_E_RESERVED (0xFFFFFFFF)
extern const value_string nspi_MAPISTATUS_vals[];
int nspi_dissect_enum_MAPISTATUS(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree, guint8 *drep, int hf_index, guint32 *param);
int nspi_dissect_struct_MAPIUID(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_input_locale(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_MAPI_SETTINGS(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_SPropTagArray(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_instance_key(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_MAPINAMEID(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
#define RES_AND (0)
#define RES_OR (1)
#define RES_NOT (2)
#define RES_CONTENT (3)
#define RES_PROPERTY (4)
#define RES_COMPAREPROPS (5)
#define RES_BITMASK (6)
#define RES_SIZE (7)
#define RES_EXIST (8)
#define RES_SUBRESTRICTION (9)
#define RES_COMMENT (10)
extern const value_string nspi_nspi_RestrictionType_vals[];
int nspi_dissect_enum_RestrictionType(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree, guint8 *drep, int hf_index, guint32 *param);
int nspi_dissect_struct_SPropertyRestriction(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_SAndRestriction(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_SRestriction(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_SSortOrder(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_SSortOrderSet(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_NAME_STRING(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
#define PT_UNSPECIFIED (0x0000)
#define PT_NULL (0x0001)
#define PT_I2 (0x0002)
#define PT_LONG (0x0003)
#define PT_R4 (0x0004)
#define PT_DOUBLE (0x0005)
#define PT_CURRENCY (0x0006)
#define PT_APPTIME (0x0007)
#define PT_ERROR (0x000a)
#define PT_BOOLEAN (0x000b)
#define PT_OBJECT (0x000d)
#define PT_I8 (0x0014)
#define PT_STRING8 (0x001e)
#define PT_UNICODE (0x001f)
#define PT_SYSTIME (0x0040)
#define PT_CLSID (0x0048)
#define PT_BINARY (0x0102)
#define PT_MV_I2 (0x1002)
#define PT_MV_LONG (0x1003)
#define PT_MV_R4 (0x1004)
#define PT_MV_DOUBLE (0x1005)
#define PT_MV_CURRENCY (0x1006)
#define PT_MV_APPTIME (0x1007)
#define PT_MV_I8 (0x1014)
#define PT_MV_STRING8 (0x101e)
#define PT_MV_TSTRING (0x101e)
#define PT_MV_UNICODE (0x101f)
#define PT_MV_SYSTIME (0x1040)
#define PT_MV_CLSID (0x1048)
#define PT_MV_BINARY (0x1102)
extern const value_string nspi_property_types_vals[];
int nspi_dissect_enum_property_types(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree, guint8 *drep, int hf_index, guint32 *param);
int nspi_dissect_struct_SBinary(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_FILETIME(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_SShortArray(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_MV_LONG_STRUCT(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_LPSTR(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_SLPSTRArray(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_SBinaryArray(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_SGuidArray(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_MV_UNICODE_STRUCT(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_SDateTimeArray(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_SPropValue(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_SRow(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
int nspi_dissect_struct_SRowSet(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, int hf_index, guint32 param _U_);
#endif /* __PACKET_DCERPC_NSPI_H */
